@@ -5,7 +5,7 @@
  *
  * Jon Trulson, 1/2006
  *
- * $Id: GL.h 707 2007-07-04 23:06:09Z jon $
+ * $Id: GL.h 762 2008-07-23 02:14:59Z jon13 $
  *
  * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -18,9 +18,9 @@
 /* Blinker animdefs useful to other modules */
 
 #if defined(NOEXTERN_GL)
-animStateRec_t GLBlinkerOneSec = {};
-animStateRec_t GLBlinkerHalfSec = {};
-animStateRec_t GLBlinkerQtrSec = {};
+animStateRec_t        GLBlinkerOneSec = {};
+animStateRec_t        GLBlinkerHalfSec = {};
+animStateRec_t        GLBlinkerQtrSec = {};
 #else
 extern animStateRec_t GLBlinkerOneSec;
 extern animStateRec_t GLBlinkerHalfSec;
@@ -41,8 +41,6 @@ typedef struct _glship {
   GLint     phas;             /* phaser */
   GLint     ico;              /* ship icon */
   GLint     ico_sh;           /* icon shields id */
-  GLint     ico_cloak;        /* cloak indicator */
-  GLint     ico_repair;       /* repairing */
   GLint     decal1;           /* sh/hull gauges */
   GLint     decal2;           /* fuel/w/e/alloc/kills gauges */
   GLint     dial;             /* ships astrogator dial */
@@ -91,8 +89,8 @@ GLfloat scaleFactorsSR[10] = {
 #else
 extern GLShip_t GLShips[NUMPLAYERTEAMS][MAXNUMSHIPTYPES]; 
 
-extern GLfloat scaleFactorsLR[10];
-extern GLfloat scaleFactorsSR[10];
+extern GLfloat  scaleFactorsLR[10];
+extern GLfloat  scaleFactorsSR[10];
 #endif
 
 #endif /* _C_GL_H */
