@@ -2,7 +2,7 @@
 
 /************************************************************************
  *
- * $Id: cd2lb.c 552 2006-07-17 04:47:23Z jon $
+ * $Id: cd2lb.c 774 2008-09-01 19:41:52Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -58,7 +58,11 @@
 #include "conf.h"
 #include "global.h"
 #include "color.h"
+
+#define NOEXTERN_CD2LB
 #include "cd2lb.h"
+#undef NOEXTERN_CD2LB
+
 #include "cumisc.h"
 #include "iolb.h"
 #include "ui.h"
@@ -159,7 +163,7 @@ void cdclra ( int l1, int c1, int l2, int c2 )
   cdfill(' ', tmpstr, j);
   tmpstr[j] = '\0';
 
-  /*  clog("cdclra(): rfl = %d rll = %d rfc = %d rlc = %d, maxcol = %d", rfl, rll, rfc, rlc, maxcol);
+  /*  utLog("cdclra(): rfl = %d rll = %d rfc = %d rlc = %d, maxcol = %d", rfl, rll, rfc, rlc, maxcol);
    */
 
 
@@ -220,9 +224,9 @@ void cdend(void)
   endwin();
 
 #if defined (HAVE_TERMIOS_H)
-  tcgetattr(PollInputfd, &term);
+  tcgetattr(iolbStdinFD, &term);
   term.c_cc[VINTR] = Context.intrchar; /* restore INTR */
-  tcsetattr(PollInputfd, TCSANOW, &term);
+  tcsetattr(iolbStdinFD, TCSANOW, &term);
 #endif
   
   return;
@@ -498,7 +502,7 @@ int cdgetp ( char pmt[], int lin, int col, char terms[], char str[],
       else if ( ! isprint ( ch & 0xff) )
 	{
 #ifdef DEBUG_IO
-	  clog("cdgetp1:Got a strange char: ascii %d, errno=%d", ch, errno);
+	  utLog("cdgetp1:Got a strange char: ascii %d, errno=%d", ch, errno);
 #endif
 	  cdbeep();
 	}
@@ -516,7 +520,7 @@ int cdgetp ( char pmt[], int lin, int col, char terms[], char str[],
       else
 	{
 #ifdef DEBUG_IO
-	  clog("cdgetp2:Got a strange char: '%c' = ascii %d", ch, ch);
+	  utLog("cdgetp2:Got a strange char: '%c' = ascii %d", ch, ch);
 #endif
 	  cdbeep(); /* exceeded max. allowable characters. */
 	  if (do_append_flg == TRUE) {
@@ -562,7 +566,7 @@ int cdgetp ( char pmt[], int lin, int col, char terms[], char str[],
 		  str[i] = ' ';
 	      }
 	    } 
-	    iBufPut(mbuf);
+	    ibufPut(mbuf);
 	    *append_flg = TRUE;
 	    break;
 	  } /* end if do_append_flg */
@@ -607,9 +611,7 @@ void cdinit(void)
 
   /* Initialize screen library (this MUST be done first). */
   
-  iBufInit();
-  
-  PollInputfd = 0;		/* for stdin */
+  ibufInit();
   
   initscr();
   start_color();
@@ -628,45 +630,31 @@ void cdinit(void)
   maxcol = ((COLS > 80) ? 80 : COLS);
   maxlin = LINES;
 
-  /* make sure COLS is >= 80,
-     LINES >= 24 */
+  /* make sure COLS is >= 80, LINES >= 24 */
   
-  if (maxcol < 80 || LINES < 24)
+  if (maxcol < 80 || LINES < 25)
     {
       cdend();
       
-      fprintf(stderr, "Your terminal must have at least 80 columns and 24 lines.\n");
+      fprintf(stderr, 
+              "\nYour terminal must have at least 80 columns and 25 lines.\n");
       
       exit(1);
     }
   
-  /* If you have  25 or more lines, use line 25 to display messages in, else
-     set to regular msg line... */
-
-  if (LINES >= 25)
-    {
-      RMsg_Line = 25;
-    }
-  else
-    {
-      RMsg_Line = MSG_LIN1;
-    }
-
-				/* get the users INTR char if possible
-				   so it can be stuffed into the KB
-				   buffer if a INTR is recieved.  Useful
-				   for unixware systems where DEL is the
-				   default INTR char.  This should allow
-				   DEL to be used for deleting text
-				   for example */
+  /* get the users INTR char if possible so it can be stuffed into the
+   *  KB buffer if a INTR is recieved.  Useful for unixware systems
+   *  where * DEL is the default INTR char.  This should allow DEL
+   *  to be used for deleting text for example 
+   */
 
   Context.intrchar = 0;	/* default - nothing */
 
 #if defined (HAVE_TERMIOS_H)
-  tcgetattr(PollInputfd, &term);
+  tcgetattr(iolbStdinFD, &term);
   Context.intrchar = term.c_cc[VINTR]; /* save it */
   term.c_cc[VINTR] = 0x03;	/* ^C - harmless */
-  tcsetattr(PollInputfd, TCSANOW, &term);
+  tcsetattr(iolbStdinFD, TCSANOW, &term);
 #endif
 
   cdclear();
