@@ -2,7 +2,7 @@
 
 /************************************************************************
  *
- * $Id: colorCU.c 552 2006-07-17 04:47:23Z jon $
+ * $Id: colorCU.c 762 2008-07-23 02:14:59Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -86,7 +86,7 @@ void uiInitColors(void)
   if (Context.hascolor)
     {
 #ifdef DEBUG_COLOR
-      clog("Terminal has colors, COLORS = %d, COLOR_PAIRS = %d",
+      utLog("Terminal has colors, COLORS = %d, COLOR_PAIRS = %d",
            COLORS,
            COLOR_PAIRS);
 #endif
