@@ -2,7 +2,7 @@
  *
  * conf.h - header for conf.c
  *
- * $Id: conf.h 688 2006-11-27 22:34:45Z jon $
+ * $Id: conf.h 762 2008-07-23 02:14:59Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -20,11 +20,6 @@
 
 #include "datatypes.h"
 #include "cqkeys.h"
-#ifdef CONF_NOEXTERN
-# define CEXTERN
-#else
-# define CEXTERN extern
-#endif
 
 #define SYSCONFIG_FILE "conquestrc"	/* relative to CONQETC */
 #define CONFIG_FILE "conquestrc"
@@ -76,59 +71,84 @@ struct Conf
 #define SYSCF_END (sizeof(SysConfData)/sizeof(struct Conf))
 
 typedef struct _userConf {
-				/* Whether to beep on an incoming message */
+  /* Whether to beep on an incoming message */
   int MessageBell;
-				/* Whether or not to disable color */
+
+  /* Whether or not to disable color */
   int NoColor;
-				/* whether or not you want to see robot msgs */
+
+  /* whether or not you want to see robot msgs */
   int NoRobotMsgs;
-				/* whether to update the screen twice per */
-				/* second instead of once per second. */
+
+  /* whether to update the screen twice per 
+   * second instead of once per second. 
+   */
   int UpdatesPerSecond;
-				/* whether to send emergency distress calls
-				   to all friendly ships, rather than just
-				   your team mates */
+
+  /* whether to send emergency distress calls
+   *  to all friendly ships, rather than just
+   *  your team mates 
+   */
   int DistressToFriendly;
-				/* whether to use alt HUD.  no effect if
-				   allow_alt_hud is false */
+
+  /* not currently used. */
   int AltHUD;
-				/* Macro keys - F1-F<MAX_MACROS> */
 
-  int ShowPhasers;		/* want phaser graphics? */
+  /* whether to display last firing angle, and target, distance, and
+   *  angle of the last ship or planet that was (i)nfo'd
+   */
+  int hudInfo; 
 
-  int ShowPlanNames;		/* show planet names? */
+  /* want phaser graphics? */
+  int ShowPhasers;
 
-  int DoAlarms;			/* want alarm bell? */
+  /* show planet names? */
+  int ShowPlanNames;
 
-  int DoIntrudeAlert;		/* want intruder alerts */
+  /* want alarm bell? */
+  int DoAlarms;
 
-  int DoNumMap;			/* want numeric map */
+  /* want intruder alerts */
+  int DoIntrudeAlert;
 
-  int Terse;			/* be terse? */
- 
-  int DoExplode;		/* show explosions? */
+  /* want numeric map */
+  int DoNumMap;
 
-				/* can see friendly torps on LR scan? */
+  /* be terse? */
+  int Terse;
+
+  /* show explosions? */
+  int DoExplode;
+
+  /* can see friendly torps on LR scan? */
   int DoLRTorpScan;
-                              /* (M)ap is actually LongeRange scan? */
+
+  /* (M)ap is actually LongeRange scan? */
   int DoLocalLRScan;
-                                /* (I)nfo cmds return ETA data? */
+
+  /* (I)nfo cmds return ETA data? */
   int DoETAStats;
-     /* for the GL client only - draws a red box around enemy ships */
+
+  /* for the GL client only - draws a red box around enemy ships */
   int EnemyShipBox;
 
-  int doVBG;                    /* draw the background in the viewer? */
+  /* draw the background in the viewer? */
+  int doVBG;
 
-  int DoShields;                /* Cataboligne - enhanced colored shield
-                                   indicator */
+  /* Cataboligne - enhanced colored shield indicator */
+  int DoShields;
 
-  int DoTacBkg;                 /* tactical background graphic */
+  /* tactical background graphic */
+  int DoTacBkg;
 
-  int DoTacShade;               /* tactical background alpha */
+  /* tactical background alpha */
+  int DoTacShade;
 
-  int musicVol;                 /* nusic/effects volume */
+  /* nusic/effects volume */
+  int musicVol;
   int effectsVol;
 
+  /* Macro keys - F1-F<MAX_MACROS> */
   char MacrosF[MAX_MACROS][MAX_MACRO_LEN];
 
   /* mouse macros, indexed by [max buttons][modifiers (8)]  */
@@ -137,32 +157,36 @@ typedef struct _userConf {
 } UserConf_t;
 
 typedef struct _sysConf {
-				/* randomly gen a doomsday machine? */
+  /* randomly gen a doomsday machine? */
   int NoDoomsday;
-				/* allow randomized robot strengths */
+
+  /* allow randomized robot strengths */
   int DoRandomRobotKills;
-				/* allow vacant ships */
+
+  /* allow vacant ships */
   int AllowVacant;
-				/* allow users to (s)witchteams from main
-				   menu */
+
+  /* allow users to (s)witchteams from main menu */
   int AllowSwitchteams;
-				/* number of days of inactivity before
-				   expiring a user */
+
+  /* number of days of inactivity before expiring a user */
   int UserExpiredays;
 
-				/* whether to log all messages into
-				   the logfile */
+  /* whether to log all messages into the logfile */
   int LogMessages;
 
-				/* whether to allow refitting */
+  /* whether to allow refitting */
   int AllowRefits;
 
-  int AllowSlingShot;           /* slingshot bug enabled? */
+  /* slingshot bug enabled? */
+  int AllowSlingShot; 
 
   /* server name */
   char ServerName[CONF_SERVER_NAME_SZ];
+
   /* server motd */
   char ServerMotd[CONF_SERVER_MOTD_SZ];
+
   /* server owner contact info */
   char ServerContact[META_GEN_STRSIZE];
 
@@ -172,35 +196,37 @@ typedef struct _sysConf {
 				/* Revision on conquestrc file */
 				/* - for updating conquestrc   */
 				/*   when something changes */
-#ifndef CONF_NOEXTERN
-CEXTERN char ConfigVersion[];
-
-#else
-char ConfigVersion[] = "$Revision: 688 $";
-#endif /* CONF_NOEXTERN */
-
+#ifdef NOEXTERN_CONF
+char              ConfigVersion[] = "$Revision: 762 $";
 /* Config's */
-CEXTERN UserConf_t UserConf;
-CEXTERN SysConf_t SysConf;
+UserConf_t        UserConf;
+SysConf_t         SysConf;
+#else
+extern char       ConfigVersion[];
+/* Config's */
+extern UserConf_t UserConf;
+extern SysConf_t  SysConf;
+#endif /* NOEXTERN_CONF */
+
 
 				/* local function declarations */
 void confSetTelnetClientMode(int telnetc);
 int confGetTelnetClientMode(void);
-CEXTERN int GetSysConf(int checkonly);
-CEXTERN int GetConf(int usernum);
-CEXTERN int MakeSysConf(void);
-CEXTERN int SaveUserConfig(void);
-CEXTERN int SaveSysConfig(void);
-CEXTERN char *Str2Macro(char *str);
-CEXTERN char *Macro2Str(char *str);
-CEXTERN char *process_macrostr(char *str);
-CEXTERN int process_bool(char *bufptr);
-CEXTERN int MakeConf(char *filename);
-CEXTERN Unsgn32 getServerFlags(void);
+int GetSysConf(int checkonly);
+int GetConf(int usernum);
+int MakeSysConf(void);
+int SaveUserConfig(void);
+int SaveSysConfig(void);
+char *Str2Macro(char *str);
+char *Macro2Str(char *str);
+char *process_macrostr(char *str);
+int process_bool(char *bufptr);
+int MakeConf(char *filename);
+Unsgn32 getServerFlags(void);
 
 				/* Initialize the system configurables */
-#ifndef CONF_NOEXTERN
-CEXTERN struct Conf SysConfData[];
+#ifndef NOEXTERN_CONF
+extern struct Conf SysConfData[];
 #else
 struct Conf SysConfData[] =
 {
@@ -400,10 +426,10 @@ struct Conf SysConfData[] =
     }
   }
 };
-#endif /* CONF_NOEXTERN */
+#endif /* NOEXTERN_CONF */
 				/* Initialize the user configurables */
-#ifndef CONF_NOEXTERN
-CEXTERN struct Conf ConfData[];
+#ifndef NOEXTERN_CONF
+extern struct Conf ConfData[];
 #else
 struct Conf ConfData[] =
 {
@@ -618,13 +644,30 @@ struct Conf ConfData[] =
     0, 0,			/* mix/max */
     "Use an alternate, experimental HUD",
     {
-      "# define this as true if you want to use a new, experimental",
-      "#  HUD.  This option allows the display of certain information",
-      "#  on the bottom view line.  There may be more in the future.",
+      "# Not currently used, but might be in a future revision.",
       "#  Default: false",
       NULL,
     }
   },
+  {
+    FALSE,
+    CTYPE_BOOL,
+    "hud_info=",
+    &UserConf.hudInfo,
+    0, 0,			/* mix/max */
+    "Display and retain certain (i)nfo'd data in the cockpit HUD",
+    {
+      "# define this as true if you want to display last firing angle, ",
+      "#  and the target, distance, and angle of the last ship or planet ",
+      "#  that was (i)nfo'd in the 'hud'",
+      "#",
+      "# For the curses client, this info will displayed below the viewer.",
+      "# For the OpenGL client, this info will be displayed below the ",
+      "#  HUD iconic ship display.",
+      "#  Default: true",
+      NULL,
+    }
+  },
   {
     FALSE,
     CTYPE_BOOL,
@@ -788,7 +831,7 @@ struct Conf ConfData[] =
       "#  that particular Button and Modifier combination is pressed.",
       "#",
       "# The following special sequences are recognized:",
-      "#  \\r = [RETURN], \\t = [TAB] \\a = [Clicked Angle]",
+      "#  \\r = [ENTER], \\t = [TAB] \\a = [Clicked Angle]",
       "#",
       "# Here are some example entries as they might appear in the",
       "#  ~/.conquest/conquestrc file:",
@@ -821,7 +864,7 @@ struct Conf ConfData[] =
       "#  that particular Function Key is hit.",
       "#",
       "# The following special sequences are recognized:",
-      "#  \\r = [RETURN], \\t = [TAB]",
+      "#  \\r = [ENTER], \\t = [TAB]",
       "#",
       "# Here are some example entries as they might appear in the",
       "#  ~/.conquest/conquestrc file:",
@@ -839,20 +882,18 @@ struct Conf ConfData[] =
     }
   }
 };
-#endif /* CONF_NOEXTERN */
+#endif /* NOEXTERN_CONF */
 
-#ifndef CONF_NOEXTERN
-CEXTERN int CfEnd;
+#ifndef NOEXTERN_CONF
+extern int CfEnd;
 #else
 int CfEnd = CF_END;
-#endif /* CONF_NOEXTERN */
+#endif /* NOEXTERN_CONF */
 
-#ifndef CONF_NOEXTERN
-CEXTERN int SysCfEnd;
+#ifndef NOEXTERN_CONF
+extern int SysCfEnd;
 #else
 int SysCfEnd = SYSCF_END;
-#endif /* CONF_NOEXTERN */
-
-#undef CEXTERN			/* cleanup */
+#endif /* NOEXTERN_CONF */
 
 #endif /* CONF_H */
