@@ -1,7 +1,7 @@
 
 /************************************************************************
  *
- * $Id: conqcom.h 552 2006-07-17 04:47:23Z jon $
+ * $Id: conqcom.h 762 2008-07-23 02:14:59Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -9,7 +9,7 @@
 #ifndef CONQCOM_H
 #define CONQCOM_H
 
-#ifdef NOCOMEXTERN
+#ifdef NOEXTERN_CONQCOM
 #define CEXTERN 
 #else
 #define CEXTERN extern 
@@ -27,12 +27,6 @@
 #include "history.h"
 #include "robot.h"
 
-/* for mapping variables into the common block */
-#define map1d(thevarp, thetype, size) {  \
-              thevarp = (thetype *) (cBasePtr + coff); \
-              coff += (sizeof(thetype) * (size)); \
-}
-
 #define CMN_MODE 0660		/* mode of a new common block */
 
 
