@@ -1,20 +1,23 @@
 /*
  * conqinit - utility program
  *
- * $Id: conqinit.c 700 2007-05-28 04:31:51Z jon $
+ * $Id: conqinit.c 762 2008-07-23 02:14:59Z jon13 $
  *
  */
 
 #include "c_defs.h"
 
-#define NOEXTERN
 #include "conqdef.h"
 #include "conqcom.h"
+
+#define NOEXTERN_CONTEXT
 #include "context.h"
   
 #include "global.h"
 #include "color.h"
 
+#include "conqutil.h"
+
 #include "conqinit.h"
 
 /* print_usage - print usage. Duh. */
@@ -43,7 +46,7 @@ int main(int argc, char **argv)
 
   rndini(0, 0);
   
-  setSystemLog(FALSE, TRUE);    /* log + stderr! :) */
+  utSetLogConfig(FALSE, TRUE);    /* log + stderr! :) */
 
   while ( (ch = getopt( argc, argv, "vdDf:hts" )) != EOF )
     {      switch(ch)
