@@ -2,7 +2,7 @@
 
 /************************************************************************
  *
- * $Id: conqlb.c 688 2006-11-27 22:34:45Z jon $
+ * $Id: conqlb.c 771 2008-08-17 20:32:24Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -28,7 +28,8 @@
 #include "conqcom.h"
 #include "context.h"
 #include "conqlb.h"
-#define NOCDHEXTERN
+#include "conqutil.h"
+#define NOEXTERN_CONQDATA
 #include "conqdata.h"
 
 #include "conf.h"
@@ -246,7 +247,7 @@ void clbIKill( int snum, int kb )
 	}
       
       /* Sticky war logic. */
-				/* should set sticky war too. -JET */
+      /* should set sticky war too. -JET */
 
       if ( ! Ships[snum].war[kteam] )
 	{
@@ -267,17 +268,29 @@ void clbIKill( int snum, int kb )
   
   if ( ! SROBOT(snum) || Ships[snum].pid != 0 )
     {
-      Ships[snum].status = SS_DEAD;
-      Ships[snum].sdfuse = -TIMEOUT_PLAYER;		/* setup dead timeout timer */
+      /* if the ship was vacant at the time, just turn it off, 
+       * freeing the slot immediately. 
+       */
+      if (SVACANT(snum))
+        {
+          Ships[snum].status = SS_OFF;
+        }
+      else
+        {
+          Ships[snum].status = SS_DEAD;
+          Ships[snum].sdfuse = -TIMEOUT_PLAYER; /* setup dead timeout timer */
+        }
     }
   else
     {
 #if defined(DO_EXPLODING_SHIPS)
       Ships[snum].status = SS_DEAD;
-      Ships[snum].sdfuse = -5;          /* setup dead timeout timer,
-				      for robots, that's 5 seconds, this
-				      gives enough time for detonating torps,
-				      just like regular players */
+
+      /* setup dead timeout timer. For robots, that's 5 seconds - this
+       *  gives enough time for detonating torps, just like regular
+       *  players
+       */
+      Ships[snum].sdfuse = -5;  
 #else
 				/* old behavior */
       Ships[snum].status = SS_OFF;   /* turn robots off */
@@ -606,7 +619,7 @@ void clbOrbit( int snum, int pnum )
   Ships[snum].dwarp = 0.0;
   
   /* Find bearing to planet. */
-  beer = angle( Ships[snum].x, Ships[snum].y, Planets[pnum].x, Planets[pnum].y );
+  beer = utAngle( Ships[snum].x, Ships[snum].y, Planets[pnum].x, Planets[pnum].y );
   if ( Ships[snum].head < ( beer - 180.0 ) )
     beer = beer - 360.0;
   
@@ -614,12 +627,12 @@ void clbOrbit( int snum, int pnum )
   if ( beer <= Ships[snum].head )
     {
       Ships[snum].warp = ORBIT_CW;
-      Ships[snum].head = mod360( beer + 90.0 );
+      Ships[snum].head = utMod360( beer + 90.0 );
     }
   else
     {
       Ships[snum].warp = ORBIT_CCW;
-      Ships[snum].head = mod360( beer - 90.0 );
+      Ships[snum].head = utMod360( beer - 90.0 );
     }
   
   return;
@@ -672,7 +685,7 @@ int clbPhaser( int snum, real dir )
 	  dis = dist( Ships[snum].x, Ships[snum].y, Ships[k].x, Ships[k].y );
 	  if ( dis <= PHASER_DIST )
 	    {
-	      ang = angle( Ships[snum].x, Ships[snum].y, Ships[k].x, Ships[k].y );
+	      ang = utAngle( Ships[snum].x, Ships[snum].y, Ships[k].x, Ships[k].y );
 	      if ( fabs( dir - ang ) <= PHASER_SPREAD )
 		{
 		  clbHit( k, clbPhaserHit( snum, dis ), snum );
@@ -745,8 +758,8 @@ int clbRegister( char *lname, char *rname, int team, int *unum )
 	  Users[i].ooptions[OOPT_SWITCHTEAMS] = FALSE;
 
 	Users[i].lastentry = 0;	/* never */
-	stcpn( lname, Users[i].username, MAXUSERNAME );
-	stcpn( rname, Users[i].alias, MAXUSERPNAME );
+	utStcpn( lname, Users[i].username, MAXUSERNAME );
+	utStcpn( rname, Users[i].alias, MAXUSERPNAME );
 	*unum = i;
 	return ( TRUE );
       }
@@ -786,7 +799,7 @@ void clbResign( int unum, int isoper )
   PVUNLOCK(&ConqInfo->lockword);
 
   if (isoper != TRUE)
-    clog("INFO: %s (%s) has resigned",
+    utLog("INFO: %s (%s) has resigned",
 	 usrname, usralias);
 	      
   return;
@@ -848,7 +861,7 @@ int clbTakePlanet( int pnum, int snum )
                   Teams[oteam].name);
                   
           clbStoreMsg(MSG_COMP, MSG_ALL, buf);
-          clog(buf);
+          utLog(buf);
         }
 
     }
@@ -856,7 +869,7 @@ int clbTakePlanet( int pnum, int snum )
 
   sprintf( buf, "All hail the liberating %s armies.  Thanks, ",
 	 Teams[Ships[snum].team].name );
-  appship( snum, buf );
+  utAppendShip( snum, buf );
   appchr( '!', buf );
   
   /* Check whether the universe has been conquered. */
@@ -869,14 +882,14 @@ int clbTakePlanet( int pnum, int snum )
 	  return rv;
 	}
   /* Yes! */
-  getdandt( ConqInfo->conqtime, 0 );
-  stcpn( Ships[snum].alias, ConqInfo->conqueror, MAXUSERPNAME );
+  utFormatTime( ConqInfo->conqtime, 0 );
+  utStcpn( Ships[snum].alias, ConqInfo->conqueror, MAXUSERPNAME );
   ConqInfo->lastwords[0] = EOS;
   Users[Ships[snum].unum].stats[USTAT_CONQUERS] += 1;
   Teams[Ships[snum].team].stats[TSTAT_CONQUERS] += 1;
-  stcpn( Teams[Ships[snum].team].name, ConqInfo->conqteam, MAXTEAMNAME );
+  utStcpn( Teams[Ships[snum].team].name, ConqInfo->conqteam, MAXTEAMNAME );
 
-  clog("INFO: %s (%s) has Conquered the Universe!",
+  utLog("INFO: %s (%s) has Conquered the Universe!",
        Users[Ships[snum].unum].username, 
        Ships[snum].alias);
   
@@ -957,7 +970,7 @@ void clbUserline( int unum, int snum, char *buf, int showgods, int showteam )
 	   ch,
 	   Users[unum].rating );
   
-  fmtminutes( ( Users[unum].stats[USTAT_SECONDS] + 30 ) / 60, timstr );
+  utFormatMinutes( ( Users[unum].stats[USTAT_SECONDS] + 30 ) / 60, timstr );
   
   sprintf( buf, "%s %5d %5d %5d %5d %9s",
 	 junk,
@@ -1039,7 +1052,7 @@ void clbStatline( int unum, char *buf )
     }      
   else
     {				/* format it properly */
-      getdandt(datestr, Users[unum].lastentry);
+      utFormatTime(datestr, Users[unum].lastentry);
     
       sprintf( junk, " %16.16s", datestr );
       j = 0;
@@ -1118,7 +1131,7 @@ int clbZeroPlanet( int pnum, int snum )
                       Teams[oteam].name);
               
               clbStoreMsg(MSG_COMP, MSG_ALL, buf);
-              clog(buf);
+              utLog(buf);
             }
         }
     }
@@ -1133,7 +1146,7 @@ int clbZeroPlanet( int pnum, int snum )
 char *clbWarPrompt(int snum, int twar[])
 {
   static char wbuf[BUFFER_SIZE];
-  static char *fmt = "Press TAB when done, ESCAPE to abort:  Peace: %c %c %c %c  War: %c %c %c %c";
+  static char *fmt = "Press [TAB] when done, [ESC] to abort:  Peace: %c %c %c %c  War: %c %c %c %c";
   int i;
   char ch, peace[NUMPLAYERTEAMS], war[NUMPLAYERTEAMS];
 
@@ -1312,9 +1325,9 @@ void clbDoomFind(void)
       }
   
   if ( Doomsday->lock < 0 )
-    Doomsday->heading = angle( Doomsday->x, Doomsday->y, Planets[-Doomsday->lock].x, Planets[-Doomsday->lock].y );
+    Doomsday->heading = utAngle( Doomsday->x, Doomsday->y, Planets[-Doomsday->lock].x, Planets[-Doomsday->lock].y );
   else if ( Doomsday->lock > 0 )
-    Doomsday->heading = angle( Doomsday->x, Doomsday->y, Ships[Doomsday->lock].x, Ships[Doomsday->lock].y );
+    Doomsday->heading = utAngle( Doomsday->x, Doomsday->y, Ships[Doomsday->lock].x, Ships[Doomsday->lock].y );
   
   return;
   
@@ -1369,8 +1382,16 @@ int clbFindOrbit( int snum, int *pnum )
 int clbFindShip( int *snum )
 {
   int i;
+  int vacantShips[MAXSHIPS];    /* MAXSHIPS is '1' based, use 0 based here */
+  int numvacant;
+
+  /* maybe free up some slots... */
+  clbCheckShips(FALSE);
+
   PVLOCK(&ConqInfo->lockword);
   *snum = -1;
+  numvacant = 0;
+
   for ( i = 1; i <= MAXSHIPS; i = i + 1 )
     {
       /* first, look for reserved ships that have no valid pid */
@@ -1378,28 +1399,55 @@ int clbFindShip( int *snum )
         if (!checkPID(Ships[i].pid))
           {
             Ships[i].status = SS_OFF; /* no-one there, turn it off */
-            clog("INFO: clbFindShip(): turned off reserved ship %d\n",
-                 i);
+            utLog("INFO: clbFindShip(): turned off reserved ship %d\n",
+                  i);
           }
 
+      /* if it's vacant, save it for later */
+      if (Ships[i].status == SS_LIVE && SVACANT(i))
+        vacantShips[numvacant++] = i;
+
       /* if it's off, grab it */
       if ( Ships[i].status == SS_OFF )
         {
           *snum = i;
-          clbZeroShip( *snum );
-          Ships[*snum].status = SS_RESERVED;
-          Ships[*snum].lastmsg = LMSG_NEEDINIT;
-          Ships[*snum].sdfuse = -TIMEOUT_PLAYER;
-          Ships[*snum].ctime = 0;
-          Ships[*snum].etime = 0;
-          Ships[*snum].cacc = 0;
-          Ships[*snum].eacc = 0;
           break;
         }
     }
+
+  if (*snum == -1)
+    {
+      /* we didn't find one.  If there were vacant ships, pick one and
+       *  steal it. 
+       */
+      if (numvacant)
+        {
+          if (numvacant == 1)
+            *snum = vacantShips[0];
+          else
+            *snum = vacantShips[rndint(0, numvacant - 1)];
+
+          utLog("INFO: clbFindShip: stealing vacant ship %d", *snum);
+          clbIKill( *snum,  KB_GOD );
+        }
+    }
+
+  if (*snum != -1)
+    {
+      /* we found one, so complete the takeover */
+      clbZeroShip( *snum );
+      Ships[*snum].status = SS_RESERVED;
+      Ships[*snum].lastmsg = LMSG_NEEDINIT;
+      Ships[*snum].sdfuse = -TIMEOUT_PLAYER;
+      Ships[*snum].ctime = 0;
+      Ships[*snum].etime = 0;
+      Ships[*snum].cacc = 0;
+      Ships[*snum].eacc = 0;
+    }
+
   PVUNLOCK(&ConqInfo->lockword);
   
-  return ( *snum != -1 );
+  return ( (*snum != -1) ? TRUE : FALSE );
   
 }
 
@@ -1741,12 +1789,12 @@ void clbInitEverything(void)
   ConqInfo->rcpuseconds = 0;
   ConqInfo->raccum = 0;
   
-  stcpn( "never", ConqInfo->lastupchuck, DATESIZE );
-  getdandt( ConqInfo->inittime, 0 );
-  getdandt( ConqInfo->conqtime, 0 );
-  stcpn( "GOD", ConqInfo->conqueror, MAXUSERPNAME );
-  stcpn( "self ruled", ConqInfo->conqteam, MAXTEAMNAME );
-  stcpn( "Let there be light...", ConqInfo->lastwords, MAXLASTWORDS );
+  utStcpn( "never", ConqInfo->lastupchuck, DATESIZE );
+  utFormatTime( ConqInfo->inittime, 0 );
+  utFormatTime( ConqInfo->conqtime, 0 );
+  utStcpn( "GOD", ConqInfo->conqueror, MAXUSERPNAME );
+  utStcpn( "self ruled", ConqInfo->conqteam, MAXTEAMNAME );
+  utStcpn( "Let there be light...", ConqInfo->lastwords, MAXLASTWORDS );
   
   /* Un-twiddle the lockwords. */
   PVUNLOCK(&ConqInfo->lockword);
@@ -1781,7 +1829,7 @@ void clbInitGame(void)
   Doomsday->dy = 0.0;
   Doomsday->heading = 0.0;
   Doomsday->lock = 0;
-  stcpn( "Doomsday Machine", Doomsday->name, MAXUSERPNAME );
+  utStcpn( "Doomsday Machine", Doomsday->name, MAXUSERPNAME );
   
   /* Un-twiddle the lockword. */
   PVUNLOCK(&ConqInfo->lockword);
@@ -1828,7 +1876,7 @@ void clbInitRobots(void)
 #define SETROBOT(x, y, z) \
   { \
       if ( clbGetUserNum( &unum, x, UT_LOCAL ) ) \
-          stcpn( y, Users[unum].alias, MAXUSERPNAME ); \
+          utStcpn( y, Users[unum].alias, MAXUSERPNAME ); \
       else if ( clbRegister( x, y, z, &unum ) ) \
       { \
 	  Users[unum].robot = TRUE; \
@@ -1869,14 +1917,17 @@ void clbInitShip( int snum, int unum )
 {
   int i, j;
   
-  /* sstatus(snum)				# never modified here */
+  /* Ships[snum].status                 # never modified here */
   Ships[snum].killedby = 0;
-  /* suser(snum)				# setup in menu() or newrob() */
-  /* steam(snum)				# setup in menu() or newrob() */
-  /* spid(snum)				# setup in menu() or newrob() */
-  /* shiptype - setup in newship and newrob */
-  Ships[snum].strkills = 0.0;	/* init to 0.0, newrob will init this
-				   for robots to make them stronger, faster.. ;-) */
+  /* Ships[snum].user                   # setup in menu() or newrob() */
+  /* Ships[snum].team                   # setup in menu() or newrob() */
+  /* Ships[snum].pid                    # setup in menu() or newrob() */
+  /* Ships[snum].shiptype               # setup in newship and newrob */
+
+  /* init to 0.0, newrob will init this for robots to make them
+   *   stronger, faster.. ;-) 
+   */
+  Ships[snum].strkills = 0.0;	
   Ships[snum].x = 0.0;
   Ships[snum].y = 0.0;
   Ships[snum].dx = 0.0;
@@ -1886,7 +1937,6 @@ void clbInitShip( int snum, int unum )
   Ships[snum].warp = 0.0;
   Ships[snum].dwarp = 0.0;
   Ships[snum].lock = 0;
-  SFSET(snum, SHIP_F_SHUP);
   Ships[snum].shields = 100.0;
   Ships[snum].kills = 0.0;
   Ships[snum].damage = 0.0;
@@ -1898,18 +1948,16 @@ void clbInitShip( int snum, int unum )
   Ships[snum].weapalloc = 40;
   Ships[snum].engalloc = 100 - Ships[snum].weapalloc;
   Ships[snum].armies = 0;
-  SFCLR(snum, SHIP_F_REPAIR);
-  SFCLR(snum, SHIP_F_CLOAKED);
-  /* soption(snum,i)				# setup in menu() */
+  /* Ships[snum].option                 # setup in menu() */
   for ( i = 0; i < NUMPLAYERTEAMS; i = i + 1 )
     {
-      /* srwar(snum,i)				# setup in menu() or newrob() */
-      /* swar(snum,i)				# setup in menu() or newrob() */
+      /* Ships[snum].rwar               # setup in menu() or newrob() */
+      /* Ships[snum].war                # setup in menu() or newrob() */
       Ships[snum].scanned[i] = 0;
     }
   for ( i = 1; i <= NUMPLANETS; i = i + 1 )
     Ships[snum].srpwar[i] = FALSE;
-  /* ssdfuse(snum)				# setup in clbFindShip() */
+  /* Ships[snum].sdfuse                 # setup in clbFindShip() */
   PVLOCK(&ConqInfo->lockmesg);
   if ( Ships[snum].lastmsg == LMSG_NEEDINIT )
     {
@@ -1917,16 +1965,17 @@ void clbInitShip( int snum, int unum )
       Ships[snum].alastmsg = Ships[snum].lastmsg;
     }
   PVUNLOCK(&ConqInfo->lockmesg);
-  SFCLR(snum, SHIP_F_MAP);
   Ships[snum].towing = 0;
   Ships[snum].towedby = 0;
   Ships[snum].lastblast = 0.0;
   Ships[snum].lastphase = 0.0;
   Ships[snum].pfuse = 0;
-  SFCLR(snum, SHIP_F_TALERT);
-  SFCLR(snum, SHIP_F_ROBOT);
   Ships[snum].action = 0;
-  /* spname(1,snum)				# setup in menu() or newrob() */
+
+  Ships[snum].flags = SHIP_F_NONE;
+  SFSET(snum, SHIP_F_SHUP);
+
+  /* Ships[snum].alias                  # setup in menu() or newrob() */
   
   /* Zero torpedos. */
   for ( i = 0; i < MAXTORPS; i = i + 1 )
@@ -1943,12 +1992,13 @@ void clbInitShip( int snum, int unum )
     }
   
   /* Update user some stats. */
-  Users[unum].lastentry = getnow(NULL, 0);/* time stamp for this entry */
+
+  /* time stamp for this entry */
+  Users[unum].lastentry = getnow(NULL, 0);
 
   Users[unum].stats[USTAT_ENTRIES] += 1;
   Teams[Ships[snum].team].stats[TSTAT_ENTRIES] += 1;
 
-  Ships[snum].flags = SHIP_F_NONE;
   return;
   
 }
@@ -1966,7 +2016,7 @@ void clbInitUniverse(void)
   PVUNLOCK(&ConqInfo->lockword);
   PVLOCK(&ConqInfo->lockword);
   
-  stcpn( "Scout", ShipTypes[ST_SCOUT].name, MAXSTNAME );
+  utStcpn( "Scout", ShipTypes[ST_SCOUT].name, MAXSTNAME );
   ShipTypes[ST_SCOUT].armylim = 7;
   ShipTypes[ST_SCOUT].warplim = 10.0;
   ShipTypes[ST_SCOUT].engfac = 1.2;
@@ -1974,7 +2024,7 @@ void clbInitUniverse(void)
   ShipTypes[ST_SCOUT].weafac = 0.83;
   ShipTypes[ST_SCOUT].torpwarp = 14.0;
 
-  stcpn( "Destroyer", ShipTypes[ST_DESTROYER].name, MAXSTNAME );
+  utStcpn( "Destroyer", ShipTypes[ST_DESTROYER].name, MAXSTNAME );
   ShipTypes[ST_DESTROYER].armylim = 9;
   ShipTypes[ST_DESTROYER].warplim = 9.0;
   ShipTypes[ST_DESTROYER].engfac = 1.0;
@@ -1982,7 +2032,7 @@ void clbInitUniverse(void)
   ShipTypes[ST_DESTROYER].weafac = 1.0;
   ShipTypes[ST_DESTROYER].torpwarp = 12.0;
 
-  stcpn( "Cruiser", ShipTypes[ST_CRUISER].name, MAXSTNAME );
+  utStcpn( "Cruiser", ShipTypes[ST_CRUISER].name, MAXSTNAME );
   ShipTypes[ST_CRUISER].armylim = 11;
   ShipTypes[ST_CRUISER].warplim = 8.0;
   ShipTypes[ST_CRUISER].engfac = 0.8;
@@ -1995,14 +2045,14 @@ void clbInitUniverse(void)
   Teams[TEAM_ROMULAN].shiptype = ST_CRUISER;
   Teams[TEAM_ORION].shiptype = ST_SCOUT;
   
-  stcpn( "Federation", Teams[TEAM_FEDERATION].name, MAXTEAMNAME );
-  stcpn( "Romulan", Teams[TEAM_ROMULAN].name, MAXTEAMNAME );
-  stcpn( "Klingon", Teams[TEAM_KLINGON].name, MAXTEAMNAME );
-  stcpn( "Orion", Teams[TEAM_ORION].name, MAXTEAMNAME );
-  stcpn( "self ruled", Teams[TEAM_SELFRULED].name, MAXTEAMNAME );
-  stcpn( "non", Teams[TEAM_NOTEAM].name, MAXTEAMNAME );
-  stcpn( "GOD", Teams[TEAM_GOD].name, MAXTEAMNAME );
-  stcpn( "Empire", Teams[TEAM_EMPIRE].name, MAXTEAMNAME );
+  utStcpn( "Federation", Teams[TEAM_FEDERATION].name, MAXTEAMNAME );
+  utStcpn( "Romulan", Teams[TEAM_ROMULAN].name, MAXTEAMNAME );
+  utStcpn( "Klingon", Teams[TEAM_KLINGON].name, MAXTEAMNAME );
+  utStcpn( "Orion", Teams[TEAM_ORION].name, MAXTEAMNAME );
+  utStcpn( "self ruled", Teams[TEAM_SELFRULED].name, MAXTEAMNAME );
+  utStcpn( "non", Teams[TEAM_NOTEAM].name, MAXTEAMNAME );
+  utStcpn( "GOD", Teams[TEAM_GOD].name, MAXTEAMNAME );
+  utStcpn( "Empire", Teams[TEAM_EMPIRE].name, MAXTEAMNAME );
   
   ConqInfo->chrplanets[PLANET_CLASSM] = 'M';
   ConqInfo->chrplanets[PLANET_DEAD] = 'D';
@@ -2013,14 +2063,14 @@ void clbInitUniverse(void)
   ConqInfo->chrplanets[PLANET_CLASSO] = 'O';
   ConqInfo->chrplanets[PLANET_CLASSZ] = 'Z';
 
-  stcpn( "class M planet", ConqInfo->ptname[PLANET_CLASSM], MAXPTYPENAME );
-  stcpn( "dead planet", ConqInfo->ptname[PLANET_DEAD], MAXPTYPENAME );
-  stcpn( "sun", ConqInfo->ptname[PLANET_SUN], MAXPTYPENAME );
-  stcpn( "moon", ConqInfo->ptname[PLANET_MOON], MAXPTYPENAME );
-  stcpn( "ghost planet", ConqInfo->ptname[PLANET_GHOST], MAXPTYPENAME );
-  stcpn( "class A planet", ConqInfo->ptname[PLANET_CLASSA], MAXPTYPENAME );
-  stcpn( "class O planet", ConqInfo->ptname[PLANET_CLASSO], MAXPTYPENAME );
-  stcpn( "class Z planet", ConqInfo->ptname[PLANET_CLASSZ], MAXPTYPENAME );
+  utStcpn( "class M planet", ConqInfo->ptname[PLANET_CLASSM], MAXPTYPENAME );
+  utStcpn( "dead planet", ConqInfo->ptname[PLANET_DEAD], MAXPTYPENAME );
+  utStcpn( "sun", ConqInfo->ptname[PLANET_SUN], MAXPTYPENAME );
+  utStcpn( "moon", ConqInfo->ptname[PLANET_MOON], MAXPTYPENAME );
+  utStcpn( "ghost planet", ConqInfo->ptname[PLANET_GHOST], MAXPTYPENAME );
+  utStcpn( "class A planet", ConqInfo->ptname[PLANET_CLASSA], MAXPTYPENAME );
+  utStcpn( "class O planet", ConqInfo->ptname[PLANET_CLASSO], MAXPTYPENAME );
+  utStcpn( "class Z planet", ConqInfo->ptname[PLANET_CLASSZ], MAXPTYPENAME );
   
   Teams[TEAM_FEDERATION].teamchar = 'F';
   Teams[TEAM_ROMULAN].teamchar = 'R';
@@ -2083,16 +2133,16 @@ void clbIntrude( int snum, int pnum )
 	  upper( Doomsday->name );
 	  appstr( atta, buf );
 	  appstr( armeq, buf );
-	  appint( Planets[pnum].armies, buf );
+	  utAppendInt( Planets[pnum].armies, buf );
 	  clbStoreMsgf( -pnum, -Planets[pnum].team, buf, MSG_FLAGS_INTRUDER );
 	}
       else if ( Ships[snum].war[Planets[pnum].team] )
 	{
 	  c_strcpy( "INTRUDER ALERT - ", buf );
-	  appship( snum, buf );
+	  utAppendShip( snum, buf );
 	  appstr( atta, buf );
 	  appstr( armeq, buf );
-	  appint( Planets[pnum].armies, buf );
+	  utAppendInt( Planets[pnum].armies, buf );
 	  clbStoreMsgf( -pnum, -Planets[pnum].team, buf, MSG_FLAGS_INTRUDER );
 	  defend( snum, pnum );
 	}
@@ -2112,7 +2162,7 @@ int clbLogHist( int unum )
   int hnum;
 
   PVLOCK(&ConqInfo->lockword);
-  ConqInfo->histptr = modp1( ConqInfo->histptr + 1, MAXHISTLOG );
+  ConqInfo->histptr = utModPlusOne( ConqInfo->histptr + 1, MAXHISTLOG );
 				/* time stamp for this entry */
   History[ConqInfo->histptr].histlog = getnow(NULL, 0 );	
   History[ConqInfo->histptr].elapsed = (time_t)0;
@@ -2175,7 +2225,7 @@ int clbPhoon( int pnum )
     return ( PHOON_NO );
   
   /* Things are cool, now calculate the phase. */
-  ph = (int) ( mod360( Planets[pnum].orbang - Planets[i].orbang - 45.0 ) / 90.0 );
+  ph = (int) ( utMod360( Planets[pnum].orbang - Planets[i].orbang - 45.0 ) / 90.0 );
   
   /* The number calculated is in the range 0 to 3, and works fine */
   /* if the moon is orbiting counter clockwise. If it is orbiting */
@@ -2206,14 +2256,14 @@ int clbPlanetMatch( char *str, int *pnum, int godlike )
   if ( godlike )
     {
       for ( *pnum = 1; *pnum <= NUMPLANETS; *pnum = *pnum + 1 )
-	if ( stmatch( str, Planets[*pnum].name, FALSE ) )
+	if ( utStringMatch( str, Planets[*pnum].name, FALSE ) )
 	  return ( TRUE );
     }
   else
     {
       for ( *pnum = 1; *pnum <= NUMPLANETS; *pnum = *pnum + 1 )
 	if ( Planets[*pnum].real )
-	  if ( stmatch( str, Planets[*pnum].name, FALSE ) )
+	  if ( utStringMatch( str, Planets[*pnum].name, FALSE ) )
 	    return ( TRUE );
     }
   
@@ -2226,8 +2276,8 @@ int clbPlanetMatch( char *str, int *pnum, int godlike )
 /*  SYNOPSIS */
 /*    int snum */
 /*    real basex, basey */
-/*    clPutShip( snum, basex, basey ) */
-void clPutShip( int snum, real basex, real basey )
+/*    clbPutShip( snum, basex, basey ) */
+void clbPutShip( int snum, real basex, real basey )
 {
   int i, j;
   real smear; 
@@ -2256,7 +2306,7 @@ void clPutShip( int snum, real basex, real basey )
   
   /* If we got here, we couldn't find a "good" position, */
   /*  so just report the error and let it slide. */
-  clog( "clPutShip(): Failed retry maximum on ship %d", snum );
+  utLog( "clbPutShip(): Failed retry maximum on ship %d", snum );
   
   return;
   
@@ -2272,7 +2322,7 @@ int clbFmtMsg(int to, int from, char *buf)
 				/* Format who the message is from. */
   if ( from > 0 && from <= MAXSHIPS )
     {
-      appship( from, buf );
+      utAppendShip( from, buf );
     }
   else if ( -from > 0 && -from <= NUMPLANETS )
     c_strcpy( Planets[-from].name, buf );
@@ -2302,7 +2352,7 @@ int clbFmtMsg(int to, int from, char *buf)
   
   /* Format who the message is to. */
   if ( to > 0 && to <= MAXSHIPS )
-    appship( to, buf );
+    utAppendShip( to, buf );
   else if ( -to >= 0 && -to < NUMPLAYERTEAMS )
     {
       appchr( Teams[-to].teamchar, buf );
@@ -2485,8 +2535,8 @@ void clbStoreMsgf( int from, int to, char *msg, unsigned char flags )
       return;
 
   PVLOCK(&ConqInfo->lockmesg);
-  nlastmsg = modp1( ConqInfo->lastmsg + 1, MAXMESSAGES );
-  stcpn( msg, Msgs[nlastmsg].msgbuf, MESSAGE_SIZE );
+  nlastmsg = utModPlusOne( ConqInfo->lastmsg + 1, MAXMESSAGES );
+  utStcpn( msg, Msgs[nlastmsg].msgbuf, MESSAGE_SIZE );
   Msgs[nlastmsg].msgfrom = from;
   Msgs[nlastmsg].msgto = to;
   Msgs[nlastmsg].flags = flags;
@@ -2501,7 +2551,7 @@ void clbStoreMsgf( int from, int to, char *msg, unsigned char flags )
   if (SysConf.LogMessages == TRUE || to == MSG_GOD || from == MSG_GOD)
     {
       clbFmtMsg(to, from, buf);
-      clog("MSG: %s: %s",
+      utLog("MSG: %s: %s",
 	   buf, msg);
     }
 
@@ -2636,7 +2686,6 @@ void clbZeroShip( int snum )
   Ships[snum].warp = 0.0;
   Ships[snum].dwarp = 0.0;
   Ships[snum].lock = 0;
-  SFSET(snum, SHIP_F_SHUP);
   Ships[snum].shields = 0.0;
   Ships[snum].kills = 0.0;
   Ships[snum].damage = 0.0;
@@ -2648,8 +2697,6 @@ void clbZeroShip( int snum )
   Ships[snum].weapalloc = 0;
   Ships[snum].engalloc = 0;
   Ships[snum].armies = 0;
-  SFCLR(snum, SHIP_F_REPAIR);
-  SFCLR(snum, SHIP_F_CLOAKED);
   Ships[snum].shiptype = ST_SCOUT;
   for ( i = 0; i < NUMPLAYERTEAMS; i = i + 1 )
     {
@@ -2662,14 +2709,11 @@ void clbZeroShip( int snum )
   Ships[snum].sdfuse = 0;
   Ships[snum].lastmsg = 0;
   Ships[snum].alastmsg = 0;
-  SFCLR(snum, SHIP_F_MAP);
   Ships[snum].towing = 0;
   Ships[snum].towedby = 0;
   Ships[snum].lastblast = 0.0;
   Ships[snum].lastphase = 0.0;
   Ships[snum].pfuse = 0;
-  SFCLR(snum, SHIP_F_TALERT);
-  SFCLR(snum, SHIP_F_ROBOT);
   Ships[snum].action = 0;
   for ( i = 0; i < MAXUSERPNAME; i = i + 1 )
     Ships[snum].alias[i] = EOS;
@@ -2678,6 +2722,9 @@ void clbZeroShip( int snum )
   Ships[snum].cacc = 0;
   Ships[snum].eacc = 0;
   
+  Ships[snum].flags = SHIP_F_NONE;
+  SFSET(snum, SHIP_F_SHUP);
+
   for ( i = 0; i < MAXTORPS; i = i + 1 )
     {
       Ships[snum].torps[i].status = TS_OFF;
@@ -2707,7 +2754,7 @@ char *clbGetUserLogname(void)
     {
       if ((pwd = getpwuid(geteuid())) == NULL)
 	{
-	  clog("ERROR: clbGetUserLogname(): getpwuid(geteuid()) failed: %s",
+	  utLog("ERROR: clbGetUserLogname(): getpwuid(geteuid()) failed: %s",
 	       strerror(errno));
 	  
 	  pwname[0] = 0;
@@ -2736,7 +2783,7 @@ void clbPlanetDrive(real itersec)
       if ( Planets[i].primary != 0 )
 	{
 
-	  Planets[i].orbang = mod360( Planets[i].orbang + 
+	  Planets[i].orbang = utMod360( Planets[i].orbang + 
                                       Planets[i].orbvel *
                                       itersec / 60.0 );
 
@@ -2807,6 +2854,44 @@ void clbTorpDrive(real itersec)
   return;
 }
 
+/* cmpute a ship's proper position when orbiting */
+void clbAdjOrbitalPosition(int snum)
+{
+  if (snum > 0 && snum <= MAXSHIPS && Ships[snum].warp < 0.0)
+    {                           
+      int pnum = -Ships[snum].lock;
+      
+      if ( pnum > 0 && pnum <= NUMPLANETS )
+        {
+          /* ajust the ship's X/Y based on orbit direction and heading */
+          if ( Ships[snum].warp == ORBIT_CW )
+            {
+              Ships[snum].x = 
+                (real)(Planets[pnum].x + (ORBIT_DIST * 
+                                          cosd(Ships[snum].head + 90.0)));
+              
+              Ships[snum].y = 
+                (real)(Planets[pnum].y + (ORBIT_DIST * 
+                                          sind(Ships[snum].head + 90.0)));
+            }
+          else if ( Ships[snum].warp == ORBIT_CCW )
+            {
+              /* Orbiting counter-clockwise. */
+              Ships[snum].x = 
+                (real)(Planets[pnum].x + (ORBIT_DIST * 
+                                          cosd(Ships[snum].head - 90.0)));
+              
+              Ships[snum].y = 
+                (real)(Planets[pnum].y + (ORBIT_DIST * 
+                                          sind(Ships[snum].head - 90.0)));
+              
+            }
+        }
+    }
+  return;
+}
+
+
 /* borrowed from glut */
 #if defined(SVR4) && !defined(sun)  /* Sun claims SVR4, but
                                        wants 2 args. */
@@ -2814,18 +2899,7 @@ void clbTorpDrive(real itersec)
 #else
 #define GETTIMEOFDAY(_x) gettimeofday(_x, NULL)
 #endif
-#define ADD_TIME(dest, src1, src2) { \
-  if(((dest).tv_usec = \
-    (src1).tv_usec + (src2).tv_usec) >= 1000000) { \
-    (dest).tv_usec -= 1000000; \
-    (dest).tv_sec = (src1).tv_sec + (src2).tv_sec + 1; \
-  } else { \
-    (dest).tv_sec = (src1).tv_sec + (src2).tv_sec; \
-    if(((dest).tv_sec >= 1) && (((dest).tv_usec <0))) { \
-      (dest).tv_sec --;(dest).tv_usec += 1000000; \
-    } \
-  } \
-}
+
 #define TIMEDELTA(dest, src1, src2) { \
   if(((dest).tv_usec = (src1).tv_usec - (src2).tv_usec) < 0) { \
     (dest).tv_usec += 1000000; \
@@ -2885,3 +2959,48 @@ void clbUnblockAlarm(void)
 
   return;
 }
+
+/* may use LOCKING */
+void clbCheckShips(int isDriver)
+{
+  int i;
+
+  /* look for vacant ships that aren't marked vacant */
+  for (i=1; i <= MAXSHIPS; i++)
+    {
+      if (Ships[i].status == SS_LIVE && !SVACANT(i))
+        if (Ships[i].pid > 0 && !checkPID(Ships[i].pid))
+          {
+            utLog("INFO: clbCheckShips(isDriver=%d): marking ship %d as VACANT", 
+                  isDriver, i);
+            SFSET(i, SHIP_F_VACANT);
+          }
+
+      /* if the ship is VACANT, and vacants aren't allowed, kill them. */
+      if (!SysConf.AllowVacant && SVACANT(i) && Ships[i].status == SS_LIVE )
+        {
+          /* when the driver calls this function, and the ship must be
+           *  killed, then we'll do it 'normally' so players can know
+           *  about it.  Otherwise just turn it off.
+           */
+          if (isDriver)
+            {
+              utLog("INFO: clbCheckShips(isDriver=%d): killing VACANT ship %d", 
+                    isDriver, i);
+              clbKillShip( i, KB_GOD );
+            }
+          else
+            {
+              /* just turn it off and log it */
+              utLog("INFO: clbCheckShips(isDriver=%d): turning off VACANT ship %d", 
+                    isDriver, i);
+              PVLOCK(&ConqInfo->lockword);
+              clbIKill( i,  KB_GOD );
+              clbZeroShip( i );
+              PVUNLOCK(&ConqInfo->lockword);
+            }
+        }
+    }
+
+  return;
+}
