@@ -4,19 +4,20 @@
  *
  * conqmetad - the Conquest meta server.  Similiar to conquestd no? :)
  *
- * $Id: conqmetad.c 711 2007-07-16 18:37:32Z jon $
+ * $Id: conqmetad.c 762 2008-07-23 02:14:59Z jon13 $
  *
  * Copyright 2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
 
 #include "global.h"
 #include "conqcom.h"
-#define NOEXTERN
+#define NOEXTERN_CONTEXT
 #include "context.h"
-#undef NOEXTERN
+#undef NOEXTERN_CONTEXT
 #include "conqdef.h"
 #include "conqnet.h"
 #include "conf.h"
+#include "conqutil.h"
 
 #include "meta.h"
 
@@ -63,10 +64,11 @@ static void sortmetas( int mv[], int numentries )
 
 void printUsage()
 {
-  printf("Usage: conqmetad [ -d ] [ -l ] [ -u user ]\n");
+  printf("Usage: conqmetad [ -d ] [ -l ] [ -u user ] [ -v ] \n");
   printf("   -d            daemon mode\n");
   printf("   -l            listen for local connections only\n");
   printf("   -u user       run as user 'user'.\n");
+  printf("   -v            be more verbose.\n");
 
   return;
 }
@@ -81,7 +83,7 @@ void ageServers(void)
       if (metaServerList[i].valid)
         if (abs(metaServerList[i].lasttime - now) > expireSeconds)
           {
-            clog("META: expiring %s:%u(%s)\n",
+            utLog("META: expiring %s:%u(%s)\n",
                  metaServerList[i].altaddr,
                  metaServerList[i].port,
                  metaServerList[i].addr);
@@ -167,11 +169,11 @@ void metaProcList(int sock, char *hostbuf)
   /* dump the sorted server list */
   for (i=0; i<nm; i++)
     {
-      srec2str(tbuf, &metaServerList[mvec[i]]);
+      metaServerRec2Buffer(tbuf, &metaServerList[mvec[i]]);
       write(sock, tbuf, strlen(tbuf));
     }
 
-  clog("META: server query from %s", hostbuf);
+  utLog("META: server query from %s", hostbuf);
 
   return;
 }
@@ -182,9 +184,9 @@ void metaProcUpd(char *buf, int rlen, char *hostbuf)
   int slot;
   int wasfound;
 
-  if (!str2srec(&sRec, buf))
+  if (!metaBuffer2ServerRec(&sRec, buf))
     {
-      clog("META: malformed buffer '%s', ignoring", buf);
+      utLog("META: malformed buffer '%s', ignoring", buf);
       return;
     }
 
@@ -198,7 +200,7 @@ void metaProcUpd(char *buf, int rlen, char *hostbuf)
   /* now find a slot for it. */
   if ((slot = findSlot(&sRec, &wasfound)) == -1)
     {
-      clog("META: findSlot couldn't find one, ignoring\n");
+      utLog("META: findSlot couldn't find one, ignoring\n");
       return;
     }
 
@@ -210,7 +212,7 @@ void metaProcUpd(char *buf, int rlen, char *hostbuf)
   metaServerList[slot] = sRec;
 
   if (!wasfound)                /* new server */
-    clog("META: Added server %s:%u(%s), slot %d",
+    utLog("META: Added server %s:%u(%s), slot %d",
          metaServerList[slot].altaddr,
          metaServerList[slot].port,
          metaServerList[slot].addr,
@@ -218,7 +220,7 @@ void metaProcUpd(char *buf, int rlen, char *hostbuf)
   else
     {
 #if defined(DEBUG_META)
-      clog("META: Updated server %s(%s)",
+      utLog("META: Updated server %s(%s)",
          metaServerList[slot].altaddr,
            metaServerList[slot].addr);
 #endif
@@ -238,10 +240,11 @@ void metaListen(void)
   struct timeval tv;
   socklen_t len;
   struct hostent *hp;
-  int rv, rlen, i;
+  int rv, rlen;
+  socklen_t sockln;
   char hostbuf[CONF_SERVER_NAME_SZ];
   char rbuf[BUFFERSZ];
-  int alen;
+  socklen_t alen;
   fd_set readfds;
 
   sa.sin_port = htons(listenPort);
@@ -295,7 +298,7 @@ void metaListen(void)
 
   alen = sizeof(struct sockaddr);
 
-  clog("NET: meta server listening on TCP and UDP port %d\n", listenPort);
+  utLog("NET: meta server listening on TCP and UDP port %d\n", listenPort);
   
   /* go into infinite loop waiting for new connections */
   while (TRUE) 
@@ -308,17 +311,17 @@ void metaListen(void)
 
       if ((rv = select(max(s,t)+1, &readfds, NULL, NULL, &tv)) < 0)
         {
-          clog("META: select failed: %s", strerror(errno));
+          utLog("META: select failed: %s", strerror(errno));
           exit(1);
         }
 
       /* TCP (list) socket */
       if (FD_ISSET(t, &readfds))
         {
-          i = sizeof (isa);
-          if ((tc = accept(t, (struct sockaddr *)&tisa, &i )) < 0) 
+          sockln = sizeof (isa);
+          if ((tc = accept(t, (struct sockaddr *)&tisa, &sockln )) < 0) 
             {
-              clog("META: accept failed: %s", strerror(errno) );
+              utLog("META: accept failed: %s", strerror(errno) );
               continue;
             }
           
@@ -396,7 +399,7 @@ int main(int argc, char *argv[])
 
   progName = argv[0];
 
-  while ((i = getopt(argc, argv, "dlp:u:")) != EOF)    /* get command args */
+  while ((i = getopt(argc, argv, "dlp:u:v")) != EOF)    /* get command args */
     switch (i)
       {
       case 'd':
@@ -414,6 +417,11 @@ int main(int argc, char *argv[])
       case 'u':
         myuidname = optarg;
         break;
+
+      case 'v':
+        cqDebug++;
+        break;
+
       default:
 	printUsage();
 	exit(1);
@@ -446,18 +454,18 @@ int main(int argc, char *argv[])
           exit(1);
         }        
       else
-        clog("INFO: META running as user '%s', uid %d.", myuidname, myuid); 
+        utLog("INFO: META running as user '%s', uid %d.", myuidname, myuid); 
     }
 
   
 #ifdef DEBUG_CONFIG
-  clog("%s@%d: main() Reading Configuration files.", __FILE__, __LINE__);
+  utLog("%s@%d: main() Reading Configuration files.", __FILE__, __LINE__);
 #endif
   
   if (GetSysConf(FALSE) == ERR)
     {
 #ifdef DEBUG_CONFIG
-      clog("%s@%d: main(): GetSysConf() returned ERR.", __FILE__, __LINE__);
+      utLog("%s@%d: main(): GetSysConf() returned ERR.", __FILE__, __LINE__);
 #endif
     }
 
@@ -465,7 +473,7 @@ int main(int argc, char *argv[])
   if (dodaemon)
     {
       int cpid;
-      clog("INFO: becoming daemon");
+      utLog("INFO: becoming daemon");
       chdir("/");
 
       cpid = fork();
@@ -535,6 +543,6 @@ void catchSignals(void)
 
 void handleSignal(int sig)
 {
-  clog("META: exiting on signal %d", sig);
+  utLog("META: exiting on signal %d", sig);
   exit(0);
 }
