@@ -4,12 +4,11 @@
  *
  * conqreplay - replay a cqr recording for curses interface
  *
- * $Id: conqreplay.c 552 2006-07-17 04:47:23Z jon $
+ * $Id: conqreplay.c 774 2008-09-01 19:41:52Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
 
-#define NOEXTERN
 #include "conqdef.h"
 #include "conqcom.h"
 #include "context.h"
@@ -17,6 +16,7 @@
 #include "color.h"
 #include "ui.h"
 #include "conqlb.h"
+#include "conqutil.h"
 #include "cd2lb.h"
 #include "iolb.h"
 #include "cumisc.h"
@@ -34,34 +34,34 @@ static void replay(void);
 static void watch(void);
 static int prompt_ship(char buf[], int *snum, int *normal);
 static void toggle_line(int snum, int old_snum);
-static void setdheader(int show_header);
 static void dowatchhelp(void);
 static char *build_toggle_str(char *snum_str, int snum);
 
 
-/* overlay the elapsed time, and current frameDelay */
+/* overlay the elapsed time, and current recFrameDelay */
 void displayReplayData(void)
 {
   char buf[128];
-  time_t elapsed = (currTime - startTime);
+  time_t elapsed = (recCurrentTime - recStartTime);
   char *c;
+  real percent;
 
   /* elapsed time */
-  fmtseconds((int)elapsed, buf);
+  utFormatSeconds((int)elapsed, buf);
   c = &buf[2];			/* skip day count */
-  cdputs( c, DISPLAY_LINS + 1, 2 );
+  if (elapsed <= 0)
+    elapsed = 1;
+  
+  percent = ((real)elapsed / (real)recTotalElapsed ) * 100.0;
 
-  /* current frame delay */
-#if 1
-  sprintf(buf, "%2.3fs", frameDelay);
-#else  /* an attempt at fps. */
-  if (frameDelay != 0)
-    sprintf(buf, "%3.2f fps", (1.0 / frameDelay));
+  /* current speed */
+  if (pbSpeed == PB_SPEED_INFINITE)
+    /* current frame delay */
+    sprintf(buf, "%s (%d%%) INF", c, (int)percent);
   else
-    sprintf(buf, "MAX fps");
-#endif
+    sprintf(buf, "%s (%d%%) %2dx ", c, (int)percent, pbSpeed);
 
-  cdputs( buf, DISPLAY_LINS + 1, 15);
+  cdputs( buf, DISPLAY_LINS + 1, 2);
 
   /* paused status */
   if (Context.recmode == RECMODE_PAUSED)
@@ -97,17 +97,12 @@ void displayMsg(Msg_t *themsg)
       appstr( themsg->msgbuf, buf );
       
       uiPutColor(attrib);
-      mcuPutMsg( buf, RMsg_Line );
+      mcuPutMsg( buf, MSG_MSG );
       uiPutColor(0);
-      /* clear second line if sending to MSG_LIN1 */
-      if (RMsg_Line == MSG_LIN1)
-	{
-	  cdclrl( MSG_LIN2, 1 );
-	}
     }
   else
     {				/* just clear the message line */
-      cdclrl( RMsg_Line, 1 );
+      cdclrl( MSG_MSG, 1 );
     }
 
   return;
@@ -117,9 +112,9 @@ void displayMsg(Msg_t *themsg)
 /* MAIN */
 void conquestReplay(void)
 {
-  /* if frameDelay wasn't overridden, setup based on samplerate */
-  if (frameDelay == -1.0)
-    frameDelay = 1.0 / (real)fhdr.samplerate;
+  /* if recFrameDelay wasn't overridden, setup based on samplerate */
+  if (recFrameDelay == -1.0)
+    recFrameDelay = 1.0 / (real)recFileHeader.samplerate;
 
   replay();
   
@@ -181,7 +176,7 @@ static void replay(void)
 	case 'r':
 	  /* first close the input file, free the common block,
 	     then re-init */
-	  pbFileSeek(startTime);
+	  pbFileSeek(recStartTime);
 	  break;
 
         case '/':
@@ -221,7 +216,7 @@ static void watch(void)
       Context.redraw = TRUE;
       cdclear();
       cdredo();
-      grand( &msgrand );
+      utGrand( &msgrand );
       
       Context.snum = snum;		/* so display knows what to display */
       /*	  setopertimer();*/
@@ -238,23 +233,16 @@ static void watch(void)
 	  if (toggle_flg)
 	    toggle_line(snum,old_snum);
 	  
-	  
-	  setdheader( TRUE ); /* always true for watching ships and
-				 doomsday.  We may want to turn it off
-				 if we ever add an option for watching
-				 planets though, so we'll keep this
-				 in for now */
-	  
 	  if (Context.recmode == RECMODE_PLAYING || upddsp)
 	    {
-	      display(Context.snum, headerflag);
+	      display(Context.snum);
 	      displayReplayData();
               if (recMsg.msgbuf[0])
                 displayMsg(&recMsg);
 	      upddsp = FALSE;	/* use this for one-shots */
 	    }
 	  
-	  if (!iogtimed(&ch, frameDelay))
+	  if (!iogtimed(&ch, recFrameDelay))
 	  continue;
 	  
 	  /* got a char */
@@ -272,13 +260,13 @@ static void watch(void)
 	      
 	    case 'f':	/* move forward 30 seconds */
 	      displayMsg(NULL);
-	      pbFileSeek(currTime + 30);
+	      pbFileSeek(recCurrentTime + 30);
 	      upddsp = TRUE;
 	      break;
 	      
 	    case 'F':	/* move forward 2 minutes */
 	      displayMsg(NULL);
-	      pbFileSeek(currTime + (2 * 60));
+	      pbFileSeek(recCurrentTime + (2 * 60));
 	      upddsp = TRUE;
 	      break;
 	      
@@ -294,7 +282,7 @@ static void watch(void)
 	      displayMsg(NULL);
 	      cdputs( "Rewinding...", MSG_LIN1, 0);
 	      cdrefresh();
-	      pbFileSeek(currTime - 30);
+	      pbFileSeek(recCurrentTime - 30);
 	      cdclrl( MSG_LIN1, 1 );
 	      upddsp = TRUE;
 	      break;
@@ -303,7 +291,7 @@ static void watch(void)
 	      displayMsg(NULL);
 	      cdputs( "Rewinding...", MSG_LIN1, 0);
 	      cdrefresh();
-	      pbFileSeek(currTime - (2 * 60));
+	      pbFileSeek(recCurrentTime - (2 * 60));
 	      cdclrl( MSG_LIN1, 1 );
 	      upddsp = TRUE;
 	      break;
@@ -311,7 +299,7 @@ static void watch(void)
 	    case 'r':	/* reset to beginning */
 	      cdputs( "Rewinding...", MSG_LIN1, 0);
 	      cdrefresh();
-	      pbFileSeek(startTime);
+	      pbFileSeek(recStartTime);
 	      cdclrl( MSG_LIN1, 1 );
 	      upddsp = TRUE;
 	      break;
@@ -329,34 +317,22 @@ static void watch(void)
 	      upddsp = TRUE;
 	      break;
 		    
-	    case 'n':		/* set frameDelay to normal playback
+	    case 'n':		/* set recFrameDelay to normal playback
 				   speed.*/
-	      frameDelay = 1.0 / (real)fhdr.samplerate;
+              pbSetPlaybackSpeed(1, recFileHeader.samplerate);
 	      upddsp = TRUE;
 	      break;
 
 	      /* these seem backward, but it's easier to understand
 		 the '+' is faster, and '-' is slower ;-) */
 	    case '-':
-	      /* if it's at 0, we should still
-		 be able to double it. sorta. */
-	      if (frameDelay == 0.0) 
-		frameDelay = 0.001;
-	      frameDelay *= 2;
-	      if (frameDelay > 10.0) /* really, 10s is a *long* time
-					between frames... */
-		frameDelay = 10.0;
+              pbSetPlaybackSpeed(pbSpeed - 1, recFileHeader.samplerate);
 	      upddsp = TRUE;
 	      break;
 
 	    case '+': 
 	    case '=':
-	      if (frameDelay != 0)
-		{		/* can't divide 0 in our universe */
-		  frameDelay /= 2;
-		  if (frameDelay < 0.0)
-		    frameDelay = 0.0;
-		}
+              pbSetPlaybackSpeed(pbSpeed + 1, recFileHeader.samplerate);
 	      upddsp = TRUE;
 	      break;
 
@@ -576,13 +552,6 @@ static void watch(void)
   
 }
 
-static void setdheader(int show_header)
-{
-
-  headerflag = show_header;
-  return;
-}
-
 static int prompt_ship(char buf[], int *snum, int *normal)
 {
   int tch;
@@ -594,10 +563,10 @@ static int prompt_ship(char buf[], int *snum, int *normal)
 
   cdclrl( MSG_LIN1, 2 );
 
-  if (fhdr.snum == 0)
+  if (recFileHeader.snum == 0)
     buf[0] = EOS;
   else
-    sprintf(buf, "%d", fhdr.snum);
+    sprintf(buf, "%d", recFileHeader.snum);
 
   tch = cdgetx( pmt, MSG_LIN1, 1, TERMS, buf, MSGMAXLINE, TRUE );
   cdclrl( MSG_LIN1, 1 );
@@ -614,7 +583,7 @@ static int prompt_ship(char buf[], int *snum, int *normal)
   
   *normal = ( tch != TERM_EXTRA );		/* line feed means debugging */
 
-  delblanks( buf );
+  utDeleteBlanks( buf );
 
   if ( strlen( buf ) == 0 ) 
     {              /* watch doomsday machine */
@@ -631,7 +600,7 @@ static int prompt_ship(char buf[], int *snum, int *normal)
 	  c_sleep( 1.0 );
 	  return(FALSE); /* dwp */
 	}
-      safectoi( &tmpsnum, buf, 0 );	/* ignore return status */
+      utSafeCToI( &tmpsnum, buf, 0 );	/* ignore return status */
     }
 
   if ( (tmpsnum < 1 || tmpsnum > MAXSHIPS) && tmpsnum != DISPLAY_DOOMSDAY )
