@@ -2,7 +2,7 @@
 
 /************************************************************************
  *
- * $Id: conquest.c 698 2007-05-14 02:24:01Z jon $
+ * $Id: conquest.c 775 2008-09-01 20:21:05Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -24,12 +24,16 @@
 /*                                                                    */
 /**********************************************************************/
 
-#define NOEXTERN
 #include "conqdef.h"
 #include "conqcom.h"
 #include "conqlb.h"
+#include "conqutil.h"
+
+#define NOEXTERN_CONTEXT
 #include "context.h"
+
 #include "conf.h"
+
 #include "global.h"
 #include "color.h"
 #include "ui.h"
@@ -50,6 +54,7 @@
 #include "udp.h"
 #include "meta.h"
 #include "conqinit.h"
+#include "playback.h"
 
 #define CLIENTNAME "Conquest"	/* our client name */
 
@@ -166,7 +171,7 @@ int connectServer(char *remotehost, Unsgn16 remoteport)
 
   if ((hp = gethostbyname(remotehost)) == NULL) 
     {
-      clog("conquest: %s: no such host\n", remotehost);
+      utLog("conquest: %s: no such host\n", remotehost);
 
       cprintf(lin, 0, ALIGN_CENTER, "conquest: %s: no such host", 
               remotehost);
@@ -184,7 +189,7 @@ int connectServer(char *remotehost, Unsgn16 remoteport)
 
   if ((s = socket(AF_INET, SOCK_STREAM, 0 )) < 0) 
     {
-      clog("socket: %s", strerror(errno));
+      utLog("socket: %s", strerror(errno));
       cprintf(lin, 0, ALIGN_CENTER, "socket: %s", 
               remotehost);
       mcuPutPrompt(MTXT_DONE, MSG_LIN2 );
@@ -194,15 +199,15 @@ int connectServer(char *remotehost, Unsgn16 remoteport)
 
   if (cInfo.tryUDP)
     {
-      clog("NET: Opening UDP...");
+      utLog("NET: Opening UDP...");
       if ((cInfo.usock = udpOpen(0, &cInfo.servaddr)) < 0) 
         {
-          clog("NET: udpOpen: %s", strerror(errno));
+          utLog("NET: udpOpen: %s", strerror(errno));
           cInfo.tryUDP = FALSE;
         }
     }
 
-  clog("Connecting to host: %s, port %d\n",
+  utLog("Connecting to host: %s, port %d\n",
        remotehost, remoteport);
 
   cprintf(lin++, 0, ALIGN_CENTER, "Connecting to host: %s, port %d\n",
@@ -212,8 +217,8 @@ int connectServer(char *remotehost, Unsgn16 remoteport)
   /* connect to the remote server */
   if (connect(s, (const struct sockaddr *)&sa, sizeof(sa)) < 0) 
     {
-      clog("connect: %s", strerror(errno));
-      clog("Cannot connect to host %s:%d\n", 
+      utLog("connect: %s", strerror(errno));
+      utLog("Cannot connect to host %s:%d\n", 
            remotehost, remoteport);
 
       cprintf(lin++, 0, ALIGN_CENTER, "connect: %s", strerror(errno));
@@ -265,8 +270,8 @@ int main(int argc, char *argv[])
   cInfo.isLoggedIn = FALSE;
   cInfo.remoteport = CN_DFLT_PORT;
 
-  setSystemLog(FALSE, FALSE);	/* use $HOME for logfile */
-  if (!getLocalhost(cInfo.localhost, MAXHOSTNAME))
+  utSetLogConfig(FALSE, FALSE);	/* use $HOME for logfile */
+  if (!getLocalhost((char *)cInfo.localhost, MAXHOSTNAME))
     return(1);
 
   cInfo.remotehost = strdup("localhost"); /* default to your own server */
@@ -275,8 +280,9 @@ int main(int argc, char *argv[])
   while ((i = getopt(argc, argv, "mM:s:r:tP:Buv")) != EOF)    /* get command args */
     switch (i)
       {
-      case 'B':                 /* Benchmark mode, set frameDelay to 0.0 */
-        frameDelay = 0.0;
+      case 'B':                 /* Benchmark mode, set recFrameDelay to 0.0 */
+        pbSpeed = PB_SPEED_INFINITE;
+        recFrameDelay = 0.0;
         break;
       case 'm':
         wantMetaList = TRUE;
@@ -285,7 +291,7 @@ int main(int argc, char *argv[])
         metaServer = optarg;
         break;
       case 's':                 /* [host[:port]] */
-	cInfo.remotehost = (Unsgn8 *)strdup(optarg);
+	cInfo.remotehost = strdup(optarg);
         if (!cInfo.remotehost)
           {
             printf("strdup failed\n");
@@ -313,7 +319,7 @@ int main(int argc, char *argv[])
         /* don't want to do this if we've already seen -P */
         if (Context.recmode != RECMODE_PLAYING)
           {
-            if (recordOpenOutput(optarg, FALSE))
+            if (recOpenOutput(optarg, FALSE))
               {			/* we are almost ready... */
                 Context.recmode = RECMODE_STARTING;
                 printf("Recording game to %s...\n", optarg);
@@ -332,7 +338,7 @@ int main(int argc, char *argv[])
         break;
 
       case 'P':
-        rfname = optarg;
+        recFilename = optarg;
         Context.recmode = RECMODE_PLAYING;
         break;
 
@@ -355,13 +361,13 @@ int main(int argc, char *argv[])
 
 
 #ifdef DEBUG_CONFIG
-  clog("%s@%d: main() Reading Configuration files.", __FILE__, __LINE__);
+  utLog("%s@%d: main() Reading Configuration files.", __FILE__, __LINE__);
 #endif
   
   if (GetConf(0) == ERR)	
     {
 #ifdef DEBUG_CONFIG
-      clog("%s@%d: main(): GetConf() returned ERR.", __FILE__, __LINE__);
+      utLog("%s@%d: main(): GetConf() returned ERR.", __FILE__, __LINE__);
 #endif
 	exit(1);
       }
@@ -374,12 +380,12 @@ int main(int argc, char *argv[])
         printf("-P option specified.  All other options ignored.\n");
 
       serveropt = wantMetaList = FALSE;
-      printf("Scanning file %s...\n", rfname);
-      if (!initReplay(rfname, &totElapsed))
+      printf("Scanning file %s...\n", recFilename);
+      if (!recInitReplay(recFilename, &recTotalElapsed))
         exit(1);
 
       /* now init for real */
-      if (!initReplay(rfname, NULL))
+      if (!recInitReplay(recFilename, NULL))
         exit(1);
 
       Context.unum = MSG_GOD;       /* stow user number */
@@ -391,6 +397,8 @@ int main(int argc, char *argv[])
 
       /* turn off annoying beeps */
       UserConf.DoAlarms = FALSE;
+      /* turn off hudInfo */
+      UserConf.hudInfo = FALSE;
     }
   
   if (serveropt && wantMetaList)
@@ -425,14 +433,14 @@ int main(int argc, char *argv[])
   map_lcommon();
 
 #ifdef DEBUG_FLOW
-  clog("%s@%d: main() starting conqinit().", __FILE__, __LINE__);
+  utLog("%s@%d: main() starting conqinit().", __FILE__, __LINE__);
 #endif
   
   conqinit();			/* machine dependent initialization */
-  iBufInit();
+  ibufInit();
   
 #ifdef DEBUG_FLOW
-  clog("%s@%d: main() starting cdinit().", __FILE__, __LINE__);
+  utLog("%s@%d: main() starting cdinit().", __FILE__, __LINE__);
 #endif
 
   cdinit();			/* set up display environment */
@@ -468,7 +476,7 @@ int main(int argc, char *argv[])
 
       if ((cInfo.remotehost = strdup(metaServerList[i].altaddr)) == NULL)
         {
-          clog("strdup(metaServerList[i]) failed");
+          utLog("strdup(metaServerList[i]) failed");
           cdend();
           return 1;
         }
@@ -489,13 +497,13 @@ int main(int argc, char *argv[])
   if (!clientHello(CLIENTNAME))
     {
       cdend();
-      clog("conquest: clientHello() failed\n");
+      utLog("conquest: clientHello() failed\n");
       printf("conquest: clientHello() failed, check log\n");
       exit(1);
     }
 
 #ifdef DEBUG_FLOW
-  clog("%s@%d: main() welcoming player.", __FILE__, __LINE__);
+  utLog("%s@%d: main() welcoming player.", __FILE__, __LINE__);
 #endif
   
   if ( welcome( &Context.unum ) )
@@ -507,7 +515,7 @@ int main(int argc, char *argv[])
   conqend();			/* machine dependent clean-up */
   
 #ifdef DEBUG_FLOW
-  clog("%s@%d: main() *EXITING*", __FILE__, __LINE__);
+  utLog("%s@%d: main() *EXITING*", __FILE__, __LINE__);
 #endif
   
   exit(0);
@@ -674,7 +682,7 @@ void command( int ch )
       if ( clbStillAlive( Context.snum ) )
         {
           stopTimer();
-          display( Context.snum, FALSE );
+          display( Context.snum );
           startTimer();
         }
       break;
@@ -686,7 +694,7 @@ void command( int ch )
       if ( clbStillAlive( Context.snum ) )
         {
           stopTimer();
-          display( Context.snum, FALSE );
+          display( Context.snum );
           startTimer();
         }
       break;
@@ -712,7 +720,7 @@ void command( int ch )
       else
 	SFSET(Context.snum, SHIP_F_MAP);
       stopTimer();
-      display( Context.snum, FALSE );
+      display( Context.snum );
       startTimer();
       break;
     case 'N':				/* change pseudonym */
@@ -727,7 +735,7 @@ void command( int ch )
       if ( clbStillAlive( Context.snum ) )
         {
           stopTimer();
-          display( Context.snum, FALSE );
+          display( Context.snum );
           startTimer();
         }
       break;
@@ -774,7 +782,7 @@ void command( int ch )
       if ( clbStillAlive( Context.snum ) )
         {
           stopTimer();
-          display( Context.snum, FALSE );
+          display( Context.snum );
           startTimer();
         }
       break;
@@ -786,7 +794,7 @@ void command( int ch )
       if ( clbStillAlive( Context.snum ) )
         {
           stopTimer();
-          display( Context.snum, FALSE );
+          display( Context.snum );
           startTimer();
         }
       break;
@@ -801,7 +809,7 @@ void command( int ch )
       if ( clbStillAlive( Context.snum ) )
         {
           stopTimer();
-          display( Context.snum, FALSE );
+          display( Context.snum );
           startTimer();
         }
       break;
@@ -811,13 +819,13 @@ void command( int ch )
     case '-':				/* shields down */
       doshields( Context.snum, FALSE );
       stopTimer();
-      display( Context.snum, FALSE );
+      display( Context.snum );
       startTimer();
       break;
     case '+':				/* shields up */
       doshields( Context.snum, TRUE );
       stopTimer();
-      display( Context.snum, FALSE );
+      display( Context.snum );
       startTimer();
       break;
     case '/':				/* player list */
@@ -828,7 +836,7 @@ void command( int ch )
       if ( clbStillAlive( Context.snum ) )
         {
           stopTimer();
-          display( Context.snum, FALSE );
+          display( Context.snum );
           startTimer();
         }
       break;
@@ -840,23 +848,23 @@ void command( int ch )
       if ( clbStillAlive( Context.snum ) )
         {
           stopTimer();
-          display( Context.snum, FALSE );
+          display( Context.snum );
           startTimer();
         }
-	display( Context.snum, FALSE );
+	display( Context.snum );
       break;
     case TERM_REDRAW:			/* clear and redisplay */
       stopTimer();
       cdredo();
       Context.redraw = TRUE;
-      display( Context.snum, FALSE );
+      display( Context.snum );
       startTimer();
       break;
       
-    case TERM_NORMAL:		/* Have [RETURN] act like 'I[RETURN]'  */
+    case TERM_NORMAL:		/* Have [ENTER] act like 'I[ENTER]'  */
     case KEY_ENTER:
     case '\n':
-      iBufPut("i\r");		/* (get last info) */
+      ibufPut("i\r");		/* (get last info) */
       break;
 
     case ' ':
@@ -864,12 +872,12 @@ void command( int ch )
       break;
 
     case TERM_EXTRA:		/* Have [TAB] act like 'i\t' */
-      iBufPut("i\t");		/* (get next last info) */
+      ibufPut("i\t");		/* (get next last info) */
       break;
       
     case TERM_RELOAD:		/* have server resend current universe */
       sendCommand(CPCMD_RELOAD, 0);
-      clog("client: sent CPCMD_RELOAD");
+      utLog("client: sent CPCMD_RELOAD");
       break;
       
     case -1:			/* really nothing, move along */
@@ -880,7 +888,7 @@ void command( int ch )
     label1:
       cdbeep();
 #ifdef DEBUG_IO
-      clog("command(): got 0%o, KEY_A1 =0%o", ch, KEY_A1);
+      utLog("command(): got 0%o, KEY_A1 =0%o", ch, KEY_A1);
 #endif
       mcuPutMsg( "Type h for help.", MSG_LIN2 );
     }
@@ -1005,7 +1013,7 @@ void dead( int snum, int leave )
   /* If something is wrong, don't do anything. */
   if ( snum < 1 || snum > MAXSHIPS )
     {
-      clog("dead: snum < 1 || snum > MAXSHIPS (%d)", snum);
+      utLog("dead: snum < 1 || snum > MAXSHIPS (%d)", snum);
       return;
     }
   
@@ -1071,7 +1079,7 @@ void dead( int snum, int leave )
 	  junk[0] = EOS;
       if ( kb > 0 && kb <= MAXSHIPS )
 	{
-	  appship( kb, cbuf );
+	  utAppendShip( kb, cbuf );
 	  if ( Ships[kb].status != SS_LIVE )
 	    appstr( ", who also died.", buf );
 	  else
@@ -1098,10 +1106,10 @@ void dead( int snum, int leave )
 	{
 	  /* We were unable to determine the cause of death. */
 	  buf[0] = EOS;
-	  appship( snum, buf );
+	  utAppendShip( snum, buf );
 	  sprintf(cbuf, "dead: %s was killed by %d.", buf, kb);
-	  cerror( cbuf );
-	  clog(cbuf);
+	  utError( cbuf );
+	  utLog(cbuf);
 	  
 	  cprintf(8,0,ALIGN_CENTER,"#%d#%s%s", 
 	  	RedLevelColor, ywkb, "nothing in particular.  (How strange...)");
@@ -1128,9 +1136,9 @@ void dead( int snum, int leave )
 	  else
 	    {
 	      if ( i < 100 )
-			appnum( i, junk );
+			utAppendNumWord( i, junk );
 	      else
-			appint( i, junk );
+			utAppendInt( i, junk );
 	      strcpy( cbuf, "armies" );
 	    }
 	  if ( i == 1 )
@@ -1190,7 +1198,7 @@ void dead( int snum, int leave )
 	  else
 	    cprintf( 14,0,ALIGN_CENTER,"#%d#%s", InfoColor,
 		   "You have chosen to NOT leave any last words:" );
-	  ch = mcuGetCX( "Press TAB to confirm:", 16, 0,
+	  ch = mcuGetCX( "Press [TAB] to confirm:", 16, 0,
 		     TERMS, cbuf, 10 );
 	}
       while ( ch != TERM_EXTRA ); /* until . while */
@@ -1239,7 +1247,7 @@ void doalloc( int snum )
 
     case TERM_NORMAL:
       i = 0;
-      safectoi( &alloc, cbuf, i );			/* ignore status */
+      utSafeCToI( &alloc, cbuf, i );			/* ignore status */
       if ( alloc != 0 )
 	{
 	  if ( alloc < 30 )
@@ -1276,7 +1284,7 @@ void doalloc( int snum )
 void doautopilot( int snum )
 {
   int ch; 
-  string conf="Press TAB to engage autopilot:";
+  string conf="Press [TAB] to engage autopilot:";
   
   cdclrl( MSG_LIN1, 2 );
   cbuf[0] = EOS;
@@ -1299,7 +1307,7 @@ void doautopilot( int snum )
       if ( ! iogtimed( &ch, 1.0 ) )
 	continue;		/* next . echo */
       Context.msgok = FALSE;
-      grand( &Context.msgrand );
+      utGrand( &Context.msgrand );
       switch ( ch )
 	{
 	case TERM_ABORT:
@@ -1308,7 +1316,7 @@ void doautopilot( int snum )
 	  cdredo();
 	  break;
 	default:
-	  mcuPutMsg( "Press ESCAPE to abort autopilot.", MSG_LIN1 );
+	  mcuPutMsg( "Press [ESC] to abort autopilot.", MSG_LIN1 );
 	  cdbeep();
 	  cdrefresh();
 	}
@@ -1516,14 +1524,14 @@ void dobeam( int snum )
     num = beamax;
   else
     {
-      delblanks( buf );
+      utDeleteBlanks( buf );
       if ( alldig( buf ) != TRUE )
 	{
 	  mcuPutMsg( abt, MSG_LIN1 );
 	  return;
 	}
       i = 0;
-      safectoi( &num, buf, i );			/* ignore status */
+      utSafeCToI( &num, buf, i );			/* ignore status */
       if ( num < 1 || num > beamax )
 	{
 	  mcuPutMsg( abt, MSG_LIN1 );
@@ -1611,7 +1619,7 @@ void dobomb( int snum )
       }
   
   /* Confirm. */
-  sprintf( cbuf, "Press TAB to bombard %s, %d armies:",
+  sprintf( cbuf, "Press [TAB] to bombard %s, %d armies:",
 	 Planets[pnum].name, Planets[pnum].armies );
   cdclrl( MSG_LIN1, 1 );
   cdclrl( MSG_LIN2, 1 );
@@ -1688,7 +1696,7 @@ void doburst( int snum )
 /*    docloak( snum ) */
 void docloak( int snum )
 {
-  string pmt="Press TAB to engage cloaking device: ";
+  string pmt="Press [TAB] to engage cloaking device: ";
   
   cdclrl( MSG_LIN1, 1 );
   cdclrl( MSG_LIN2, 1 );
@@ -1723,7 +1731,7 @@ void dorefit( int snum, int dodisplay )
   int oldstype = 0, stype = 0;
   string ntp="We must be orbiting a team owned planet to refit.";
   string nek="You must have at least one kill to refit.";
-  string conf="Press TAB to change, ENTER to accept: ";
+  string conf="Press [TAB] to change, [ENTER] to accept: ";
   string cararm="You cannot refit while carrying armies";
   
   cdclrl( MSG_LIN2, 1 );
@@ -1777,14 +1785,14 @@ void dorefit( int snum, int dodisplay )
     switch ( ch )
       {
       case TERM_EXTRA:
-	stype = modp1( stype + 1, MAXNUMSHIPTYPES );
+	stype = utModPlusOne( stype + 1, MAXNUMSHIPTYPES );
 	leave = FALSE;
 
 	if ( dodisplay )
 	  {
 	    /* Force an update. */
 	    stopTimer();
-	    display( snum, FALSE );
+	    display( snum );
 	    startTimer();
 	  }
 
@@ -1804,7 +1812,7 @@ void dorefit( int snum, int dodisplay )
 	  {
 	    /* Force an update. */
 	    stopTimer();
-	    display( snum, FALSE );		/* update the display */
+	    display( snum );		/* update the display */
 	    startTimer();
 	  }
 	
@@ -1830,8 +1838,8 @@ void dorefit( int snum, int dodisplay )
   mcuPutMsg( "Refitting ship...", MSG_LIN1 );
   sendCommand(CPCMD_REFIT, (Unsgn16)stype);
   cdrefresh();
-  grand( &entertime );
-  while ( dgrand( entertime, &now ) < REFIT_GRAND )
+  utGrand( &entertime );
+  while ( utDeltaGrand( entertime, &now ) < REFIT_GRAND )
     {
       /* See if we're still alive. */
       if ( ! clbStillAlive( snum ) )
@@ -1856,7 +1864,7 @@ void docoup( int snum )
 {
   int i, pnum;
   string nhp="We must be orbiting our home planet to attempt a coup.";
-  string conf="Press TAB to try it: ";
+  string conf="Press [TAB] to try it: ";
   
   cdclrl( MSG_LIN2, 1 );
   
@@ -1939,7 +1947,7 @@ void docourse( int snum )
 
   cbuf[0] = EOS;
   ch = cdgetx( "Come to course: ", MSG_LIN1, 1, TERMS, cbuf, MSGMAXLINE, TRUE );
-  delblanks( cbuf );
+  utDeleteBlanks( cbuf );
   if ( ch == TERM_ABORT || cbuf[0] == EOS )
     {
       cdclrl( MSG_LIN1, 1 );
@@ -1955,10 +1963,10 @@ void docourse( int snum )
       /* Raw angle. */
       cdclrl( MSG_LIN1, 1 );
       i = 0;
-      if ( safectoi( &j, cbuf, i ) )
+      if ( utSafeCToI( &j, cbuf, i ) )
 	{
 	  what = NEAR_DIRECTION;
-	  dir = (real)mod360( (real)( j ) );
+	  dir = (real)utMod360( (real)( j ) );
 	}
     }
   else if ( cbuf[0] == 's' && alldig( &cbuf[1] ) == TRUE )
@@ -1966,12 +1974,12 @@ void docourse( int snum )
       /* Ship. */
 
       i = 1;
-      if ( safectoi( &sorpnum, cbuf, i ) )
+      if ( utSafeCToI( &sorpnum, cbuf, i ) )
 	what = NEAR_SHIP;
     }
-  else if ( arrows( cbuf, &dir ) )
+  else if ( utArrowsToDir( cbuf, &dir ) )
     what = NEAR_DIRECTION;
-  else if ( special( cbuf, &i, &token, &count ) )
+  else if ( utIsSpecial( cbuf, &i, &token, &count ) )
     {
       if ( clbFindSpecial( snum, token, count, &sorpnum, &xsorpnum ) )
 	what = i;
@@ -2010,7 +2018,7 @@ void docourse( int snum )
       appx = Ships[sorpnum].x;
       appy = Ships[sorpnum].y;
 
-      dir = (real)angle( Ships[snum].x, Ships[snum].y, appx, appy );
+      dir = utAngle( Ships[snum].x, Ships[snum].y, appx, appy );
       
       /* Give info if he used TAB. */
       if ( ch == TERM_EXTRA )
@@ -2019,7 +2027,7 @@ void docourse( int snum )
 	cdclrl( MSG_LIN1, 1 );
       break;
     case NEAR_PLANET:
-      dir = angle( Ships[snum].x, Ships[snum].y, Planets[sorpnum].x, Planets[sorpnum].y );
+      dir = utAngle( Ships[snum].x, Ships[snum].y, Planets[sorpnum].x, Planets[sorpnum].y );
       if ( ch == TERM_EXTRA )
 	{
 	  newlock = -sorpnum;
@@ -2079,7 +2087,7 @@ void dodet( int snum )
 /*    dodistress( snum ) */
 void dodistress( int snum )
 {
-  string pmt="Press TAB to send an emergency distress call: ";
+  string pmt="Press [TAB] to send an emergency distress call: ";
   
   cdclrl( MSG_LIN1, 2 );
 
@@ -2211,7 +2219,7 @@ void dohelp( void )
   "^L", "refresh the screen");
   tlin++;
   cprintf(tlin,col,ALIGN_NONE,sfmt, 
-  "[RETURN]", "get last info");
+  "[ENTER]", "get last info");
   tlin++;
   cprintf(tlin,col,ALIGN_NONE,sfmt, "[TAB]", "get next last info");
   
@@ -2248,7 +2256,7 @@ void doinfo( int snum )
   extra = ( ch == TERM_EXTRA );
   
   /* Default to what we did last time. */
-  delblanks( cbuf );
+  utDeleteBlanks( cbuf );
   fold( cbuf );
   if ( cbuf[0] == EOS )
     {
@@ -2262,7 +2270,7 @@ void doinfo( int snum )
   else
     c_strcpy( cbuf, Context.lastinfostr );
   
-  if ( special( cbuf, &what, &token, &count ) )
+  if ( utIsSpecial( cbuf, &what, &token, &count ) )
     {
       if ( ! clbFindSpecial( snum, token, count, &sorpnum, &xsorpnum ) )
 	what = NEAR_NONE;
@@ -2284,22 +2292,22 @@ void doinfo( int snum )
   else if ( cbuf[0] == 's' && alldig( &cbuf[1] ) == TRUE )
     {
       i = 1;
-      safectoi( &j, cbuf, i );		/* ignore status */
+      utSafeCToI( &j, cbuf, i );		/* ignore status */
       mcuInfoShip( j, snum );
     }
   else if ( alldig( cbuf ) == TRUE )
     {
       i = 0;
-      safectoi( &j, cbuf, i );		/* ignore status */
+      utSafeCToI( &j, cbuf, i );		/* ignore status */
       mcuInfoShip( j, snum );
     }
   else if ( clbPlanetMatch( cbuf, &j, FALSE ) )
     mcuInfoPlanet( "", j, snum );
-  else if ( stmatch( cbuf, "time", FALSE ) )
+  else if ( utStringMatch( cbuf, "time", FALSE ) )
     {
       getnow( now, 0 );
       c_strcpy( "It's ", cbuf );
-      appnumtim( now, cbuf );
+      utAppendTime( now, cbuf );
       appchr( '.', cbuf );
       mcuPutMsg( cbuf, MSG_LIN1 );
       cdmove( MSG_LIN1, 1 );
@@ -2435,15 +2443,6 @@ void doReviewMsgs( int snum )
   int ch;
   int lstmsg;			/* saved last msg in case new ones come in */
   
-  if (RMsg_Line == MSG_LIN1)
-    {				/* if we don't have an extra msg line,
-				   then make sure new msgs don't come
-				   in while reviewing */
-      
-      Context.msgok = FALSE;		/* don't want to get msgs when reading
-				   old ones.  */
-    }
-
   lstmsg = Ships[snum].lastmsg;	/* don't want lstmsg changing while reading old ones. */
 
   if ( ! mcuReviewMsgs( snum, lstmsg ) )
@@ -2456,11 +2455,6 @@ void doReviewMsgs( int snum )
       cdclrl( MSG_LIN1, 2 );
     }
 
-  if (RMsg_Line == MSG_LIN1)
-    {
-      Context.msgok = TRUE;		
-    }
-
   return;
   
 }
@@ -2471,7 +2465,7 @@ void doReviewMsgs( int snum )
 /*    doselfdest */
 void doselfdest(int snum)
 {
-  string pmt="Press TAB to initiate self-destruct sequence: ";
+  string pmt="Press [TAB] to initiate self-destruct sequence: ";
   
   cdclrl( MSG_LIN1, 2 );
 
@@ -2513,7 +2507,7 @@ void doselfdest(int snum)
 	    }
 	  else
 	    {
-	      mcuPutMsg( "Press ESCAPE to abort self destruct.", MSG_LIN1 );
+	      mcuPutMsg( "Press [ESC] to abort self destruct.", MSG_LIN1 );
 	      cdbeep();
 	      cdrefresh();
 	    }
@@ -2640,7 +2634,7 @@ void dotow( int snum )
   if ( Ships[snum].towedby != 0 )
     {
       c_strcpy( "But we are being towed by ", cbuf );
-      appship( Ships[snum].towedby, cbuf );
+      utAppendShip( Ships[snum].towedby, cbuf );
       appchr( '!', cbuf );
       mcuPutMsg( cbuf, MSG_LIN2 );
       return;
@@ -2648,7 +2642,7 @@ void dotow( int snum )
   if ( Ships[snum].towing != 0 )
     {
       c_strcpy( "But we're already towing ", cbuf );
-      appship( Ships[snum].towing, cbuf );
+      utAppendShip( Ships[snum].towing, cbuf );
       appchr( '.', cbuf );
       mcuPutMsg( cbuf, MSG_LIN2 );
       return;
@@ -2661,7 +2655,7 @@ void dotow( int snum )
     return;
   
   i = 0;
-  safectoi( &other, cbuf, i );		/* ignore status */
+  utSafeCToI( &other, cbuf, i );		/* ignore status */
 
   sendCommand(CPCMD_TOW, (Unsgn16)other);
 
@@ -2736,7 +2730,7 @@ void menu(void)
   int pkttype;
   struct timeval timeout;
   fd_set readfds;
-  Unsgn8 buf[PKT_MAXSIZE];
+  char buf[PKT_MAXSIZE];
   spAck_t *sack;
   char *if1="Suddenly  a  sinister,  wraithlike  figure appears before you";
   char *if2="seeming to float in the air.  In a low,  sorrowful  voice  he";
@@ -2773,10 +2767,10 @@ void menu(void)
 
   /* now look for our ship packet before we get started.  It should be a
      full SP_SHIP packet for this first time */
-  if (waitForPacket(PKT_FROMSERVER, sockl, SP_SHIP, buf, PKT_MAXSIZE,
+  if (pktWaitForPacket(PKT_FROMSERVER, sockl, SP_SHIP, buf, PKT_MAXSIZE,
 		    60, NULL) <= 0)
     {
-      clog("conquest:menu: didn't get initial SP_SHIP");
+      utLog("conquest:menu: didn't get initial SP_SHIP");
       return;
     }
   else
@@ -2788,7 +2782,7 @@ void menu(void)
 
       lose = FALSE;
 
-      while ((pkttype = waitForPacket(PKT_FROMSERVER, sockl, PKT_ANYPKT,
+      while ((pkttype = pktWaitForPacket(PKT_FROMSERVER, sockl, PKT_ANYPKT,
 				      buf, PKT_MAXSIZE, 0, NULL)) > 0)
 	{			/* proc packets while we get them */
 	  switch (pkttype)
@@ -2798,7 +2792,7 @@ void menu(void)
 	      if (sack->code == PERR_LOSE)
 		lose = TRUE;
 	      else
-		clog("conquest:menu: got unexp ack code %d", sack->code);
+		utLog("conquest:menu: got unexp ack code %d", sack->code);
 
 	      break;
 
@@ -2810,7 +2804,7 @@ void menu(void)
 	      
       if (pkttype < 0)		/* some error */
 	{
-	  clog("conquest:menu:waiForPacket returned %d", pkttype);
+	  utLog("conquest:menu:waiForPacket returned %d", pkttype);
 	  Ships[Context.snum].status = SS_OFF;
 	  return;
 	}
@@ -2892,9 +2886,9 @@ void menu(void)
       
       FD_ZERO(&readfds);
       FD_SET(cInfo.sock, &readfds);
-      FD_SET(PollInputfd, &readfds);
+      FD_SET(iolbStdinFD, &readfds);
 
-      if ((rv=select((max(cInfo.sock, PollInputfd) + 1), &readfds, NULL, 
+      if ((rv=select((max(cInfo.sock, iolbStdinFD) + 1), &readfds, NULL, 
                      NULL, &timeout)) > 0)
         {                           /* we have activity */
           if (FD_ISSET(cInfo.sock, &readfds))
@@ -2902,7 +2896,7 @@ void menu(void)
               continue;            /* go process them at the top */
             }
 
-          if (FD_ISSET(PollInputfd, &readfds))
+          if (FD_ISSET(iolbStdinFD, &readfds))
             {          /* got a char */
               ch = iogchar();
 
@@ -2988,7 +2982,7 @@ void menu(void)
                          overwritten on the next ship update.  Improves perceived
                          response time. */
                       Ships[Context.snum].team = 
-                        modp1( Ships[Context.snum].team+1, NUMPLAYERTEAMS );
+                        utModPlusOne( Ships[Context.snum].team+1, NUMPLAYERTEAMS );
                       Ships[Context.snum].shiptype = 
                         Teams[Ships[Context.snum].team].shiptype;
                       Users[Context.unum].team = Ships[Context.snum].team;
@@ -3044,7 +3038,7 @@ void menu(void)
 
       if (rv < 0 && errno != EINTR)
         {
-          clog("conquest:menu: select returned %d, %s\n",
+          utLog("conquest:menu: select returned %d, %s\n",
                rv, strerror(errno));
           Context.leave = TRUE;
         }
@@ -3075,7 +3069,7 @@ int newship( int unum, int *snum )
   spAck_t *sack;
   spClientStat_t *scstat;
   int pkttype;
-  Unsgn8 buf[PKT_MAXSIZE];
+  char buf[PKT_MAXSIZE];
   int sockl[2] = {cInfo.sock, cInfo.usock};
   /* here we will wait for ack's or a clientstat pkt. Acks indicate an
      error.  If the clientstat pkt's esystem is !0, we need to prompt
@@ -3085,10 +3079,10 @@ int newship( int unum, int *snum )
 
   while (TRUE)
     {
-      if ((pkttype = waitForPacket(PKT_FROMSERVER, sockl, PKT_ANYPKT,
+      if ((pkttype = pktWaitForPacket(PKT_FROMSERVER, sockl, PKT_ANYPKT,
 				   buf, PKT_MAXSIZE, 60, NULL)) < 0)
 	{
-	  clog("conquest:newship: waitforpacket returned %d", pkttype);
+	  utLog("conquest:newship: waitforpacket returned %d", pkttype);
 	  return FALSE;
 	}
       
@@ -3124,7 +3118,7 @@ int newship( int unum, int *snum )
 	      i = i + 1;
 	      c_strcpy( "You are only allowed to fly ", cbuf );
 	      j = Users[unum].multiple;
-	      appint( j, cbuf );
+	      utAppendInt( j, cbuf );
 	      appstr( " ship", cbuf );
 	      if ( j != 1 )
 		appchr( 's', cbuf );
@@ -3137,7 +3131,7 @@ int newship( int unum, int *snum )
 	      break;
 	      
 	    default:
-	      clog("newship: unexpected ack code %d",
+	      utLog("newship: unexpected ack code %d",
 		   sack->code);
 	      break;
 	    }
@@ -3164,7 +3158,7 @@ int newship( int unum, int *snum )
             }
           else
             {
-              clog("newship: invalid CLIENTSTAT\n");
+              utLog("newship: invalid CLIENTSTAT\n");
               return FALSE;       /* don't want to hang if a bad pkt */
             }
 	  
@@ -3202,14 +3196,14 @@ int play()
     Context.entship = TRUE;
   
   Ships[Context.snum].sdfuse = 0;	/* zero self destruct fuse */
-  grand( &Context.msgrand );		/* initialize message timer */
+  utGrand( &Context.msgrand );		/* initialize message timer */
   Context.leave = FALSE;		/* assume we won't want to bail */
   Context.redraw = TRUE;		/* want redraw first time */
   Context.msgok = TRUE;		/* ok to get messages */
   cdclear();			/* clear the display */
   cdredo();			/*  (quickly) */
   stopTimer();			/* stop the display interrupt */
-  display( Context.snum, FALSE );	/* update the screen manually */
+  display( Context.snum );	/* update the screen manually */
   Context.display = TRUE;		/* ok to display */
   clientFlags = 0;
   startTimer();			/* setup for next second */
@@ -3218,7 +3212,7 @@ int play()
   /* start recording if neccessary */
   if (Context.recmode == RECMODE_STARTING)
     {
-      if (recordInitOutput(Context.unum, getnow(NULL, 0), Context.snum, 
+      if (recInitOutput(Context.unum, getnow(NULL, 0), Context.snum, 
                            FALSE))
         {
           Context.recmode = RECMODE_ON;
@@ -3243,9 +3237,9 @@ int play()
 
       FD_ZERO(&readfds);
       FD_SET(cInfo.sock, &readfds);
-      FD_SET(PollInputfd, &readfds);
+      FD_SET(iolbStdinFD, &readfds);
 
-      if ((rv=select((max(cInfo.sock, PollInputfd) + 1), &readfds, NULL, 
+      if ((rv=select((max(cInfo.sock, iolbStdinFD) + 1), &readfds, NULL, 
                      NULL, &timeout)) > 0)
         {                       /* we have activity */
           if (FD_ISSET(cInfo.sock,&readfds))
@@ -3258,20 +3252,18 @@ int play()
 
           /* Get a char */
 
-          if (FD_ISSET(PollInputfd, &readfds))
+          if (FD_ISSET(iolbStdinFD, &readfds))
             {
               ch = iogchar();
               /* only process commands if we are live (the server will ignore
                  them anyway) */
               if (Ships[Context.snum].status == SS_LIVE)
                 {
-                  if (RMsg_Line == MSG_LIN1)
-                    Context.msgok = FALSE;      /* off if we  have no msg line */
-                  if (DoMacro(((ch - KEY_F(0)) - 1)) == TRUE)
+                  if (ibufExpandMacro(((ch - KEY_F(0)) - 1)) == TRUE)
                     {
-                      while (iBufCount())
+                      while (ibufCount())
                         {
-                          ch = iBufGetCh();
+                          ch = ibufGetc();
                           command( ch );
                         }
                     }
@@ -3280,7 +3272,7 @@ int play()
                       do 
                         {
                           command( ch );
-                        } while (iBufCount() && (ch = iBufGetCh()));
+                        } while (ibufCount() && (ch = ibufGetc()));
                     }
                 }
             }
@@ -3289,7 +3281,7 @@ int play()
 
       if (rv < 0 && errno != EINTR)
         {
-          clog("conquest:play: select returned %d, %s\n",
+          utLog("conquest:play: select returned %d, %s\n",
                rv, strerror(errno));
           Context.display = FALSE;
           return FALSE;
@@ -3334,9 +3326,9 @@ int welcome( int *unum )
   char * starship_str=" starship.";
   char * prepare_str="Prepare to be beamed aboard...";
   spClientStat_t *scstat = NULL;
-  spAck_t *sack = NULL;
+  spAck_t sack = {};
   int pkttype;
-  Unsgn8 buf[PKT_MAXSIZE];
+  char buf[PKT_MAXSIZE];
   int sockl[2] = {cInfo.sock, cInfo.usock};
   int done = FALSE;
   
@@ -3344,7 +3336,7 @@ int welcome( int *unum )
 
   if (!Logon(name))
     {
-      clog("conquest: Logon failed.");
+      utLog("conquest: Logon failed.");
       return FALSE;
     }
 
@@ -3352,9 +3344,9 @@ int welcome( int *unum )
     {
       /* now look for SP_CLIENTSTAT or SP_ACK */
       if ((pkttype = 
-           readPacket(PKT_FROMSERVER, sockl, buf, PKT_MAXSIZE, 60)) <= 0)
+           pktRead(PKT_FROMSERVER, sockl, buf, PKT_MAXSIZE, 60)) <= 0)
         {
-          clog("welcome: read SP_CLIENTSTAT or SP_ACK failed: %d\n", pkttype);
+          utLog("welcome: read SP_CLIENTSTAT or SP_ACK failed: %d\n", pkttype);
           return FALSE;
         }
       
@@ -3370,17 +3362,18 @@ int welcome( int *unum )
             }
           else
             {
-              clog("welcome: invalid CLIENTSTAT\n");
+              utLog("welcome: invalid CLIENTSTAT\n");
               return FALSE;
             }
 
           break;
         case SP_ACK:
-          sack = (spAck_t *)buf;
+          /* copy it */
+          sack = *((spAck_t *)buf);
           done = TRUE;
           break;
         default:
-          clog("welcome: got unexpected packet type %d. Ignoring.", 
+          utLog("welcome: got unexpected packet type %d. Ignoring.", 
                pkttype);
           done = FALSE;         /* redundant, but it gets the point across */
           break;
@@ -3404,7 +3397,7 @@ int welcome( int *unum )
 	}
       team = scstat->team;
       cbuf[0] = EOS;
-      apptitle( team, cbuf );
+      utAppendTitle( team, cbuf );
       appchr( ' ', cbuf );
       i = strlen( cbuf );
       appstr( name, cbuf );
@@ -3430,7 +3423,7 @@ int welcome( int *unum )
 
   if (pkttype == SP_ACK)	/* some problem was detected */
     {
-      switch (sack->code)
+      switch (sack.code)
 	{
 	case PERR_CLOSED:
 	  cdclear();
@@ -3468,7 +3461,7 @@ int welcome( int *unum )
 	  break;
 
 	default:
-	  clog("welcome: unexpected ACK code %d\n", sack->code);
+	  utLog("welcome: unexpected ACK code %d\n", sack.code);
 	  return FALSE;
 	  break;
 
@@ -3481,10 +3474,10 @@ int welcome( int *unum )
      for a user packet for this user. */
       
 
-  if (waitForPacket(PKT_FROMSERVER, sockl, SP_USER, buf, PKT_MAXSIZE,
+  if (pktWaitForPacket(PKT_FROMSERVER, sockl, SP_USER, buf, PKT_MAXSIZE,
 		    60, NULL) <= 0)
     {
-      clog("conquest:welcome: waitforpacket SP_USER returned error");
+      utLog("conquest:welcome: waitforpacket SP_USER returned error");
       return FALSE;
     }
   else
@@ -3498,7 +3491,7 @@ int welcome( int *unum )
 void catchSignals(void)
 {
 #ifdef DEBUG_SIG
-  clog("catchSignals() ENABLED");
+  utLog("catchSignals() ENABLED");
 #endif
   
   signal(SIGHUP, (void (*)(int))handleSignal);
@@ -3515,7 +3508,7 @@ void handleSignal(int sig)
 {
   
 #ifdef DEBUG_SIG
-  clog("handleSignal() got SIG %d", sig);
+  utLog("handleSignal() got SIG %d", sig);
 #endif
   
   switch(sig)
@@ -3551,9 +3544,8 @@ void astservice(int sig)
 {
   int now;
   int readone;
-  static int RMsggrand = 0;
   int difftime;
-  Unsgn8 buf[PKT_MAXSIZE];
+  char buf[PKT_MAXSIZE];
   int sockl[2] = {cInfo.sock, cInfo.usock};
   static Unsgn32 iterstart = 0;
   Unsgn32 iternow = clbGetMillis();
@@ -3566,7 +3558,7 @@ void astservice(int sig)
      doesn't stop when executing various commands */
 
 
-  while (readPacket(PKT_FROMSERVER, sockl,
+  while (pktRead(PKT_FROMSERVER, sockl,
 		    buf, PKT_MAXSIZE, 0) > 0)
     processPacket(buf); /* process them */
 
@@ -3576,7 +3568,7 @@ void astservice(int sig)
       clbPlanetDrive(tdelta / 1000.0);
       clbTorpDrive(tdelta / 1000.0);
       iterstart = iternow;
-      recordGenTorpLoc();
+      recGenTorpLoc();
     }
 
   /* Don't do anything if we're not supposed to. */
@@ -3600,20 +3592,13 @@ void astservice(int sig)
   readone = FALSE;
   if ( Context.msgok )
     {
-      if (RMsg_Line != MSG_LIN1)
-	{			/* we have line 25 for msgs */
-	  difftime = dgrand( RMsggrand, &now );
-	}
-      else
-	{
-	  difftime = dgrand( Context.msgrand, &now );
-	}
+      difftime = utDeltaGrand( Context.msgrand, &now );
 
       if ( difftime >= NEWMSG_GRAND )
-	if ( getamsg( Context.snum, &Ships[Context.snum].lastmsg ) )
+	if ( utGetMsg( Context.snum, &Ships[Context.snum].lastmsg ) )
 	  {
 	    if (mcuReadMsg( Context.snum, Ships[Context.snum].lastmsg, 
-			 RMsg_Line ) == TRUE)
+			 MSG_MSG ) == TRUE)
 	      {
 		if (Msgs[Ships[Context.snum].lastmsg].msgfrom != 
 		    Context.snum)
@@ -3622,22 +3607,15 @@ void astservice(int sig)
 		/* set both timers, regardless of which
 		   one we're actally concerned with */
 		Context.msgrand = now;
-		RMsggrand = now;
 		readone = TRUE;
 	      }
 	  }
     }
 
   /* Perform one ship display update. */
-  display( Context.snum, FALSE );
+  display( Context.snum );
 
-  recordUpdateFrame();          /* update recording */
-  
-  /* Un-read the message if there's a chance it got garbaged. */
-  if ( readone )
-    if (RMsg_Line == MSG_LIN1)	/* we don't have an extra msg line */
-      if ( iochav() )
-	Ships[Context.snum].lastmsg = modp1( Ships[Context.snum].lastmsg - 1, MAXMESSAGES );
+  recUpdateFrame();          /* update recording */
   
   /* Schedule for next time. */
   startTimer();
@@ -3699,7 +3677,7 @@ void startTimer(void)
 
   if (sigaction(SIGALRM, &Sig, NULL) == -1)
     {
-      clog("startTimer():sigaction(): %s\n", strerror(errno));
+      utLog("startTimer():sigaction(): %s\n", strerror(errno));
       exit(errno);
     }
   
@@ -3741,7 +3719,7 @@ void startTimer(void)
 void conqend(void)
 {
   sendCommand(CPCMD_DISCONNECT, 0); /* tell the server */
-  recordCloseOutput();
+  recCloseOutput();
 
   return;
   
