@@ -4,18 +4,21 @@
  *
  * conquestd - the Conquest server/client driver
  *
- * $Id: conquestd.c 711 2007-07-16 18:37:32Z jon $
+ * $Id: conquestd.c 773 2008-09-01 17:13:51Z jon13 $
  *
  * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
 
 
-#define NOEXTERN
 
 #include "conqdef.h"
 #include "conqcom.h"
 #include "conqlb.h"
+#include "conqutil.h"
+
+#define NOEXTERN_CONTEXT
 #include "context.h"
+
 #include "conf.h"
 #include "global.h"
 #include "color.h"
@@ -27,9 +30,8 @@
 #include "packet.h"
 #include "udp.h"
 
-#define SERVER_NOEXTERN
+#define NOEXTERN_SERVER
 #include "server.h"
-#undef SERVER_NOEXTERN
 #include "serverpkt.h"
 
 #include "servauth.h"
@@ -81,6 +83,7 @@ void printUsage()
   printf("   -M metaserver specify an alternate metaserver to contact\n");
   printf("   -N myname     explicitly specify server name 'myname' to metaserver\n");
   printf("   -u user       run as user 'user'.\n");
+  printf("   -v            be more verbose.\n");
   return;
 }
 
@@ -94,7 +97,7 @@ int getHostname(int sock, char *buf, int buflen)
   len = sizeof(struct sockaddr_in);
   if (getpeername(sock, (struct sockaddr *) &addr, &len) < 0)
     {
-      clog("getpeername failed: %s\n", strerror(errno));
+      utLog("getpeername failed: %s\n", strerror(errno));
       return FALSE;
     }
   else
@@ -121,7 +124,8 @@ int getHostname(int sock, char *buf, int buflen)
 void checkMaster(void)
 {
   int s,t;			/* socket descriptor */
-  int i,rv;			/* general purpose integer */
+  int rv;			/* general purpose integer */
+  socklen_t sockln;
   struct sockaddr_in sa, isa;	/* internet socket addr. structure */
   struct hostent *hp;		/* result of host name lookup */
   struct timeval tv;
@@ -138,7 +142,7 @@ void checkMaster(void)
       ConqInfo->conqservPID = getpid();
       PVUNLOCK(&ConqInfo->lockword);
       sInfo.isMaster = TRUE;
-      clog("NET: master server listening on port %d\n", listenPort);
+      utLog("NET: master server listening on port %d\n", listenPort);
     }
 
   /* get our own host information */
@@ -148,7 +152,7 @@ void checkMaster(void)
 
   if ((hp = gethostbyname(sInfo.localhost)) == NULL) 
     {
-      clog("NET: gethostbyname() failed: %s", strerror(errno));
+      utLog("NET: gethostbyname() failed: %s", strerror(errno));
       exit (1);
     }
   
@@ -164,7 +168,7 @@ void checkMaster(void)
   /* allocate an open socket for incoming connections */
   if (( s = socket(hp->h_addrtype, SOCK_STREAM, 0)) < 0) 
     {
-      clog("NET: socket() failed: %s", strerror(errno));
+      utLog("NET: socket() failed: %s", strerror(errno));
       exit(1);
     }
   
@@ -173,7 +177,7 @@ void checkMaster(void)
   if (setsockopt(s, SOL_SOCKET, SO_REUSEPORT,
                  (SSOType)&opt, sizeof(opt)) < 0) 
     {
-      clog("NET: setsockopt SO_REUSEPORT: %s", strerror(errno));
+      utLog("NET: setsockopt SO_REUSEPORT: %s", strerror(errno));
     }
 
 #endif 
@@ -183,7 +187,7 @@ void checkMaster(void)
   if (setsockopt(s, SOL_SOCKET, SO_REUSEADDR,
                  (SSOType)&opt, sizeof(opt)) < 0) 
     {
-      clog("NET: setsockopt SO_REUSEADDR: %s", 
+      utLog("NET: setsockopt SO_REUSEADDR: %s", 
            strerror(errno));
     }
 #endif
@@ -193,7 +197,7 @@ void checkMaster(void)
    */
   if ( bind( s, (struct sockaddr *)&sa, sizeof ( sa )) < 0 ) 
     {
-      clog("NET: bind() failed: %s", strerror(errno));
+      utLog("NET: bind() failed: %s", strerror(errno));
       exit(1);
     }
   
@@ -219,17 +223,17 @@ void checkMaster(void)
 
       if ((rv = select(s+1, &readfds, NULL, NULL, &tv)) < 0)
         {
-          clog("checkMaster: select failed: %s", strerror(errno));
+          utLog("checkMaster: select failed: %s", strerror(errno));
           exit(1);
         }
 
       if (FD_ISSET(s, &readfds))
         {        
 
-          i = sizeof (isa);
+          sockln = (socklen_t)sizeof (isa);
       
           /* hang in accept() while waiting for new connections */
-          if ((t = accept(s, (struct sockaddr *)&isa, &i )) < 0) 
+          if ((t = accept(s, (struct sockaddr *)&isa, &sockln )) < 0) 
             {
               perror ( "accept" );
               exit (1);
@@ -237,7 +241,7 @@ void checkMaster(void)
       
           if ( fork() == 0 ) 
             {			/* child - client driver */
-              clog("NET: forked client driver, pid = %d", getpid());
+              utLog("NET: forked client driver, pid = %d", getpid());
               sInfo.sock = t;
 
               memset(sInfo.remotehost, 0, MAXHOSTNAME);
@@ -245,7 +249,7 @@ void checkMaster(void)
               if (!tcpwCheckHostAccess(TCPW_DAEMON_CONQUESTD, 
                                        sInfo.remotehost))
                 {
-                  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_FATAL, PERR_UNSPEC,
+                  pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_FATAL, PERR_UNSPEC,
                           "Access Denied: You are not allowed to connect to this server.");
                   close(t);
                   exit(1);
@@ -283,7 +287,7 @@ int main(int argc, char *argv[])
   sInfo.isMaster = FALSE;
   sInfo.isLoggedIn = FALSE;
 
-  while ((i = getopt(argc, argv, "dlp:u:mM:N:")) != EOF)    /* get command args */
+  while ((i = getopt(argc, argv, "dlp:u:mM:N:v")) != EOF)    /* get command args */
     switch (i)
       {
       case 'd':
@@ -314,6 +318,10 @@ int main(int argc, char *argv[])
         myServerName = optarg;
         break;
 
+      case 'v':
+        cqDebug++;
+        break;
+
       default:
 	printUsage();
 	exit(1);
@@ -350,24 +358,24 @@ int main(int argc, char *argv[])
           exit(1);
         }        
       else
-        clog("INFO: running as user '%s', uid %d.", myuidname, myuid); 
+        utLog("INFO: running as user '%s', uid %d.", myuidname, myuid); 
     }
 
   
 #ifdef DEBUG_CONFIG
-  clog("%s@%d: main() Reading Configuration files.", __FILE__, __LINE__);
+  utLog("%s@%d: main() Reading Configuration files.", __FILE__, __LINE__);
 #endif
   
   if (GetSysConf(FALSE) == ERR)
     {
 #ifdef DEBUG_CONFIG
-      clog("%s@%d: main(): GetSysConf() returned ERR.", __FILE__, __LINE__);
+      utLog("%s@%d: main(): GetSysConf() returned ERR.", __FILE__, __LINE__);
 #endif
     }
 
   if (setgid(ConquestGID) == -1)
     {
-      clog("conquest: setgid(%d): %s",
+      utLog("conquest: setgid(%d): %s",
            ConquestGID,
            strerror(errno));
       fprintf(stderr, "conquest: setgid(): failed\n");
@@ -375,11 +383,11 @@ int main(int argc, char *argv[])
     }
   
 #ifdef DEBUG_FLOW
-  clog("%s@%d: main() *STARTING*", __FILE__, __LINE__);
+  utLog("%s@%d: main() *STARTING*", __FILE__, __LINE__);
 #endif
   
 #ifdef DEBUG_FLOW
-  clog("%s@%d: main() getting semephores - semInit()", __FILE__, __LINE__);
+  utLog("%s@%d: main() getting semephores - semInit()", __FILE__, __LINE__);
 #endif
   
   if (semInit() == ERR)
@@ -389,7 +397,7 @@ int main(int argc, char *argv[])
     }
   
 #ifdef DEBUG_FLOW
-  clog("%s@%d: main() mapping common block.", __FILE__, __LINE__);
+  utLog("%s@%d: main() mapping common block.", __FILE__, __LINE__);
 #endif
 
   map_common();
@@ -403,7 +411,7 @@ int main(int argc, char *argv[])
 
   
 #ifdef DEBUG_FLOW
-  clog("%s@%d: main() starting conqinit().", __FILE__, __LINE__);
+  utLog("%s@%d: main() starting conqinit().", __FILE__, __LINE__);
 #endif
   
   Context.maxlin = 0;		/* not used here */
@@ -420,7 +428,7 @@ int main(int argc, char *argv[])
   if (dodaemon)
     {
       int cpid;
-      clog("INFO: becoming daemon");
+      utLog("INFO: becoming daemon");
       chdir("/");
 
       cpid = fork();
@@ -476,7 +484,7 @@ int main(int argc, char *argv[])
   if (GetSysConf(FALSE) == ERR)
     {
 #ifdef DEBUG_CONFIG
-      clog("%s@%d: main(): GetSysConf() returned ERR.", __FILE__, __LINE__);
+      utLog("%s@%d: main(): GetSysConf() returned ERR.", __FILE__, __LINE__);
 #endif
     }
 
@@ -488,16 +496,16 @@ int main(int argc, char *argv[])
 
   rndini( 0, 0 );		/* initialize random numbers */
   
-  clog("CONNECT: client %s", sInfo.remotehost);
+  utLog("CONNECT: client %s", sInfo.remotehost);
 
   /* now we need to negotiate. */
   if (!hello())
     {
-      clog("conquestd: hello() failed");
+      utLog("conquestd: hello() failed");
       exit(1);
     }
 
-  clog("CONNECT: client %s SUCCESS.", sInfo.remotehost);
+  utLog("CONNECT: client %s SUCCESS.", sInfo.remotehost);
 
   Context.recmode = RECMODE_OFF; /* always */
 
@@ -512,7 +520,7 @@ int main(int argc, char *argv[])
   conqend();			/* machine dependent clean-up */
   
 #ifdef DEBUG_FLOW
-  clog("%s@%d: main() *EXITING*", __FILE__, __LINE__);
+  utLog("%s@%d: main() *EXITING*", __FILE__, __LINE__);
 #endif
   
   exit(0);
@@ -535,7 +543,7 @@ void updateProc(void)
     Unsgn32 millis = clbGetMillis();
     
     if ((millis - lastms) > (int)((1.0 / (real)Context.updsec) * 1000.0))
-      clog("millisdiff = %u(%d)", (millis - lastms), Context.updsec);
+      utLog("millisdiff = %u(%d)", (millis - lastms), Context.updsec);
     lastms = millis;
   }
 #endif
@@ -543,10 +551,10 @@ void updateProc(void)
   /* update client view of the universe */
   updateClient(FALSE);
 
-  recordUpdateFrame();
+  recUpdateFrame();
 
   /* check for and send any new messages */
-  if ( getamsg( Context.snum, &Ships[Context.snum].lastmsg ) )
+  if ( utGetMsg( Context.snum, &Ships[Context.snum].lastmsg ) )
     sendMessage(&(Msgs[Ships[Context.snum].lastmsg]));
 
   /* Schedule for next time. */
@@ -570,7 +578,7 @@ void startUpdate(void)
 
   if (sigaction(SIGALRM, &Sig, NULL) == -1)
     {
-      clog("startUpdater():sigaction(): %s\n", strerror(errno));
+      utLog("startUpdater():sigaction(): %s\n", strerror(errno));
       exit(errno);
     }
   
@@ -639,7 +647,7 @@ int capentry( int snum, int *system )
   int owned[NUMPLAYERTEAMS]; 
   int pkttype;
   cpCommand_t *ccmd;
-  Unsgn8 buf[PKT_MAXSIZE];
+  char buf[PKT_MAXSIZE];
   Unsgn8 esystem = 0;
   int sockl[2] = {sInfo.sock, sInfo.usock};
   
@@ -692,10 +700,10 @@ int capentry( int snum, int *system )
       /* now we wait for another ENTER command packet with it's detail member
 	 indicating the desired system. */
 
-      if ((pkttype = waitForPacket(PKT_FROMCLIENT, sockl, CP_COMMAND,
+      if ((pkttype = pktWaitForPacket(PKT_FROMCLIENT, sockl, CP_COMMAND,
 				   buf, PKT_MAXSIZE, 1, NULL)) < 0)
         {
-	  clog("conquestd:capentry: waitforpacket returned %d", pkttype); 
+	  utLog("conquestd:capentry: waitforpacket returned %d", pkttype); 
           return FALSE;
         }
 
@@ -706,7 +714,7 @@ int capentry( int snum, int *system )
       ccmd = (cpCommand_t *)buf;
       ccmd->detail = ntohs(ccmd->detail);
 
-      clog("conquestd: capentry: got CP_COMMAND, detail =0x%x", 
+      utLog("conquestd: capentry: got CP_COMMAND, detail =0x%x", 
 	   ccmd->detail);
 
       if (ccmd->cmd != CPCMD_ENTER)
@@ -761,13 +769,13 @@ void dead( int snum, int leave )
   kb = Ships[snum].killedby;
   
   /* Delay while our torps are exploding. */
-  grand( &entertime );
+  utGrand( &entertime );
   i = 0;
-  while ( dgrand( entertime, &now ) < TORPEDOWAIT_GRAND )
+  while ( utDeltaGrand( entertime, &now ) < TORPEDOWAIT_GRAND )
     {
       updateClient(FALSE);
       i = 0;
-      for ( j = 0; j < MAXTORPS; j = j + 1 )
+      for ( j = 0; j < MAXTORPS; j++ )
 	if ( Ships[snum].torps[j].status == TS_DETONATE )
 	  i = i + 1;
       if ( i <= 0 )
@@ -779,14 +787,14 @@ void dead( int snum, int leave )
   if ( i > 0 )
     {
       buf[0] = EOS;
-      appship( snum, buf );
-      clog("INFO: dead: %s, detonating torp count is %d.",
+      utAppendShip( snum, buf );
+      utLog("INFO: dead: %s, detonating torp count is %d.",
 	   buf, i);
     }
   
   buf[0] = EOS;
-  appship( snum, buf );
-  clog("INFO: dead: %s was killed by %d.", buf, kb);
+  utAppendShip( snum, buf );
+  utLog("INFO: dead: %s was killed by %d.", buf, kb);
   
   updateClient(FALSE);
   for ( i=0; i<10 && Ships[snum].status == SS_DYING; i++ )
@@ -816,13 +824,13 @@ void dead( int snum, int leave )
           ConqInfo->lastwords[MAXLASTWORDS - 1] = 0;
         }
 
-      clog("conquestd: dead(): sendClientStat failed, fl = 0x%0x\n",
+      utLog("conquestd: dead(): sendClientStat failed, fl = 0x%0x\n",
            flags);
 
       return;
     }
 
-  clog("INFO: dead(): sent sendClientStat, fl = 0x%0x",
+  utLog("INFO: dead(): sent sendClientStat, fl = 0x%0x",
        flags);
 
   /* fix things up */
@@ -836,7 +844,7 @@ void dead( int snum, int leave )
   /* if conquered, wait for the cpMessage_t */
   if (kb == KB_CONQUER)
     {
-      if (waitForPacket(PKT_FROMCLIENT, sockl, CP_MESSAGE, 
+      if (pktWaitForPacket(PKT_FROMCLIENT, sockl, CP_MESSAGE, 
 			buf, PKT_MAXSIZE,
 			(60 * 5), NULL) <= 0)
 	{			/* error or timeout.  gen lastwords */
@@ -851,7 +859,7 @@ void dead( int snum, int leave )
 	  cpMessage_t *cmsg = (cpMessage_t *)buf;
 
 	  /* copy as much of the message as you can. */
-	  strncpy(ConqInfo->lastwords, cmsg->msg, MAXLASTWORDS);
+	  strncpy(ConqInfo->lastwords, (char *)cmsg->msg, MAXLASTWORDS);
           ConqInfo->lastwords[MAXLASTWORDS - 1] = 0;
 	}
     }
@@ -1142,7 +1150,7 @@ void handleSimpleCmdPkt(cpCommand_t *ccmd)
       break;
 
     case CPCMD_DISCONNECT:
-      clog("CPCMD_DISCONNECT");
+      utLog("CPCMD_DISCONNECT");
       /* 'fake' signal.  cleans up and exits. */
       handleSignal(0);
       /* NOTREACHED */
@@ -1150,7 +1158,7 @@ void handleSimpleCmdPkt(cpCommand_t *ccmd)
 
     case CPCMD_PING:
       clbBlockAlarm();
-      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_PINGRESP, NULL);
+      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_PINGRESP, NULL);
       clbUnblockAlarm();
       break;
 
@@ -1158,7 +1166,7 @@ void handleSimpleCmdPkt(cpCommand_t *ccmd)
       break;
 
     default:
-      clog("conquestd: handleSimpleCmdPkt(): unexpected command code %d",
+      utLog("conquestd: handleSimpleCmdPkt(): unexpected command code %d",
 	   cmd);
       break;
     }
@@ -1182,12 +1190,14 @@ void freeship(void)
 /*    menu */
 void menu(void)
 {
-  int i, sleepy, countdown;
+  int i;
+  Unsgn32 sleepy;
   int lose, oclosed, switchteams, multiple, redraw;
   int playrv;
   int pkttype;
-  Unsgn8 buf[PKT_MAXSIZE];
+  char buf[PKT_MAXSIZE];
   cpCommand_t *ccmd;
+  static const Unsgn32 sleeplimit = ((1000 * 60) * 5); /* 5 minutes */
   int sockl[2] = {sInfo.sock, sInfo.usock};
 
   catchSignals();	/* enable trapping of interesting signals */
@@ -1213,7 +1223,7 @@ void menu(void)
       Ships[Context.snum].rwar[i] = FALSE;
       Ships[Context.snum].war[i] = Users[Context.unum].war[i];
     }
-  stcpn( Users[Context.unum].alias, Ships[Context.snum].alias, MAXUSERPNAME );
+  utStcpn( Users[Context.unum].alias, Ships[Context.snum].alias, MAXUSERPNAME );
   
   /* Set up some things for the menu display. */
   switchteams = Users[Context.unum].ooptions[OOPT_SWITCHTEAMS];
@@ -1221,8 +1231,7 @@ void menu(void)
   oclosed = ConqInfo->closed;
   Context.leave = FALSE;
   redraw = TRUE;
-  sleepy = 0;
-  countdown = 0;
+  sleepy = clbGetMillis();
   playrv = FALSE;
 
   /* send a ship packet for our ship.  Since this is the first ship packet,
@@ -1254,7 +1263,7 @@ void menu(void)
 	    lose = TRUE;
 	  else if ( Ships[Context.snum].status != SS_RESERVED )
 	    {
-	      clog( "menu(): Ship %d no longer reserved.", Context.snum );
+	      utLog( "menu(): Ship %d no longer reserved.", Context.snum );
 	      lose = TRUE;
 	    }
 	  else
@@ -1265,45 +1274,36 @@ void menu(void)
 
       if ( lose )				/* again, Jorge? */
 	{
-	  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_FATAL, PERR_LOSE, NULL);
+	  pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_FATAL, PERR_LOSE, NULL);
 	  return;
 	}
       
-      /* Try to kill the driver if we started one the last time */
-      /*  we played and we've been in the menu long enough. */
-      if ( countdown > 0 )
-	{
-	  countdown = countdown - 1;
-	  if ( countdown <= 0 )
-	    drkill();
-	}
-      
       /* Reset up the destruct fuse. */
       Ships[Context.snum].sdfuse = -TIMEOUT_PLAYER;
       
-      if ((pkttype = waitForPacket(PKT_FROMCLIENT, sockl, PKT_ANYPKT,
-			buf, PKT_MAXSIZE, 1, NULL)) < 0)
+      if ((pkttype = pktWaitForPacket(PKT_FROMCLIENT, sockl, PKT_ANYPKT,
+                                   buf, PKT_MAXSIZE, 0, NULL)) < 0)
 	{
 	  freeship();
-	  clog("conquestd:menu: waitforpacket returned %d", pkttype); 
+	  utLog("conquestd:menu: waitforpacket returned %d", pkttype); 
           handleSignal(0);
           /* not reached */
 
 	  return;
 	}
       
-      /* we get sleepy if we are recieving no packets, of only
+      /* we get sleepy if we are recieving no packets, or only
          keepalive packets */
       if ( pkttype == 0 || ((pkttype == CP_COMMAND) && 
                             CPCMD_KEEPALIVE == (((cpCommand_t *)buf)->cmd)))
 	{
-	  /* We get here if a packet hasn't been recieved. */
-	  sleepy++;
-	  if ( sleepy > 300 )
+          if ((clbGetMillis() - sleepy) > sleeplimit)
 	    break;
-	  continue; /* next */
-	}
+          else
+            c_sleep(0.05);
 
+	  continue; 
+	}
 
       switch(pkttype)
 	{
@@ -1321,10 +1321,6 @@ void menu(void)
 	    {			/* time to play */
 	      playrv = play();
 	      sInfo.state = SVR_STATE_MAINMENU;
-	      if ( Context.childpid != 0 )
-		countdown = 15;
-	      else
-		countdown = 0;
 	      break;
 	    }
 	  else if (ccmd->cmd == CPCMD_RESIGN)
@@ -1347,13 +1343,14 @@ void menu(void)
 	  break;
 
 	default:
-	  clog("conquestd: MENU: got unexp packet type %d", pkttype);
+          if (cqDebug)
+            utLog("conquestd: MENU: got unexp packet type %d", pkttype);
 	  break;
 	}
       
-      /* Got a character, zero timeout. */
+      /* Got something, reset timeout. */
       
-      sleepy = 0;
+      sleepy = clbGetMillis();
     }
   while ( clbStillAlive( Context.snum ) &&  !Context.leave );
   
@@ -1361,6 +1358,10 @@ void menu(void)
   if ( Ships[Context.snum].status == SS_RESERVED )
     freeship();
   
+  /* Try to kill the driver if we started one the last time */
+  /*  we played and we've been in the menu long enough. */
+  drkill();
+      
   return;
   
 }
@@ -1386,6 +1387,9 @@ int newship( int unum, int *snum )
   int numavail = 0;
   int numvec = 0;
 
+  /* cleanup any unliving ships - this is the first thing we need to do */
+  clbCheckShips(FALSE);
+
   PVLOCK(&ConqInfo->lockword);
   
   Ships[*snum].status = SS_ENTERING;		/* show intent to fly */
@@ -1415,7 +1419,7 @@ int newship( int unum, int *snum )
 	  if (!SVACANT(vec[0]))
 	    {		   /* if it's available, we'll take it */
 			   /* ...if it's not already being flown... */
-	      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_ERROR, PERR_FLYING, NULL);
+	      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_ERROR, PERR_FLYING, NULL);
 	      Ships[*snum].status = SS_RESERVED;
 	      return ( FALSE );
 	    }
@@ -1431,7 +1435,7 @@ int newship( int unum, int *snum )
 		*snum = i;
 		Ships[*snum].pid = Context.pid;
 		Ships[*snum].status = SS_ENTERING;
-		bitClear(Ships[*snum].flags, SHIP_F_VACANT);
+		SFCLR(*snum, SHIP_F_VACANT);
 		break;
 	      }
 	  PVUNLOCK(&ConqInfo->lockword);
@@ -1460,7 +1464,7 @@ int newship( int unum, int *snum )
 	 reincarnate too */
       if ( j >= Users[unum].multiple && numavail == 0)
 	{
-	  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_ERROR, PERR_TOOMANYSHIPS, 
+	  pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_ERROR, PERR_TOOMANYSHIPS, 
 		  NULL);
 	  Ships[*snum].status = SS_RESERVED;
 	  
@@ -1511,7 +1515,7 @@ int newship( int unum, int *snum )
 	i = Teams[system].homesun;
       else
 	i = Teams[system].homeplanet;
-      clPutShip( *snum, Planets[i].x, Planets[i].y );
+      clbPutShip( *snum, Planets[i].x, Planets[i].y );
       Ships[*snum].dhead = rnduni( 0.0, 359.9 );
       Ships[*snum].head = Ships[*snum].dhead;
       Ships[*snum].dwarp = (real) rndint( 2, 5 ) ;/* #~~~ this is a kludge*/
@@ -1557,26 +1561,26 @@ int play(void)
   int rv;
   char msgbuf[128];
   int pkttype;
-  Unsgn8 buf[PKT_MAXSIZE];
+  char buf[PKT_MAXSIZE];
   int sockl[2] = {sInfo.sock, sInfo.usock};
 
   /* Can't carry on without a vessel. */
   if ( (rv = newship( Context.unum, &Context.snum )) != TRUE)
     {
-      clog("conquestd:play: newship() returned %d",
+      utLog("conquestd:play: newship() returned %d",
 	   rv);
       return(rv);
     }
   
   drstart();			/* start a driver, if necessary */
   Ships[Context.snum].sdfuse = 0;	/* zero self destruct fuse */
-  grand( &Context.msgrand );		/* initialize message timer */
+  utGrand( &Context.msgrand );		/* initialize message timer */
   Context.leave = FALSE;		/* assume we won't want to bail */
   Context.redraw = TRUE;		/* want redraw first time */
   Context.msgok = TRUE;		/* ok to get messages */
   Context.display = FALSE;		/* ok to get messages */
   stopUpdate();			/* stop the display interrupt */
-  gsecs( &laststat );		/* initialize stat timer */
+  utGetSecs( &laststat );		/* initialize stat timer */
 
   /* send a clientstat packet and a ship packet. */
 
@@ -1619,12 +1623,12 @@ int play(void)
 	break;
 
       didsomething = 0;
-      if ((pkttype = waitForPacket(PKT_FROMCLIENT, sockl, PKT_ANYPKT,
+      if ((pkttype = pktWaitForPacket(PKT_FROMCLIENT, sockl, PKT_ANYPKT,
 				   buf, PKT_MAXSIZE, 0, NULL)) < 0)
 	{
 	  if (errno != EINTR)
 	    {
-	      clog("conquestd:play:waitForPacket: %s", strerror(errno));
+	      utLog("conquestd:play:pktWaitForPacket: %s", strerror(errno));
               handleSignal(0);
               /* NOTREACHED */
 	      return FALSE;
@@ -1665,7 +1669,7 @@ int play(void)
 
 	default:
 	  if (pkttype != 0 && pkttype != -1)
-	    clog("conquestd: play: got unexpected packet type %d", pkttype);
+	    utLog("conquestd: play: got unexpected packet type %d", pkttype);
 	  break;
 	}
 
@@ -1676,11 +1680,11 @@ int play(void)
           clbUnblockAlarm();
         }
 
-      grand( &Context.msgrand );
+      utGrand( &Context.msgrand );
       Context.msgok = TRUE;
       
       /* See if it's time to update the statistics. */
-      if ( dsecs( laststat, &now ) >= 15 )
+      if ( utDeltaSecs( laststat, &now ) >= 15 )
 	{
 	  conqstats( Context.snum );
 	  laststat = now;
@@ -1702,12 +1706,10 @@ int play(void)
   
   /* Asts are still enabled, simply cancel the next screen update. */
 
-
   stopUpdate();
   updateClient(FALSE);	/* one last, to be sure. */
   sendConqInfo(sInfo.sock, TRUE);
-  c_sleep( 2.0 );
-  clog("INFO: ship %d died, calling dead()", Context.snum);
+  utLog("PLAY: ship %d died, calling dead()", Context.snum);
   dead( Context.snum, Context.leave );
   
   return(TRUE);
@@ -1738,14 +1740,14 @@ int welcome( int *unum )
       /* Must be a new player. */
       if ( ConqInfo->closed )
 	{
-	  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_FATAL, PERR_CLOSED,
+	  pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_FATAL, PERR_CLOSED,
                   NULL);
 	  return ( FALSE );
 	}
       team = rndint( 0, NUMPLAYERTEAMS - 1 );
       
       cbuf[0] = EOS;
-      apptitle( team, cbuf );
+      utAppendTitle( team, cbuf );
       appchr( ' ', cbuf );
       i = strlen( cbuf );
       appstr( name, cbuf );
@@ -1753,12 +1755,12 @@ int welcome( int *unum )
 
       if ( ! clbRegister( name, cbuf, team, unum ) )
 	{
-	  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_FATAL, PERR_REGISTER,
+	  pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_FATAL, PERR_REGISTER,
                   NULL);
 	  return ( FALSE );
 	}
 
-      clog("conquestd: clbRegister COMPLETE!!!! unum = %d, team = %d\n", 
+      utLog("conquestd: clbRegister COMPLETE!!!! unum = %d, team = %d\n", 
 	   *unum, team);
 
 				/* copy in the password */
@@ -1772,18 +1774,18 @@ int welcome( int *unum )
   /* Must be special to play when closed. */
   if ( ConqInfo->closed && ! Users[*unum].ooptions[OOPT_PLAYWHENCLOSED] )
     {
-      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_FATAL, PERR_CLOSED,
+      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_FATAL, PERR_CLOSED,
 	      NULL);
-      clog("conquestd: welcome: game closed\n");
+      utLog("conquestd: welcome: game closed\n");
       return ( FALSE );
     }
 
   /* Can't play without a ship. */
   if ( ! clbFindShip( &Context.snum ) )
     {
-      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_FATAL, PERR_NOSHIP,
+      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_FATAL, PERR_NOSHIP,
 	      NULL);
-      clog("WELCOME: findship failed");
+      utLog("WELCOME: findship failed");
       return ( FALSE );
     }
 
@@ -1805,7 +1807,7 @@ int welcome( int *unum )
 static int hello(void)
 {
   spHello_t shello;
-  Unsgn8 buf[PKT_MAXSIZE];
+  char buf[PKT_MAXSIZE];
   char cbuf[MESSAGE_SIZE * 2];
   int pkttype;
   extern char *ConquestVersion, *ConquestDate;
@@ -1819,7 +1821,7 @@ static int hello(void)
   /* open a UDP socket and bind to it */
   if ((sInfo.usock = udpOpen(listenPort, &usa)) < 0)
     {
-      clog("NET: SERVER hello: udpOpen() failed: %s", strerror(errno));
+      utLog("NET: SERVER hello: udpOpen() failed: %s", strerror(errno));
       sInfo.usock = -1;
       sInfo.tryUDP = FALSE;
     }
@@ -1829,24 +1831,24 @@ static int hello(void)
   shello.protover = (Unsgn16)htons(PROTOCOL_VERSION);
 
   shello.cmnrev = (Unsgn32)htonl(COMMONSTAMP);
-  strncpy(shello.servername, SysConf.ServerName, CONF_SERVER_NAME_SZ);
-  strncpy(shello.serverver, ConquestVersion, CONF_SERVER_NAME_SZ);
-  strcat(shello.serverver, " ");
-  strncat(shello.serverver, ConquestDate, 
+  strncpy((char *)shello.servername, SysConf.ServerName, CONF_SERVER_NAME_SZ);
+  strncpy((char *)shello.serverver, ConquestVersion, CONF_SERVER_NAME_SZ);
+  strcat((char *)shello.serverver, " ");
+  strncat((char *)shello.serverver, ConquestDate, 
          (CONF_SERVER_NAME_SZ - strlen(ConquestVersion)) - 2);
-  strncpy(shello.motd, SysConf.ServerMotd, CONF_SERVER_MOTD_SZ);
+  strncpy((char *)shello.motd, SysConf.ServerMotd, CONF_SERVER_MOTD_SZ);
   shello.flags = 0;
 
   if (ConqInfo->closed)
     shello.flags |= SPHELLO_FLAGS_CLOSED;
 
-  if (!writePacket(PKT_TOCLIENT, sInfo.sock, (Unsgn8 *)&shello))
+  if (!pktWrite(PKT_TOCLIENT, sInfo.sock, &shello))
     {
-      clog("NET: SERVER: hello: write shello failed\n");
+      utLog("NET: SERVER: hello: write shello failed\n");
       return FALSE;
     }
 
-  clog("NET: SERVER: hello: sent server hello to client");
+  utLog("NET: SERVER: hello: sent server hello to client");
 
   if (sInfo.tryUDP)
     {
@@ -1858,9 +1860,9 @@ static int hello(void)
       if ((rv = select(sInfo.usock+1, &readfds, NULL, NULL, &tv)) <= 0)
         {
           if (rv == 0)
-            clog("NET: SERVER: hello: udp select timed out. No UDP");
+            utLog("NET: SERVER: hello: udp select timed out. No UDP");
           else
-            clog("NET: SERVER: hello: udp select failed: %s", strerror(errno));
+            utLog("NET: SERVER: hello: udp select failed: %s", strerror(errno));
 
           sInfo.tryUDP = FALSE;
         }
@@ -1869,13 +1871,13 @@ static int hello(void)
           if (FD_ISSET(sInfo.usock, &readfds))
             {                       /* get the packet, almost done negotiating udp */
               rv = udpRecv(sInfo.usock, buf, PKT_MAXSIZE, &sInfo.clntaddr);
-              clog("NET: SERVER: hello: got %d UDP bytes from client port %d", rv, 
+              utLog("NET: SERVER: hello: got %d UDP bytes from client port %d", rv, 
                    (int)ntohs(sInfo.clntaddr.sin_port));
               
               if (connect(sInfo.usock, (const struct sockaddr *)&sInfo.clntaddr, 
                           sizeof(sInfo.clntaddr)) < 0)
                 {
-                  clog("NET: SERVER: hello: udp connect() failed: %s", strerror(errno));
+                  utLog("NET: SERVER: hello: udp connect() failed: %s", strerror(errno));
                   sInfo.tryUDP = FALSE;
                 }
             }
@@ -1883,22 +1885,22 @@ static int hello(void)
     }
 
   /* now we want a client hello in response */
-  if ((pkttype = readPacket(PKT_FROMCLIENT, sockl, buf, PKT_MAXSIZE, 60)) < 0)
+  if ((pkttype = pktRead(PKT_FROMCLIENT, sockl, buf, PKT_MAXSIZE, 60)) < 0)
   {
-    clog("NET: SERVER: hello: read client hello failed, pkttype = %d",
+    utLog("NET: SERVER: hello: read client hello failed, pkttype = %d",
          pkttype);
     return FALSE;
   }
 
   if (pkttype == 0)
   {
-    clog("NET: SERVER: hello: read client hello: timeout.\n");
+    utLog("NET: SERVER: hello: read client hello: timeout.\n");
     return FALSE;
   }
 
   if (pkttype != CP_HELLO)
   {
-    clog("NET: SERVER: hello: read client hello: wrong packet type %d\n", pkttype);
+    utLog("NET: SERVER: hello: read client hello: wrong packet type %d\n", pkttype);
     return FALSE;
   }
 
@@ -1911,7 +1913,7 @@ static int hello(void)
   chello.clientname[CONF_SERVER_NAME_SZ - 1] = 0;
   chello.clientver[CONF_SERVER_NAME_SZ - 1] = 0;
 
-  clog("CLIENTID:%s:%s:%d:0x%04hx:%d",
+  utLog("CLIENTID:%s:%s:%d:0x%04hx:%d",
        chello.clientname, 
        chello.clientver,
        chello.updates, 
@@ -1923,18 +1925,18 @@ static int hello(void)
     {
       sprintf(cbuf, "SERVER: Protocol mismatch, server 0x%x, client 0x%x",
 	      PROTOCOL_VERSION, chello.protover);
-      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_FATAL, PERR_BADPROTO, cbuf);
-      clog("NET: %s", cbuf);
+      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_FATAL, PERR_BADPROTO, cbuf);
+      utLog("NET: %s", cbuf);
       return FALSE;
     }
 
+  /* for now just a mild notification, since this isn't a real problem 
+   *  anymore. 
+   */
   if (chello.cmnrev != COMMONSTAMP)
     {
-      sprintf(cbuf, "SERVER: commonblock mismatch, expected %d, got %d",
-	      COMMONSTAMP, chello.cmnrev);
-      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_FATAL, PERR_BADCMN, cbuf);
-      clog("NET: %s", cbuf);
-      return FALSE;
+      utLog("NET: INFO: common block mismatch: client %d server %d", 
+            chello.cmnrev, COMMONSTAMP);
     }
 
   if (chello.updates >= 1 && chello.updates <= 10)
@@ -1949,20 +1951,20 @@ static int hello(void)
   /* now send the server stats normally */
   if (!sendServerStat(sInfo.sock))
     {
-      clog("NET: SERVER: hello: sendServerStat failed");
+      utLog("NET: SERVER: hello: sendServerStat failed");
       return FALSE;
     }
 
   /* now we want an ack.  If we get it, we're done! */
-  if ((pkttype = readPacket(PKT_FROMCLIENT, sockl, buf, PKT_MAXSIZE, 60)) < 0)
+  if ((pkttype = pktRead(PKT_FROMCLIENT, sockl, buf, PKT_MAXSIZE, 60)) < 0)
     {
-      clog("NET: SERVER: hello: read client Ack failed");
+      utLog("NET: SERVER: hello: read client Ack failed");
       return FALSE;
     }
 
   if (pkttype != CP_ACK)
     {
-      clog("NET: SERVER: hello: got packet type %d, expected CP_ACK", 
+      utLog("NET: SERVER: hello: got packet type %d, expected CP_ACK", 
            pkttype);
       return FALSE;
     }
@@ -1974,7 +1976,7 @@ static int hello(void)
       if (cpack->code == PERR_DOUDP)
         {
           sInfo.doUDP = TRUE;
-          clog("NET: SERVER: hello: Client acknowleged UDP from server. Doing UDP.");
+          utLog("NET: SERVER: hello: Client acknowleged UDP from server. Doing UDP.");
         }
     }
 
@@ -1998,7 +2000,7 @@ void handleSignal(int sig)
   stopUpdate();
 
   if (sig)
-    clog("conquestd: exiting on signal %d", sig);
+    utLog("conquestd: exiting on signal %d", sig);
   
   if (sInfo.state == SVR_STATE_PLAY)
     {
@@ -2050,7 +2052,7 @@ void conqend(void)
       clbStoreMsg(MSG_COMP, MSG_ALL, msgbuf);
     }
   
-  recordCloseOutput();
+  recCloseOutput();
 
   return;
   
