@@ -2,7 +2,7 @@
 
 /************************************************************************
  *
- * $Id: conquestgl.c 700 2007-05-28 04:31:51Z jon $
+ * $Id: conquestgl.c 762 2008-07-23 02:14:59Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -24,10 +24,14 @@
 /*                                                                    */
 /**********************************************************************/
 
-#define NOEXTERN
 #include "conqdef.h"
 #include "conqcom.h"
+
+#include "conqutil.h"
+
+#define NOEXTERN_CONTEXT
 #include "context.h"
+
 #include "conf.h"
 #include "global.h"
 #include "color.h"
@@ -48,6 +52,9 @@
 
 #include "conqinit.h"
 #include "cqsound.h"
+#include "hud.h"
+
+#include "playback.h"
 
 void catchSignals(void);
 void handleSignal(int sig);
@@ -183,7 +190,7 @@ static void _loadRCFiles(int type, char *cqdir, char *suffix)
 
               if (!(ptr = strdup(filenm)))
                 {
-                  clog("%s: Could not strdup %s, ignoring.",
+                  utLog("%s: Could not strdup %s, ignoring.",
                        __FUNCTION__,
                        filenm);
 
@@ -197,7 +204,7 @@ static void _loadRCFiles(int type, char *cqdir, char *suffix)
               
               if (!tmplist)
                 {  
-                  clog("%s: Could not realloc %d files, ignoring '%s'",
+                  utLog("%s: Could not realloc %d files, ignoring '%s'",
                        __FUNCTION__,
                        numfiles + 1,
                        filenm);
@@ -291,9 +298,6 @@ int main(int argc, char *argv[])
   char *ch;
   int wantMetaList = FALSE;     /* wants to see a list from metaserver */
   int serveropt = FALSE;        /* specified a server with '-s' */
-  int nums = 0;                     /* num servers from metaGetServerList() */
-  char *metaServer = META_DFLT_SERVER; 
-  metaSRec_t *metaServerList;   /* list of servers */
   int dosound = TRUE;
 
   Context.entship = FALSE;
@@ -301,6 +305,7 @@ int main(int argc, char *argv[])
   Context.updsec = 10;		/* dflt - 10/sec */
   Context.msgrand = getnow(NULL, 0);
 
+  strncpy(cInfo.metaServer, META_DFLT_SERVER, MAXHOSTNAME - 1);
   cInfo.sock = -1;
   cInfo.usock = -1;
   cInfo.doUDP = FALSE;
@@ -310,7 +315,7 @@ int main(int argc, char *argv[])
   cInfo.isLoggedIn = FALSE;
   cInfo.remoteport = CN_DFLT_PORT;
 
-  setSystemLog(FALSE, TRUE);	/* use $HOME for logfile */
+  utSetLogConfig(FALSE, TRUE);	/* use $HOME for logfile */
   if (!getLocalhost(cInfo.localhost, MAXHOSTNAME))
     return(1);
 
@@ -322,11 +327,12 @@ int main(int argc, char *argv[])
   while ((i = getopt(argc, argv, "fmM:s:r:tP:Bug:Sv")) != EOF)    
     switch (i)
       {
-      case 'B':                 /* Benchmark mode, set frameDelay to 0.0 */
-        frameDelay = 0.0;
+      case 'B':                 /* Benchmark mode, set recFrameDelay to 0.0 */
+        pbSpeed = PB_SPEED_INFINITE;
+        recFrameDelay = 0.0;
         break;
       case 'f':
-        dConf.fullScreen = TRUE;
+        DSPFSET(DSP_F_FULLSCREEN);
         break;
       case 'g':                 
         parseGeometry(optarg);
@@ -335,10 +341,11 @@ int main(int argc, char *argv[])
         wantMetaList = TRUE;
         break;
       case 'M':
-        metaServer = optarg;
+        strncpy(cInfo.metaServer, optarg, MAXHOSTNAME - 1);
+
         break;
       case 's':                 /* [host[:port]] */
-	cInfo.remotehost = (Unsgn8 *)strdup(optarg);
+	cInfo.remotehost = strdup(optarg);
         if (!cInfo.remotehost)
           {
             printf("strdup failed\n");
@@ -366,7 +373,7 @@ int main(int argc, char *argv[])
         /* don't want to do this if we've already seen -P */
         if (Context.recmode != RECMODE_PLAYING)
           {
-            if (recordOpenOutput(optarg, FALSE))
+            if (recOpenOutput(optarg, FALSE))
               {			/* we are almost ready... */
                 Context.recmode = RECMODE_STARTING;
                 printf("Recording game to %s...\n", optarg);
@@ -385,7 +392,7 @@ int main(int argc, char *argv[])
         break;
 
       case 'P':
-        rfname = optarg;
+        recFilename = optarg;
         Context.recmode = RECMODE_PLAYING;
         dosound = FALSE;        /* no sound during playback */
         break;
@@ -411,13 +418,13 @@ int main(int argc, char *argv[])
   
   
 #ifdef DEBUG_CONFIG
-  clog("%s@%d: main() Reading Configuration files.", __FILE__, __LINE__);
+  utLog("%s@%d: main() Reading Configuration files.", __FILE__, __LINE__);
 #endif
   
   if (GetConf(0) == ERR)	
     {
 #ifdef DEBUG_CONFIG
-      clog("%s@%d: main(): GetConf() returned ERR.", __FILE__, __LINE__);
+      utLog("%s@%d: main(): GetConf() returned ERR.", __FILE__, __LINE__);
 #endif
 	exit(1);
       }
@@ -430,23 +437,20 @@ int main(int argc, char *argv[])
         printf("-P option specified.  All other options ignored.\n");
 
       serveropt = wantMetaList = FALSE;
-      printf("Scanning file %s...\n", rfname);
-      if (!initReplay(rfname, &totElapsed))
+      printf("Scanning file %s...\n", recFilename);
+      if (!recInitReplay(recFilename, &recTotalElapsed))
         exit(1);
 
       /* now init for real */
-      if (!initReplay(rfname, NULL))
+      if (!recInitReplay(recFilename, NULL))
         exit(1);
 
       Context.unum = MSG_GOD;       /* stow user number */
-      Context.snum = ERR;           /* don't display in cdgetp - JET */
-      Context.entship = FALSE;      /* never entered a ship */
-      Context.histslot = ERR;       /* useless as an op */
-      Context.lasttdist = Context.lasttang = 0;
-      Context.lasttarg[0] = EOS;
 
       /* turn off annoying beeps */
       UserConf.DoAlarms = FALSE;
+      /* turn off hudInfo */
+      UserConf.hudInfo = FALSE;
     }
 
   if (serveropt && wantMetaList)
@@ -454,27 +458,6 @@ int main(int argc, char *argv[])
       printf("-m ignored, since -s was specified\n");
       wantMetaList = FALSE;
     }
-  else if (wantMetaList)
-    {                           /* get the metalist and display */
-      printf("Querying metaserver at %s\n",
-             metaServer);
-      nums = metaGetServerList(metaServer, &metaServerList);
-
-      if (nums < 0)
-        {
-          printf("metaGetServerList() failed\n");
-          return 1;
-        }
-
-      if (nums == 0)
-        {
-          printf("metaGetServerList() reported 0 servers online\n");
-          return 1;
-        }
-
-      printf("Found %d server(s)\n",
-             nums);
-    }
 
   /* load the globals/planets, etc */
   cqiLoadRC(CQI_FILE_CONQINITRC, NULL, 1, 0);
@@ -496,14 +479,14 @@ int main(int argc, char *argv[])
     cqsSoundAvailable = FALSE;
 
 #ifdef DEBUG_FLOW
-  clog("%s@%d: main() starting conqinit().", __FILE__, __LINE__);
+  utLog("%s@%d: main() starting conqinit().", __FILE__, __LINE__);
 #endif
   
   conqinit();			/* machine dependent initialization */
-  iBufInit();
+  ibufInit();
   
 #ifdef DEBUG_FLOW
-  clog("%s@%d: main() starting cdinit().", __FILE__, __LINE__);
+  utLog("%s@%d: main() starting cdinit().", __FILE__, __LINE__);
 #endif
 
   
@@ -516,6 +499,8 @@ int main(int argc, char *argv[])
   Context.snum = 0;		/* force menu to get a new ship */
   Context.histslot = ERR;
   Context.lasttang = Context.lasttdist = 0;
+
+  Context.lasttdist = Context.lasttang = 0;
   Context.lasttarg[0] = EOS;
   catchSignals();       /* enable trapping of interesting signals */
 
@@ -524,12 +509,12 @@ int main(int argc, char *argv[])
   if (Context.recmode == RECMODE_PLAYING)
     nPlayBMenuInit();
   else if (wantMetaList)
-    nMetaInit(metaServerList, nums);
+    nMetaInit();
   else
     nConsvrInit(cInfo.remotehost, cInfo.remoteport);
 
 #ifdef DEBUG_FLOW
-  clog("%s@%d: main() welcoming player.", __FILE__, __LINE__);
+  utLog("%s@%d: main() welcoming player.", __FILE__, __LINE__);
 #endif
 
   /* start the fun! */
@@ -542,7 +527,7 @@ int main(int argc, char *argv[])
 void catchSignals(void)
 {
 #ifdef DEBUG_SIG
-  clog("catchSignals() ENABLED");
+  utLog("catchSignals() ENABLED");
 #endif
   
   signal(SIGHUP, (void (*)(int))handleSignal);
@@ -558,7 +543,7 @@ void handleSignal(int sig)
 {
   
 #ifdef DEBUG_SIG
-  clog("handleSignal() got SIG %d", sig);
+  utLog("handleSignal() got SIG %d", sig);
 #endif
   
   switch(sig)
@@ -586,7 +571,7 @@ void conqend(void)
 {
   if (cInfo.sock != -1)
     sendCommand(CPCMD_DISCONNECT, 0); /* tell the server */
-  recordCloseOutput();
+  recCloseOutput();
 
   return;
   
