@@ -4,7 +4,7 @@
  *
  * client specific stuff
  *
- * $Id: cuclient.c 552 2006-07-17 04:47:23Z jon $
+ * $Id: cuclient.c 762 2008-07-23 02:14:59Z jon13 $
  *
  * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -16,6 +16,7 @@
 #include "packet.h"
 #include "client.h"
 #include "clientlb.h"
+#include "conqutil.h"
 #include "cd2lb.h"
 #include "iolb.h"
 #include "cumisc.h"
@@ -111,8 +112,8 @@ void cucDoWar( int snum )
 		       "Reprogramming the battle computer, please stand by...",
 		       MSG_LIN2 );
 	      cdrefresh();
-	      grand( &entertime );
-	      while ( dgrand( entertime, &now ) < REARM_GRAND )
+	      utGrand( &entertime );
+	      while ( utDeltaGrand( entertime, &now ) < REARM_GRAND )
 		{
 		  /* See if we're still alive. */
 		  if ( ! clbStillAlive( Context.snum ) )
@@ -175,7 +176,7 @@ void cucSendMsg( int from, int terse, int remote )
       return;
     }
   
-  /* TAB or RETURN means use the target from the last message. */
+  /* TAB or ENTER means use the target from the last message. */
   editing = ( (ch == TERM_EXTRA || ch == TERM_NORMAL) && buf[0] == EOS );
   if ( editing )
     {
@@ -206,13 +207,13 @@ void cucSendMsg( int from, int terse, int remote )
     }
   
   /* Got a target, parse it. */
-  delblanks( buf );
+  utDeleteBlanks( buf );
   upper( buf );
   if ( alldig( buf ) == TRUE )
     {
       /* All digits means a ship number. */
       i = 0;
-      safectoi( &j, buf, i );		/* ignore status */
+      utSafeCToI( &j, buf, i );		/* ignore status */
       if ( j < 1 || j > MAXSHIPS )
 	{
 	  mcuPutMsg( "No such ship.", MSG_LIN2 );
@@ -270,7 +271,7 @@ void cucSendMsg( int from, int terse, int remote )
 	  mcuPutMsg( nf, MSG_LIN2 );
 	  return;
 	}
-      appship( to, buf );
+      utAppendShip( to, buf );
       appchr( ':', buf );
     }
   else if ( -to >= 0 && -to < NUMPLAYERTEAMS )
@@ -299,7 +300,7 @@ void cucSendMsg( int from, int terse, int remote )
     }
   
   if ( ! terse )
-    appstr( " (ESCAPE to abort)", buf );
+    appstr( " ([ESC] to abort)", buf );
   
   mcuPutMsg( buf, MSG_LIN1 );
   cdclrl( MSG_LIN2, 1 );
@@ -335,14 +336,14 @@ void cucSendMsg( int from, int terse, int remote )
 	    {
 	      appstr( Ships[from].alias, buf );
 	      appstr( " on board ", buf );
-	      appship( from, buf );
+	      utAppendShip( from, buf );
 	    }
 	  else if ( from == MSG_GOD )
 	    appstr( "GOD", buf );
 	  else
 	    {
 	      appchr( '(', buf );
-	      appint( from, buf );
+	      utAppendInt( from, buf );
 	      appchr( ')', buf );
 	    }
 	  if (remote)           /* remotes don't send 'from' */
@@ -350,7 +351,7 @@ void cucSendMsg( int from, int terse, int remote )
 	  else
 	    clbStoreMsg( from, MSG_IMPLEMENTORS, msg ); /* GOD == IMP (conqoper) */
 	  /* log it to the logfile too */
-	  clog("MSG: MESSAGE TO IMPLEMENTORS: %s: %s", buf, msg);
+	  utLog("MSG: MESSAGE TO IMPLEMENTORS: %s: %s", buf, msg);
 	}
     }
   } /* end while loop */ 
