@@ -2,7 +2,7 @@
 
 /************************************************************************
  *
- * $Id: display.c 552 2006-07-17 04:47:23Z jon $
+ * $Id: display.c 774 2008-09-01 19:41:52Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -20,6 +20,7 @@
 #include "context.h"
 #include "conf.h"
 #include "conqlb.h"
+#include "conqutil.h"
 #include "cd2lb.h"
 #include "cumisc.h"
 #include "global.h"
@@ -55,7 +56,7 @@ void do_bottomborder(int snum, char *buf, int attrib, int bufattr)
   /* now the buffer, if there */
   if ( buf && buf[0] != EOS )
     {
-      if (UserConf.AltHUD)
+      if (UserConf.hudInfo)
 	col = Context.maxcol - (strlen(buf) + 1);
       else
 	col = (int) (Context.maxcol - STAT_COLS - strlen(buf)) / 
@@ -76,8 +77,8 @@ void do_bottomborder(int snum, char *buf, int attrib, int bufattr)
       uiPutColor(0);
     }
 
-  /* if alt hud and we are a ship... */
-  if (UserConf.AltHUD && snum > 0 && 
+  /* if hudInfo and we are a ship... */
+  if (UserConf.hudInfo && snum > 0 && 
       snum <= MAXSHIPS)
     {				/* some additional info */
       /* current firing angle */
@@ -136,7 +137,7 @@ int alertcolor(int alert)
       theattrib = RedLevelColor;
       break;
     default:
-      clog("alertcolor(): invalid alert level: %d", alert);
+      utLog("alertcolor(): invalid alert level: %d", alert);
       break;
     }
 
@@ -153,7 +154,7 @@ void draw_alertborder(int snum, int alert)
 /*  SYNOPSIS */
 /*    int snum, display_info */
 /*    display( snum, display_info ) */
-void display( int snum, int display_info )
+void display( int snum )
 {
   int i, j, k, l, m, idx, lin, col, dcol, datacol, minenemy, minsenemy;
   int linofs[8] = {0, -1, -1, -1, 0, 1, 1, 1};
@@ -204,6 +205,9 @@ void display( int snum, int display_info )
   else
     lsmap = 0;
   
+  /* adjust the ships obital position if neccessary */
+  clbAdjOrbitalPosition(snum);
+
   if ( lsmap )
     {
       scale = MAP_FAC;
@@ -530,6 +534,16 @@ void display( int snum, int display_info )
 			    }
 		      
 		    }
+
+                /* if the ship is in orbit, adjust it's position for
+                 *  smoother motion on fast moving planets.  Our own
+                 *  ship's position will have already been adjusted
+                 *  above.
+                 */
+
+                if (snum != i)
+                  clbAdjOrbitalPosition(i);
+
 	      }	/* if a ship view (snum > 0) */
 
 	    /* There is potential for un-cloaked ships and ourselves. */
@@ -587,7 +601,7 @@ void display( int snum, int display_info )
 			/* itself elsewhere... anyway, a kludge: */
 			idx = ((idx == 8) ? 0 : idx);
 			
-			/*			    cerror("idx = %d", idx);*/
+			/*			    utError("idx = %d", idx);*/
 			
 			j = lin+linofs[idx];
 			k = col+colofs[idx];
@@ -674,7 +688,7 @@ void display( int snum, int display_info )
 	  
 	  if ( minenemy != 0 )
 	    {
-	      appship( minenemy, buf );
+	      utAppendShip( minenemy, buf );
 	      if ( SCLOAKED(minenemy) )
 		appstr( " (CLOAKED)", buf );
 	    }
@@ -691,7 +705,7 @@ void display( int snum, int display_info )
       OldAlert = AlertLevel;
     }
   
-  if ( (strcmp( buf, zzbuf ) != 0) || UserConf.AltHUD)
+  if ( (strcmp( buf, zzbuf ) != 0) || UserConf.hudInfo)
     {
       lin = DISPLAY_LINS + 1;
       do_bottomborder(snum, buf, alertcolor(AlertLevel), outattr);
@@ -906,12 +920,12 @@ void display( int snum, int display_info )
 	if ( i == 0 )
 	  appstr( "**", buf );
 	else
-	  appint( i, buf );
+	  utAppendInt( i, buf );
 	appchr( '/', buf );
 	if ( j == 0 )
 	  appstr( "**", buf );
 	else
-	  appint( j, buf );
+	  utAppendInt( j, buf );
 	uiPutColor(InfoColor);
 	cdputs( buf, lin, datacol );
 	uiPutColor(0);
@@ -1117,12 +1131,12 @@ void display( int snum, int display_info )
 	else if ( i < 0 )
 	  {
 	    c_strcpy( "towing ", buf );
-	    appship( -i, buf );
+	    utAppendShip( -i, buf );
 	  }
 	else if ( i > 0 )
 	  {
 	    c_strcpy( "towed by ", buf );
-	    appship( i, buf );
+	    utAppendShip( i, buf );
 	  }
 	uiPutColor(InfoColor);
 	cdputs( buf, lin, col );
@@ -1269,7 +1283,7 @@ void display( int snum, int display_info )
 	  else if ( i > 0 && i <= MAXSHIPS )
 	    {
 	      buf[0] = EOS;
-	      appship( i, buf );
+	      utAppendShip( i, buf );
 	      uiPutColor(RedLevelColor);
 	      cdputs( buf, lin, dcol );
 	      uiPutColor(0);
@@ -1287,15 +1301,22 @@ void display( int snum, int display_info )
 	}
       else
 	{			/* not the doomsday, nothing yet... */
-	  clog("display(): got invalid ship number %d", snum);
+	  utLog("display(): got invalid ship number %d", snum);
 	}
       
     }
   
-  if (snum > 0)			/* a ship */
-    if (display_info)
-      display_headers(snum);
-
+  /* draw the 'header' (ship id) if we should:
+   *
+   * ship is valid AND we are either playing or pausing a recording, OR
+   * Our user number is MSG_GOD whick means we are in conqoper.
+   */
+  if (snum > 0 && 
+       (Context.recmode == RECMODE_PLAYING  || 
+        Context.recmode == RECMODE_PAUSED  ||
+        Context.unum == MSG_GOD) )
+    display_headers(snum);
+  
   cdrefresh();
   Context.redraw = FALSE;
 
@@ -1318,7 +1339,7 @@ void display_headers(int snum)
   ssbuf[0] = EOS;
   
   appstr( ", ", ssbuf );
-  appsstatus( Ships[snum].status, ssbuf);
+  utAppendShipStatus( Ships[snum].status, ssbuf);
   
   if ( ConqInfo->closed) 
     {
