@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * $Id: display.h 552 2006-07-17 04:47:23Z jon $
+ * $Id: display.h 774 2008-09-01 19:41:52Z jon13 $
  *
  * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -8,7 +8,7 @@
 #ifndef _DISPLAY_H
 #define _DISPLAY_H
 
-void display( int snum, int display_info );
+void display( int snum );
 void display_headers(int snum);
 void do_bottomborder(int snum, char *buf, int attrib, int bufattrib);
 void do_border(int snum, int attr);
