@@ -1,7 +1,7 @@
 #include "c_defs.h"
 /************************************************************************
  *
- * $Id: glcprintf.c 552 2006-07-17 04:47:23Z jon $
+ * $Id: glcprintf.c 763 2008-07-27 06:35:28Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -22,7 +22,16 @@
 #include "gldisplay.h"
 #include "conf.h"
 
+#include <GL/glut.h>
+#include <GL/gl.h>
+#include <GL/glu.h>
+#include <GL/glx.h>
+
+#include "glmisc.h"
+#include "glfont.h"
+
 static char buf[MID_BUFFER_SIZE];
+
 /* 
  * int lin - line if pertinent
  * int col - column if pertinent
@@ -45,7 +54,7 @@ void cprintf(int lin, int col, int align, char *fmt, ...)
   (void)vsnprintf(buf, sizeof(buf) - 1, fmt, ap);
   va_end(ap);
   
-  if (dConf.inited)
+  if (DSP_INITED())
     {
       l = uiCStrlen(buf);
       if (align == ALIGN_CENTER)
@@ -55,7 +64,14 @@ void cprintf(int lin, int col, int align, char *fmt, ...)
       
       y = dConf.ppRow * (GLfloat)lin;
       w = dConf.ppCol * (GLfloat)l;
-      uiPrintFixed(x + dConf.borderW, y + dConf.borderW, w, dConf.ppRow, buf);
+
+      glfRenderFont(x + dConf.wBorderW, 
+                    y + dConf.wBorderW, 
+                    0.0, 
+                    w, dConf.ppRow, 
+                    glfFontFixed, buf, 
+                    NoColor, NULL, 
+                    GLF_FONT_F_SCALEX | GLF_FONT_F_DOCOLOR | GLF_FONT_F_ORTHO);
     }
 
   return;
