@@ -2,7 +2,7 @@
 
 /************************************************************************
  *
- * $Id: global.c 552 2006-07-17 04:47:23Z jon $
+ * $Id: global.c 762 2008-07-23 02:14:59Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -17,7 +17,7 @@
 
 #include "c_defs.h"
 
-#define NOEXTERNGLOBALS
+#define NOEXTERN_GLOBALS
 #include "global.h"
 
 /* That's it! */
