@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * $Id: global.h 698 2007-05-14 02:24:01Z jon $
+ * $Id: global.h 774 2008-09-01 19:41:52Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -19,28 +19,20 @@
 #ifndef GLOBAL_H
 #define GLOBAL_H
 
-#ifdef NOEXTERNGLOBALS
-#define CEXTERN 
-#else
-#define CEXTERN extern 
-#endif
-
-CEXTERN	   int PollInputfd;	/* a copy of stdin's fd for poll()/select() */
-CEXTERN    int ConquestGID;	/* Conquest's GID */
-CEXTERN    int RMsg_Line;
-
 /* for the semaphores */
 #define LOCKMSG      (0)	/* lock the message portion  */
 #define LOCKCMN      (1)	/* lock everything else  */
 
-CEXTERN int headerflag;         /* whether to show header flag */
+
+#if defined(NOEXTERN_GLOBALS)
+int        ConquestGID;         /* Conquest's GID */
+
+int        cqDebug = 0;
+#else
+extern int ConquestGID;         /* Conquest's GID */
 
 /* verbosity/debugging */
-#if defined(NOEXTERNGLOBALS)
-int cqDebug = 0;
-#else
-CEXTERN int cqDebug;
+extern int cqDebug;
 #endif
 
-#undef CEXTERN			/* cleanup */
-#endif
+#endif /* GLOBAL_H */
