@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * $Id: ibuf.h 552 2006-07-17 04:47:23Z jon $
+ * $Id: ibuf.h 762 2008-07-23 02:14:59Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -17,14 +17,14 @@
 #define IBUF_H
 
 #include "datatypes.h"
-#define    IBUFMAX 1024
 
-void iBufInit(void);
-int iBufCount(void);
-void iBufPut(char *thestr);
-void iBufPutc(unsigned int thechar);
-unsigned int iBufGetCh(void);
-int DoMacro(int fkey);
-int DoMouseMacro(int but, Unsgn32 mods, real mangle);
+void         ibufInit(void);
+void         ibufFlush(void);
+int          ibufCount(void);
+void         ibufPut(char *thestr);
+void         ibufPutc(unsigned int thechar);
+unsigned int ibufGetc(void);
+int          ibufExpandMacro(int fkey);
+int          ibufExpandMouseMacro(int but, Unsgn32 mods, real mangle);
 
-#endif
+#endif /* IBUF_H */
