@@ -3,7 +3,7 @@
  *
  * I/O library routines
  *
- * $Id: iolb.c 552 2006-07-17 04:47:23Z jon $
+ * $Id: iolb.c 774 2008-09-01 19:41:52Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -17,8 +17,13 @@
 /**********************************************************************/
 
 #include "global.h"
+#include "conqutil.h"
 #include "ibuf.h"
+
+#define NOEXTERN_IOLB
 #include "iolb.h"
+#undef NOEXTERN_IOLB
+
 #include "cd2lb.h"
 
 /* iochav - test whether a char is available to be read or not */
@@ -55,7 +60,7 @@ int iochav( void )
   
   int retval;
   
-  if (iBufCount())
+  if (ibufCount())
     {
       return(TRUE);
     }
@@ -64,14 +69,14 @@ int iochav( void )
   
   /* here, we'll just use select */
   FD_ZERO(&readfds);
-  FD_SET(PollInputfd, &readfds);
+  FD_SET(iolbStdinFD, &readfds);
   
   timeout.tv_sec = 0;		/* setting to zero should ret immediately */
   timeout.tv_usec = 0;
   
-  if ((retval = select(PollInputfd+1, &readfds, NULL, NULL, &timeout)) == -1)
+  if ((retval = select(iolbStdinFD+1, &readfds, NULL, NULL, &timeout)) == -1)
     {
-      clog("iochav(): select(): %s", strerror(errno));
+      utLog("iochav(): select(): %s", strerror(errno));
       return(FALSE);
     }
   
@@ -93,24 +98,24 @@ int iochav( void )
   
   flagsp = 0;
   
-  Stdin_pfd.fd = PollInputfd;		/* stdin */
+  Stdin_pfd.fd = iolbStdinFD;		/* stdin */
   Stdin_pfd.events = (POLLIN | POLLRDNORM);
   
   if (poll(&Stdin_pfd, 1, 0) > 0) /* return immediately if a char avail */
     {
 #ifdef DEBUG_IO
-      clog("ALTiochav(): had a char via poll");
+      utLog("ALTiochav(): had a char via poll");
 #endif
       
-      if ((retval = getmsg(PollInputfd, &CtlMsg, &DataMsg, 
+      if ((retval = getmsg(iolbStdinFD, &CtlMsg, &DataMsg, 
 			   &flagsp)) == -1)
 	{
-	  clog("iochav(): getmsg(): failed: %s", strerror(errno));
+	  utLog("iochav(): getmsg(): failed: %s", strerror(errno));
 	}
       else
 	{
 #ifdef DEBUG_IO
-	  clog("iochav(): getmsg() = %d: DataMsg.len = %d CtlMsg.len = %d",
+	  utLog("iochav(): getmsg() = %d: DataMsg.len = %d CtlMsg.len = %d",
 	       retval,
 	       DataMsg.len,
 	       CtlMsg.len);
@@ -119,7 +124,7 @@ int iochav( void )
 	  if (DataMsg.len <= 0 && retval > 0)
 	    {
 #ifdef DEBUG_IO
-              clog("iochav(): getmsg(): DataMsg.len <= 0 retval = %d - TRUE",
+              utLog("iochav(): getmsg(): DataMsg.len <= 0 retval = %d - TRUE",
 		   DataMsg.len,
 		   retval);
 #endif
@@ -130,14 +135,14 @@ int iochav( void )
 	  if (DataMsg.len <= 0 && CtlMsg.len <= 0)
 	    {
 #ifdef DEBUG_IO
-	      clog("iochav(): getmsg(): DataMsg.len & CtlMsg.len <= 0 ret FALSE");
+	      utLog("iochav(): getmsg(): DataMsg.len & CtlMsg.len <= 0 ret FALSE");
 #endif
 	      return(FALSE);
 	    }
 	  else
 	    {
 #ifdef DEBUG_IO
-	      clog("iochav(): getmsg(): DataMsg.len | CtlMsg.len > 0 ret TRUE");
+	      utLog("iochav(): getmsg(): DataMsg.len | CtlMsg.len > 0 ret TRUE");
 #endif
 	      return(TRUE);
 	    }
@@ -146,7 +151,7 @@ int iochav( void )
   else 
     {
 #ifdef DEBUG_IO
-      clog("ALTiochav(): NO char via poll");
+      utLog("ALTiochav(): NO char via poll");
 #endif
       return(FALSE);
     }
@@ -188,18 +193,18 @@ int iogchar ( void )
   
  reloop:
   
-  if (!iBufCount())
+  if (!ibufCount())
     {
       c_sleep(0.1);
       thechar = wgetch(stdscr);
     }
   else
-    thechar = iBufGetCh();
+    thechar = ibufGetc();
   
   if (thechar == ERR)
     {
 #ifdef DEBUG_IO
-      clog("iogchar() thechar == ERR, errno = %d", errno);
+      utLog("iogchar() thechar == ERR, errno = %d", errno);
 #endif
       goto reloop;
     }
@@ -246,9 +251,9 @@ int iogtimed ( int *ch, real seconds )
   
   cdrefresh();
   
-  if (iBufCount())
+  if (ibufCount())
     {
-      *ch = iBufGetCh();
+      *ch = ibufGetc();
       return(TRUE);
     }
   
@@ -276,7 +281,7 @@ int iogtimed ( int *ch, real seconds )
      interrupted.  Don't count on this
      behavior with other unix's... */
   FD_ZERO(&readfds);
-  FD_SET(PollInputfd, &readfds);
+  FD_SET(iolbStdinFD, &readfds);
   
   timeout.tv_sec = secs;
   timeout.tv_usec = usecs;
@@ -302,7 +307,7 @@ int iogtimed ( int *ch, real seconds )
 	 how to get around that... */
       
       FD_ZERO(&readfds);
-      FD_SET(PollInputfd, &readfds);
+      FD_SET(iolbStdinFD, &readfds);
       
       timeout.tv_sec = secs;
       timeout.tv_usec = usecs;
@@ -310,13 +315,13 @@ int iogtimed ( int *ch, real seconds )
       
 #if defined(USE_SELECT)
 
-      if ((retval = select(PollInputfd + 1, &readfds, NULL, NULL, 
+      if ((retval = select(iolbStdinFD + 1, &readfds, NULL, NULL, 
 			   &timeout)) == -1)
 	{			/* timeout or signal? */
 	  if (errno != EINTR)	/* some error */
 	    {
 	      *ch = 0;
-	      clog("iogtimed(): select() failed: %s", strerror(errno));
+	      utLog("iogtimed(): select() failed: %s", strerror(errno));
 	      cdrefresh();
 	      return(FALSE);
 	    }
@@ -324,7 +329,7 @@ int iogtimed ( int *ch, real seconds )
           else
 	    {
 # if defined(DEBUG_IOGTIMED)
-	      clog("iogtimed(): select(): interrupted: %s", 
+	      utLog("iogtimed(): select(): interrupted: %s", 
 		   strerror(errno));
 # endif
 
@@ -348,14 +353,14 @@ int iogtimed ( int *ch, real seconds )
       else if (retval > 0)
 	{
 # if defined(DEBUG_IOGTIMED)
-          if (FD_ISSET(PollInputfd,&readfds))
-	    clog("After Linux select - FD_ISSET is SET");
+          if (FD_ISSET(iolbStdinFD,&readfds))
+	    utLog("After Linux select - FD_ISSET is SET");
           else
-	    clog("After Linux select - FD_ISSET is NOT SET");
-          clog("iogtimed(): After Linux select - errno   = %d", errno);
-          clog("iogtimed(): After Linux select - tv_sec  = %d", 
+	    utLog("After Linux select - FD_ISSET is NOT SET");
+          utLog("iogtimed(): After Linux select - errno   = %d", errno);
+          utLog("iogtimed(): After Linux select - tv_sec  = %d", 
 	       timeout.tv_sec);
-          clog("iogtimed(): After Linux select - tv_usec = %d", 
+          utLog("iogtimed(): After Linux select - tv_usec = %d", 
 	       timeout.tv_usec);
 # endif
 	  
@@ -363,8 +368,8 @@ int iogtimed ( int *ch, real seconds )
 	  *ch = c;
 	  
 # if defined(DEBUG_IOGTIMED)
-	  clog("iogtimed(): retval = %d, PollInputfd = %d, *ch = %d",
-	       retval,PollInputfd,*ch);
+	  utLog("iogtimed(): retval = %d, iolbStdinFD = %d, *ch = %d",
+	       retval,iolbStdinFD,*ch);
 # endif
 	  
 	  return(TRUE);
@@ -373,8 +378,8 @@ int iogtimed ( int *ch, real seconds )
 	{
 	  *ch = 0;
 # if defined(DEBUG_IOGTIMED)
-	  clog("iogtimed(): retval = %d, PollInputfd = %d, *ch = %d",
-	       retval,PollInputfd,*ch);
+	  utLog("iogtimed(): retval = %d, iolbStdinFD = %d, *ch = %d",
+	       retval,iolbStdinFD,*ch);
 # endif
 	  cdrefresh();
 	  return(FALSE);
