@@ -1,7 +1,7 @@
 /* 
  * node
  *
- * $Id: nDead.c 552 2006-07-17 04:47:23Z jon $
+ * $Id: nDead.c 769 2008-08-17 06:41:00Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -19,11 +19,13 @@
 #include "prm.h"
 #include "conqcom.h"
 #include "conqlb.h"
+#include "conqutil.h"
 #include "nDead.h"
 #include "nMenu.h"
+#include "nPlay.h"
 #include "cqkeys.h"
-
-extern Unsgn8 clientFlags;      /* conquestgl.c */
+#include "cqsound.h"
+#include "glmisc.h"
 
 static int snum;
 static int kb;                  /* killed by... */
@@ -46,9 +48,9 @@ static int nDeadInput(int ch);
 static scrNode_t nDeadNode = {
   nDeadDisplay,               /* display */
   nDeadIdle,                  /* idle */
-  nDeadInput,                  /* input */
-  NULL,                         /* minput */
-  NULL                          /* animQue */
+  nDeadInput,                 /* input */
+  NULL,                       /* minput */
+  NULL                        /* animQue */
 };
 
 
@@ -60,7 +62,7 @@ void nDeadInit(void)
   /* If something is wrong, don't do anything. */
   if ( snum < 1 || snum > MAXSHIPS )
     {
-      clog("nDead: nDeadInit: snum < 1 || snum > MAXSHIPS (%d)", snum);
+      utLog("nDead: nDeadInit: snum < 1 || snum > MAXSHIPS (%d)", snum);
       nMenuInit();
     }
   
@@ -68,6 +70,8 @@ void nDeadInit(void)
 
   if (kb >= 1 && kb <= MAXSHIPS)
     eShip = Ships[kb];        /* get copy of killers ship */
+  else
+    memset((void *)&eShip, 0, sizeof(Ship_t));
 
   if (clientFlags & SPCLNTSTAT_FLAG_CONQUER)
     {
@@ -81,7 +85,7 @@ void nDeadInit(void)
     }
 
 
-  setNode(&nDeadNode);
+  setONode(&nDeadNode);
 
   return;
 }
@@ -150,7 +154,7 @@ static int nDeadDisplay(dspConfig_t *dsp)
       junk[0] = EOS;
       if ( kb > 0 && kb <= MAXSHIPS )
 	{
-	  appship( kb, cbuf );
+	  utAppendShip( kb, cbuf );
 	  if ( eShip.status != SS_LIVE )
 	    appstr( ", who also died.", buf );
 	  else
@@ -177,10 +181,10 @@ static int nDeadDisplay(dspConfig_t *dsp)
 	{
 	  /* We were unable to determine the cause of death. */
 	  buf[0] = EOS;
-	  appship( snum, buf );
+	  utAppendShip( snum, buf );
 	  sprintf(cbuf, "dead: %s was killed by %d.", buf, kb);
-	  cerror( cbuf );
-	  clog(cbuf);
+	  utError( cbuf );
+	  utLog(cbuf);
 	  
 	  cprintf(8,0,ALIGN_CENTER,"#%d#%s%s", 
                   RedLevelColor, ywkb, "nothing in particular.  (How strange...)");
@@ -205,9 +209,9 @@ static int nDeadDisplay(dspConfig_t *dsp)
 	  else
 	    {
 	      if ( i < 100 )
-			appnum( i, junk );
+			utAppendNumWord( i, junk );
 	      else
-			appint( i, junk );
+			utAppendInt( i, junk );
 	      strcpy( cbuf, "armies" );
 	    }
 	  if ( i == 1 )
@@ -240,7 +244,8 @@ static int nDeadDisplay(dspConfig_t *dsp)
 	InfoColor, CQC_A_BOLD, oneplace(Ships[snum].kills), InfoColor );
 
   if (state == S_PRESSANY)
-    cprintf(MSG_LIN1, 0, ALIGN_CENTER, MTXT_DONE);
+    cprintf(MSG_LIN1, 0, ALIGN_CENTER, 
+            "[ESC] for Main Menu, [TAB] to re-enter the game.");
   else
     {
       if (state == S_LASTWORDS)
@@ -282,10 +287,29 @@ static int nDeadInput(int ch)
   switch (state)
     {
     case S_PRESSANY:
-      nMenuInit();                /* go to menu */
+      if (ch == TERM_ABORT || ch == TERM_EXTRA) /* ESC or TAB */
+        {
+          setONode(NULL);
+          /* turn off any running effects */
+          cqsEffectStop(CQS_INVHANDLE, TRUE);
+
+          switch (ch)
+            {
+            case TERM_ABORT:    /* ESC */
+              nMenuInit();      /* go to menu */
+              return NODE_OK;
+            case TERM_EXTRA:
+              /* since the server is already in the 'menu' waiting for us
+               * just go for it.
+               */
+              nPlayInit();
+              return NODE_OK;
+            }
+        }
+      else
+        mglBeep(MGL_BEEP_ERR);
 
       break;
-
     case S_LASTWORDS:
       irv = prmProcInput(&prm, ch); 
       if (irv > 0)
@@ -297,6 +321,7 @@ static int nDeadInput(int ch)
       if (ch == TERM_EXTRA)
         {                       /* we are done */
           sendMessage(MSG_GOD, lastwords);
+          setONode(NULL);
           nMenuInit();
         }
       else
