@@ -1,11 +1,11 @@
 /* 
- * meta select server node
+ * meta server node
  *
  * can NODE_EXIT or transfer to ConSvr node
  *
- * $Id: nMeta.c 552 2006-07-17 04:47:23Z jon $
+ * $Id: nMeta.c 762 2008-07-23 02:14:59Z jon13 $
  *
- * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
+ * Copyright 1999-2008 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
 
 #include "c_defs.h"
@@ -23,6 +23,7 @@
 #include "gldisplay.h"
 #include "glmisc.h"
 #include "cqkeys.h"
+#include "conqutil.h"
 
 static char *header = "Server List";
 static char *header2fmt = "(Page %d of %d)";
@@ -44,7 +45,9 @@ static int nMetaDisplay(dspConfig_t *);
 static int nMetaInput(int ch);
 
 static metaSRec_t *metaServerList;
-static int nums;
+static int numMetaServers;   /* number of servers in metaServerList */
+
+static metaSRec_t *metaServerList;   /* list of servers */
 
 static scrNode_t nMetaNode = {
   nMetaDisplay,                 /* display */
@@ -148,25 +151,43 @@ static void dispServerInfo(dspConfig_t *dsp, metaSRec_t *metaServerList,
 }
 
 
-void nMetaInit(metaSRec_t *ServerList, int numserv)
+void nMetaInit(void)
 {
   int i;
-  metaServerList = ServerList;
-  nums = numserv;
+
+  /* get the server list */
+  utLog("nMetaInit: Querying metaserver at %s", cInfo.metaServer);
+  numMetaServers = metaGetServerList(cInfo.metaServer, 
+                                     &metaServerList);
+  
+  if (numMetaServers < 0)
+    {
+      utLog("nMetaInit: metaGetServerList() failed");
+      return;
+    }
+  
+  if (numMetaServers == 0)
+    {
+      utLog("nMetaInit: metaGetServerList() reported 0 servers online");
+      return;
+    }
+  
+  utLog("nMetaInit: Found %d server(s)", numMetaServers);
 
   /* this is the number of required pages,        
      though page accesses start at 0 */
-  if (nums >= servers_per_page)
+
+  if (numMetaServers >= servers_per_page)
     {
-      pages = nums / servers_per_page;
-      if ((nums % servers_per_page) != 0)
+      pages = numMetaServers / servers_per_page;
+      if ((numMetaServers % servers_per_page) != 0)
         pages++;                /* for runoff */
     }
   else
     pages = 1;
 
 				/* init the servervec array */
-  for (i=0; i < nums; i++)
+  for (i=0; i < numMetaServers; i++)
   {
     if (metaServerList[i].version >= 2) /* valid for newer meta protocols */
       servervec[i].vers = metaServerList[i].protovers;
@@ -212,7 +233,7 @@ static int nMetaDisplay(dspConfig_t *dsp)
 				   this page */
 
   if (curpage == (pages - 1)) /* last page - might be less than full */
-    llin = (nums % servers_per_page);	/* ..or more than empty? ;-) */
+    llin = (numMetaServers % servers_per_page);	/* ..or more than empty? ;-) */
   else
     llin = servers_per_page;
   
@@ -290,7 +311,7 @@ static int nMetaInput(int ch)
           
           /* setup llin  for current page */
           if (curpage == (pages - 1)) 
-            llin = (nums % servers_per_page);
+            llin = (numMetaServers % servers_per_page);
           else
             llin = servers_per_page;
           
@@ -358,7 +379,7 @@ static int nMetaInput(int ch)
         {
           if ((cInfo.remotehost = strdup(metaServerList[i].altaddr)) == NULL)
             {
-              clog("strdup(metaServerList[i]) failed");
+              utLog("strdup(metaServerList[i]) failed");
               return NODE_EXIT;
             }
           cInfo.remoteport = metaServerList[i].port;
@@ -367,7 +388,7 @@ static int nMetaInput(int ch)
           nConsvrInit(cInfo.remotehost, cInfo.remoteport);
         }
       else
-        mglBeep();
+        mglBeep(MGL_BEEP_ERR);
 
       break;
       
