@@ -1,7 +1,7 @@
 /* 
  * meta node
  *
- * $Id: nMeta.h 552 2006-07-17 04:47:23Z jon $
+ * $Id: nMeta.h 725 2008-04-14 00:04:49Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -11,6 +11,6 @@
 
 #include "meta.h"
 
-void nMetaInit(metaSRec_t *metaServerList, int numserv);
+void nMetaInit(void);
 
 #endif /* _NMETA_H */
