@@ -1,7 +1,7 @@
 /* 
  * node
  *
- * $Id: nOptions.c 688 2006-11-27 22:34:45Z jon $
+ * $Id: nOptions.c 769 2008-08-17 06:41:00Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -18,6 +18,7 @@
 #include "node.h"
 #include "client.h"
 #include "clientlb.h"
+#include "conqutil.h"
 #include "prm.h"
 #include "nCP.h"
 #include "nMenu.h"
@@ -26,10 +27,6 @@
 #include "cqkeys.h"
 #include "cqsound.h"
 
-/* from conquestgl */
-extern Unsgn8 clientFlags;
-extern int lastServerError;
-
 static int retnode;             /* node to return to */
 static int uopts = FALSE;       /* are we doing user opts? */
 
@@ -61,8 +58,8 @@ static char *mmheader2 = "'a' = Alt, 'c' = Control 's' = Shift";
 static char *uheader = "User Configurable Options";
 static char *sheader = "System-wide Configurable Options";
 
-static char *meprompt = "Enter Conquest commands.  ([RETURN] = \\r, [TAB] = \\t)";
-static char *mmeprompt = "Enter Conquest commands.  ([RETURN] = \\r, [TAB] = \\t <angle> = \\a)";
+static char *meprompt = "Enter Conquest commands.  ([ENTER] = \\r, [TAB] = \\t)";
+static char *mmeprompt = "Enter Conquest commands.  ([ENTER] = \\r, [TAB] = \\t <angle> = \\a)";
 static char *eprompt = "Arrow keys to select an item, [SPACE] to change, any other key to quit.";
 static char *eprompt2 = "Type '?' for help on an item.";
 static char *mprompt = "Arrow keys to select a macro, [SPACE] to change, any other key to quit.";
@@ -286,7 +283,7 @@ static void _changeOption(struct Conf *cdata, int init)
     case CTYPE_STRING:
       if (cdata->max > CBUFLEN)
 	{
-	  clog("_changeOption: conf data max exceeds local buffer size.");
+	  utLog("_changeOption: conf data max exceeds local buffer size.");
 	  break;
 	}
 
@@ -353,13 +350,13 @@ static void _dispUserOptsMenu(void)
   if (macroptr == NULL)
     {				/* if this happens, something is
 				   seriously confused */
-      clog("_dispUserOptsMenu(): ERROR: macroptr == NULL, no CTYPE_MACRO found in ConfData");
+      utLog("_dispUserOptsMenu(): ERROR: macroptr == NULL, no CTYPE_MACRO found in ConfData");
     }
 
   if (mouseptr == NULL)
     {				/* if this happens, something is
 				   seriously confused */
-      clog("_dispUserOptsMenu(): ERROR: mouseptr == NULL, no CTYPE_MOUSE found in ConfData");
+      utLog("_dispUserOptsMenu(): ERROR: mouseptr == NULL, no CTYPE_MOUSE found in ConfData");
     }
 
   /* First clear the display. */
@@ -387,8 +384,8 @@ static void _dispUserOptsMenu(void)
   
   if (!prompting)
     {
-      clrPrompt(MSG_LIN1);
-      clrPrompt(MSG_LIN2);
+      hudClearPrompt(MSG_LIN1);
+      hudClearPrompt(MSG_LIN2);
       cprintf(MSG_LIN2, 0, ALIGN_NONE, prompt);
     }
   
@@ -598,7 +595,7 @@ static void _showOptScreen(void)
             }
           
 #ifdef DEBUG_OPTIONS
-          clog("_showOptScreen(): k = %d, dispmac = '%s'", 
+          utLog("_showOptScreen(): k = %d, dispmac = '%s'", 
                k, 
                dispmac);
 #endif
@@ -642,10 +639,10 @@ static void _showOptScreen(void)
             }
           
 #ifdef DEBUG_OPTIONS
-          clog("_showOptScreen(): k = %d, dispmac = '%s'", 
+          utLog("_showOptScreen(): k = %d, dispmac = '%s'", 
                k, 
                dispmac);
-          clog("\t: but = %d, mod = %d", 
+          utLog("\t: but = %d, mod = %d", 
                but, 
                mod);
 #endif
@@ -846,7 +843,7 @@ static int nOptionsIdle(void)
   int gtime = frameTime;
   static int old = 0;
   int pkttype;
-  Unsgn8 buf[PKT_MAXSIZE];
+  char buf[PKT_MAXSIZE];
   int sockl[2] = {cInfo.sock, cInfo.usock};
 
   /* 'blink' the cursor */
@@ -863,13 +860,13 @@ static int nOptionsIdle(void)
   if ((state == S_SYSMENU) || (state == S_SOPTS))
     return NODE_OK;             /* don't process packets is sys modes */
 
-  while ((pkttype = waitForPacket(PKT_FROMSERVER, sockl, PKT_ANYPKT,
+  while ((pkttype = pktWaitForPacket(PKT_FROMSERVER, sockl, PKT_ANYPKT,
                                   buf, PKT_MAXSIZE, 0, NULL)) > 0)
     processPacket(buf);
 
   if (pkttype < 0)          /* some error */
     {
-      clog("nOptionsIdle: waiForPacket returned %d", pkttype);
+      utLog("nOptionsIdle: waiForPacket returned %d", pkttype);
       Ships[Context.snum].status = SS_OFF;
       return NODE_EXIT;
     }
