@@ -1,7 +1,7 @@
 /* 
  * play node.  Sets up for the cockpit (CP).
  *
- * $Id: nPlay.c 693 2007-03-04 02:15:46Z jon $
+ * $Id: nPlay.c 769 2008-08-17 06:41:00Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -18,6 +18,7 @@
 #include "node.h"
 #include "client.h"
 #include "record.h"
+#include "conqutil.h"
 
 #include "nMenu.h"
 #include "nCP.h"
@@ -29,11 +30,9 @@
 #define S_SELSYS     2          /* select system */
 #define S_MENU       3          /* go back to menu */
 
-extern void processPacket(Unsgn8 *buf);
-
 static int state;
 static int fatal = FALSE;
-static spAck_t *sack = NULL;
+static spAck_t sack = {};
 static spClientStat_t scstat = {};
 static int shipinited = FALSE;   /* whether we've done _newship() yet */
 static int owned[NUMPLAYERTEAMS]; 
@@ -91,7 +90,7 @@ static void selectentry( Unsgn8 esystem )
 static int _newship( int unum, int *snum )
 {
   int pkttype;
-  Unsgn8 buf[PKT_MAXSIZE];
+  char buf[PKT_MAXSIZE];
   int sockl[2] = {cInfo.sock, cInfo.usock};
 
   /* here we will wait for ack's or a clientstat pkt. Acks indicate an
@@ -102,10 +101,10 @@ static int _newship( int unum, int *snum )
 
   while (TRUE)
     {
-      if ((pkttype = waitForPacket(PKT_FROMSERVER, sockl, PKT_ANYPKT,
+      if ((pkttype = pktWaitForPacket(PKT_FROMSERVER, sockl, PKT_ANYPKT,
 				   buf, PKT_MAXSIZE, 60, NULL)) < 0)
 	{
-	  clog("nPlay: _newship: waitforpacket returned %d", pkttype);
+	  utLog("nPlay: _newship: waitforpacket returned %d", pkttype);
           fatal = TRUE;
 	  return FALSE;
 	}
@@ -117,7 +116,8 @@ static int _newship( int unum, int *snum )
 	  break;
 	  
 	case SP_ACK:		/* bummer */
-	  sack = (spAck_t *)buf;
+          /* copy it */
+	  sack = *((spAck_t *)buf);
           state = S_NSERR;
 	  
 	  return FALSE;		/* always a failure */
@@ -139,7 +139,7 @@ static int _newship( int unum, int *snum )
               }
             else
               {
-                clog("nPlay: _newship: invalid CLIENTSTAT");
+                utLog("nPlay: _newship: invalid CLIENTSTAT");
                 return FALSE;
               }
           }
@@ -204,37 +204,39 @@ static int nPlayDisplay(dspConfig_t *dsp)
     }
   else if (state == S_NSERR)
     {
-      if (sack)
+      switch (sack.code)
         {
-          switch (sack->code)
-            {
-            case PERR_FLYING:
-              sprintf(cbuf, "You're already playing on another ship.");
-              cprintf(5,0,ALIGN_CENTER,"#%d#%s",InfoColor, cbuf);
-              Ships[Context.snum].status = SS_RESERVED;
-              break;
-              
-            case PERR_TOOMANYSHIPS:
-              i = MSG_LIN2/2;
-              cprintf(i, 0, ALIGN_CENTER, 
-                      "I'm sorry, but you're playing on too many ships right now.");
-              i = i + 1;
-              c_strcpy( "You are only allowed to fly ", cbuf );
-              j = Users[Context.unum].multiple;
-              appint( j, cbuf );
-              appstr( " ship", cbuf );
-              if ( j != 1 )
-                appchr( 's', cbuf );
-              appstr( " at one time.", cbuf );
-              cprintf(i, 0, ALIGN_CENTER, cbuf);
-              break;
-              
-            default:
-              clog("nPlayDisplay: _newship: unexpected ack code %d",
-                   sack->code);
-              break;
-            }
+        case PERR_FLYING:
+          sprintf(cbuf, "You're already playing on another ship.");
+          cprintf(5,0,ALIGN_CENTER,"#%d#%s",InfoColor, cbuf);
+          Ships[Context.snum].status = SS_RESERVED;
+          break;
+          
+        case PERR_TOOMANYSHIPS:
+          i = MSG_LIN2/2;
+          cprintf(i, 0, ALIGN_CENTER, 
+                  "I'm sorry, but you're playing on too many ships right now.");
+          i = i + 1;
+          c_strcpy( "You are only allowed to fly ", cbuf );
+          j = Users[Context.unum].multiple;
+          utAppendInt( j, cbuf );
+          appstr( " ship", cbuf );
+          if ( j != 1 )
+            appchr( 's', cbuf );
+          appstr( " at one time.", cbuf );
+          cprintf(i, 0, ALIGN_CENTER, cbuf);
+          break;
+          
+        default:
+          cprintf(5,0,ALIGN_CENTER,
+                  "#%d#nPlay: _newship: unexpected server ack, code %d",
+                  InfoColor, sack.code);
+          utLog("nPlay: _newship: unexpected server ack, code %d",
+                sack.code);
+          break;
         }
+      /* Press any key... */
+      cprintf(MSG_LIN2, 0, ALIGN_CENTER, MTXT_DONE);
     }
 
 
@@ -247,17 +249,17 @@ static int nPlayIdle(void)
     {
       Context.entship = TRUE;
       Ships[Context.snum].sdfuse = 0;       /* zero self destruct fuse */
-      grand( &Context.msgrand );            /* initialize message timer */
+      utGrand( &Context.msgrand );            /* initialize message timer */
       Context.leave = FALSE;                /* assume we won't want to bail */
       Context.redraw = TRUE;                /* want redraw first time */
-      Context.msgok = TRUE;         /* ok to get messages */
+      Context.msgok = TRUE;                 /* ok to get messages */
       
       Context.display = TRUE;               /* ok to display */
       
       /* start recording if neccessary */
       if (Context.recmode == RECMODE_STARTING)
         {
-          if (recordInitOutput(Context.unum, getnow(NULL, 0), Context.snum,
+          if (recInitOutput(Context.unum, getnow(NULL, 0), Context.snum,
                                FALSE))
             {
               Context.recmode = RECMODE_ON;
