@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: nUserl.c 552 2006-07-17 04:47:23Z jon $
+ * $Id: nUserl.c 769 2008-08-17 06:41:00Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -17,6 +17,7 @@
 #include "node.h"
 #include "client.h"
 #include "packet.h"
+#include "conqutil.h"
 
 #include "nCP.h"
 #include "nMenu.h"
@@ -24,10 +25,6 @@
 #include "nUserl.h"
 #include "cqkeys.h"
 
-/* from conquestgl */
-extern Unsgn8 clientFlags; 
-extern int lastServerError;
-
 static int snum, godlike;
 static int uvec[MAXUSERS];
 static int nu;
@@ -178,16 +175,16 @@ static int nUserlDisplay(dspConfig_t *dsp)
 static int nUserlIdle(void)
 {
   int pkttype;
-  Unsgn8 buf[PKT_MAXSIZE];
+  char buf[PKT_MAXSIZE];
   int sockl[2] = {cInfo.sock, cInfo.usock};
 
-  while ((pkttype = waitForPacket(PKT_FROMSERVER, sockl, PKT_ANYPKT,
+  while ((pkttype = pktWaitForPacket(PKT_FROMSERVER, sockl, PKT_ANYPKT,
                                   buf, PKT_MAXSIZE, 0, NULL)) > 0)
     processPacket(buf);
 
   if (pkttype < 0)          /* some error */
     {
-      clog("nUserlIdle: waiForPacket returned %d", pkttype);
+      utLog("nUserlIdle: waiForPacket returned %d", pkttype);
       Ships[Context.snum].status = SS_OFF;
       return NODE_EXIT;
     }
@@ -228,7 +225,7 @@ static int nUserlInput(int ch)
     {
     case DSP_NODE_CP:
       setONode(NULL);
-      nCPInit();
+      nCPInit(FALSE);
       break;
     case DSP_NODE_MENU:
       setONode(NULL);
@@ -236,7 +233,7 @@ static int nUserlInput(int ch)
       break;
 
     default:
-      clog("nUserlInput: invalid return node: %d, going to DSP_NODE_MENU",
+      utLog("nUserlInput: invalid return node: %d, going to DSP_NODE_MENU",
            retnode);
       setONode(NULL);
       nMenuInit();
