@@ -4,7 +4,7 @@
  *
  * sem.c - semaphore operations on the common block. Finally.
  *
- * $Id: sem.c 552 2006-07-17 04:47:23Z jon $
+ * $Id: sem.c 762 2008-07-23 02:14:59Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -25,6 +25,7 @@
 #include "global.h"
 #include "conqcom.h"
 #include "conqlb.h"
+#include "conqutil.h"
 
 #define CONQSEMKEY   (0xff001701) /* hope that's unique! */
 #define CONQSEMPERMS (00664)
@@ -56,7 +57,7 @@ int semInit(void)
   if (ConquestSemID == -1)
     {				/* already exists? */
 #ifdef DEBUG_SEM
-      clog("semInit(): semget(IPC_CREAT): failed: %s",
+      utLog("semInit(): semget(IPC_CREAT): failed: %s",
 	   strerror(errno));
 #endif
 
@@ -67,7 +68,7 @@ int semInit(void)
       if (ConquestSemID == -1)
 	{
 #ifdef DEBUG_SEM
-	  clog("semInit(): semget(GET): failed: %s",
+	  utLog("semInit(): semget(GET): failed: %s",
 	       strerror(errno));
 #endif
 
@@ -82,7 +83,7 @@ int semInit(void)
 
 
 #if defined(DEBUG_FLOW) || defined(DEBUG_SEM)
-  clog("semInit(): semget(GET): succeeded, semaphore ID is %d",
+  utLog("semInit(): semget(GET): succeeded, semaphore ID is %d",
        ConquestSemID);
 #endif
   
@@ -99,9 +100,9 @@ void Lock(int what)
     return;			/* clients don't use sems... */
 
 #ifdef DEBUG_SEM
-  clog("Lock(%s): Attempting to aquire a lock.",
+  utLog("Lock(%s): Attempting to aquire a lock.",
        semGetName(what));
-  clog("Lock(%s): %s", semGetName(what), semGetStatusStr());
+  utLog("Lock(%s): %s", semGetName(what), semGetStatusStr());
 #endif
 
   Done = FALSE;
@@ -127,7 +128,7 @@ void Lock(int what)
 	    int err;
 
 	    err = errno;
-	    clog("Lock(%s): semop(): failed: %s",
+	    utLog("Lock(%s): semop(): failed: %s",
 		 semGetName(what),
 		 strerror(err));
 	    fprintf(stderr, "Lock(%s): semop(): failed: %s\n",
@@ -138,7 +139,7 @@ void Lock(int what)
 	  }
 	else
 	  {
-	    clog("Lock(%s): semop(): interrupted. Retrying lock attempt.", semGetName(what));
+	    utLog("Lock(%s): semop(): interrupted. Retrying lock attempt.", semGetName(what));
 	  }
       }
       else			/* we got a successful lock */
@@ -146,7 +147,7 @@ void Lock(int what)
     }
 
 #ifdef DEBUG_SEM
-  clog("Lock(%s): semop(): succeeded, got a lock",
+  utLog("Lock(%s): semop(): succeeded, got a lock",
        semGetName(what));
 #endif
 
@@ -167,22 +168,22 @@ void Unlock(int what)
   if (ConquestSemID == -1)
     return;			/* clients don't use sems... */
 
-  arg.array = semvals;
 
 #ifdef DEBUG_SEM
-  clog("Unlock(%s): Attempting to free a lock.",
+  utLog("Unlock(%s): Attempting to free a lock.",
        semGetName(what));
-  clog("Unlock(%s): %s", semGetName(what), semGetStatusStr());
+  utLog("Unlock(%s): %s", semGetName(what), semGetStatusStr());
 #endif
 
 
-				/* get the values of the semaphores */
+  /* get the values of the semaphores */
+  arg.array = semvals;
   retval = semctl(ConquestSemID, 0, GETALL, arg);
   
   if (retval != 0)
     {				/* couldn't get semvals */
 #if !defined(CYGWIN)
-      clog("Unlock(%s): semctl(GETALL) failed: %s",
+      utLog("Unlock(%s): semctl(GETALL) failed: %s",
 	   semGetName(what),
 	   strerror(errno));
 #endif
@@ -192,7 +193,7 @@ void Unlock(int what)
 				/* check to see if already unlocked */
       if (semvals[what] == 0)	/* sem already unlocked - report and continue */
 	{
-	  clog("Unlock(%s): semaphore already unlocked.",
+	  utLog("Unlock(%s): semaphore already unlocked.",
 	       semGetName(what));
 	  
           /* allow alarms again */
@@ -211,7 +212,7 @@ void Unlock(int what)
     {
       if (errno != EINTR)
 	{
-	  clog("Unlock(%s): semop(): failed: %s",
+	  utLog("Unlock(%s): semop(): failed: %s",
 	       semGetName(what),
 	       strerror(errno));
 	  fprintf(stderr,"Unlock(%s): semop(): failed: %s",
@@ -221,7 +222,7 @@ void Unlock(int what)
 	}
       else
 	{
-	  clog("Unlock(%s): semop(): interrupted. continuing...", semGetName(what));
+	  utLog("Unlock(%s): semop(): interrupted. continuing...", semGetName(what));
 	  err = EINTR;
 	}
     }
@@ -229,7 +230,7 @@ void Unlock(int what)
 				/* hopefully we got a lock */
 #ifdef DEBUG_SEM
   if (!err)
-    clog("Unlock(%s): semop(): succeeded, removed lock",
+    utLog("Unlock(%s): semop(): succeeded, removed lock",
 	 semGetName(what));
 #endif
 
@@ -258,10 +259,6 @@ char *semGetStatusStr(void)
     ushort *array;
   } arg;
 
-				/* get the values of the semaphores */
-  arg.array = semvals;
-  retval = semctl(ConquestSemID, 0, GETALL, arg);
-
 #if defined(CYGWIN)
   /* apparently not implemented */
   lastcmnpid = 0;
@@ -270,32 +267,25 @@ char *semGetStatusStr(void)
   msgzcnt = 0;
 #else /* !CYGWIN */
 
-  lastcmnpid = semctl(ConquestSemID, LOCKCMN, GETPID, semvals);
-  cmnzcnt = semctl(ConquestSemID, LOCKCMN, GETZCNT, semvals);
-  lastmsgpid = semctl(ConquestSemID, LOCKMSG, GETPID, semvals);
-  msgzcnt = semctl(ConquestSemID, LOCKMSG, GETZCNT, semvals);
+  lastcmnpid = semctl(ConquestSemID, LOCKCMN, GETPID, arg);
+  cmnzcnt = semctl(ConquestSemID, LOCKCMN, GETZCNT, arg);
+  lastmsgpid = semctl(ConquestSemID, LOCKMSG, GETPID, arg);
+  msgzcnt = semctl(ConquestSemID, LOCKMSG, GETZCNT, arg);
 #endif
-  retval = semctl(ConquestSemID, 0, GETALL, semvals);
-
-  if (retval != 0)
-    {
-      clog("semGetStatusStr(): semctl(GETALL) failed: %s",
-	   strerror(errno));
-    }
 
  
-  arg.buf = &SemDS;
-
 #if defined(CYGWIN)
   /* these do not appear to be implemented in cygwin */
   lastoptime = 0;
 #else /* !CYGWIN */    
-				/* get latest semop time  */
+
+  /* get latest semop time  */
+  arg.buf = &SemDS;
   retval = semctl(ConquestSemID, LOCKMSG, IPC_STAT, arg);
 
   if (retval != 0)
     {
-      clog("semGetStatusStr(): %s semctl(IPC_STAT) failed: %s",
+      utLog("semGetStatusStr(): %s semctl(IPC_STAT) failed: %s",
            semGetName(LOCKMSG),
 	   strerror(errno));
     }
@@ -306,7 +296,7 @@ char *semGetStatusStr(void)
 
   if (retval != 0)
     {
-      clog("semGetStatusStr(%d): %s semctl(IPC_STAT) failed: %s",
+      utLog("semGetStatusStr(%d): %s semctl(IPC_STAT) failed: %s",
            semGetName(LOCKCMN),
 	   strerror(errno));
     }
@@ -314,22 +304,35 @@ char *semGetStatusStr(void)
   lastoptime = max(lastoptime, SemDS.sem_otime);
 #endif
 
-  if (semvals[LOCKMSG] != 0)	/* currently locked */
-    sprintf(mesgtxt, "*MesgCnt = %d(%d:%d)", ConqInfo->lockmesg, lastmsgpid, msgzcnt);
-  else
-    sprintf(mesgtxt, "MesgCnt = %d(%d:%d)", ConqInfo->lockmesg, lastmsgpid, msgzcnt);
+  /* get the values of the semaphores */
+  arg.array = semvals;
+  retval = semctl(ConquestSemID, 0, GETALL, arg);
 
-  if (semvals[LOCKCMN] != 0)
-    sprintf(wordtxt, "*CmnCnt = %d(%d:%d)", ConqInfo->lockword, lastcmnpid, cmnzcnt);
-  else
-    sprintf(wordtxt, "CmnCnt = %d(%d:%d)", ConqInfo->lockword, lastcmnpid, cmnzcnt);
+  if (retval != 0)
+    {
+      utLog("semGetStatusStr(): semctl(GETALL) failed: %s",
+	   strerror(errno));
+    }
+
+
+  snprintf(mesgtxt, 80 - 1, "%sMesgCnt = %d(%d:%d)", 
+           (semvals[LOCKMSG]) ? "*" : "",
+           ConqInfo->lockmesg, 
+           lastmsgpid, 
+           msgzcnt);
+
+  snprintf(wordtxt, 80 - 1, "%sCmnCnt = %d(%d:%d)", 
+           (semvals[LOCKCMN]) ? "*" : "",
+           ConqInfo->lockword, 
+           lastcmnpid, 
+           cmnzcnt);
 
   strcpy(stimebuffer, ctime(&lastoptime));
   strncpy(newtime, &stimebuffer[4], 15); /* get the interesting part */
 
 				/* now build the string */
 
-  sprintf(buf, "%s %s Last: %s",
+  snprintf(buf, 80 - 1, "%s %s Last: %s",
 	  mesgtxt,
 	  wordtxt,
 	  newtime);
