@@ -1,7 +1,7 @@
 /* 
  * userauth.c - user stuff
  *
- * $Id: servauth.c 688 2006-11-27 22:34:45Z jon $
+ * $Id: servauth.c 762 2008-07-23 02:14:59Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -11,6 +11,7 @@
 #include "conqdef.h"
 #include "conqcom.h"
 #include "conqlb.h"
+#include "conqutil.h"
 #include "context.h"
 #include "conf.h"
 #include "color.h"
@@ -45,11 +46,11 @@ static int doLogin(char *login, char *pw, char *epw)
       
       if (strcmp(epw, Users[unum].pw) != 0)
 	{			/* invalid pw */
-	  clog("INFO: Invalid password for user '%s'", login);
+	  utLog("INFO: Invalid password for user '%s'", login);
 	  return PERR_BADPWD;
 	}
 
-      clog("INFO: user '%s' logged in", login);
+      utLog("INFO: user '%s' logged in", login);
       return PERR_OK;		/* it's all good */
     }
 
@@ -62,7 +63,7 @@ static int doLogin(char *login, char *pw, char *epw)
   strncpy(epw, (char *)crypt(pw, salt), MAXUSERNAME - 2);
   epw[MAXUSERNAME - 1] = EOS;
 
-  clog("INFO: New user '%s' logged in", login);
+  utLog("INFO: New user '%s' logged in", login);
   
   return PERR_OK;
 }
@@ -74,7 +75,7 @@ int Authenticate(char *username, char *password)
 {
   cpAuthenticate_t *cauth;
   int unum;
-  Unsgn8 buf[PKT_MAXSIZE];
+  char buf[PKT_MAXSIZE];
   int done, rv;
   char epw[MAXUSERNAME];
   int logcount = 3;
@@ -83,19 +84,19 @@ int Authenticate(char *username, char *password)
   expire_users();		/* now is a good time to expire users */
 
 #if defined(DEBUG_SERVERAUTH)
-  clog("INFO: Authenticate ENTERING\n");
+  utLog("INFO: Authenticate ENTERING\n");
 #endif
 
   done = FALSE;
 
   while (!done)
     {
-      rv = waitForPacket(PKT_FROMCLIENT, sockl, CP_AUTHENTICATE, 
+      rv = pktWaitForPacket(PKT_FROMCLIENT, sockl, CP_AUTHENTICATE, 
 			 buf, PKT_MAXSIZE, (60 * 10), "Waiting for Auth");
 
       if (rv <= 0)
 	{
-	  clog("conquestd:Authenticate: waitforpacket returned %d", rv);
+	  utLog("conquestd:Authenticate: waitforpacket returned %d", rv);
 	  return FALSE;
 	}
 
@@ -103,9 +104,9 @@ int Authenticate(char *username, char *password)
       cauth->login[MAXUSERNAME - 1] = 0;
       cauth->pw[MAXUSERNAME - 1] = 0;
 
-      if (checkuname(cauth->login) == FALSE)
+      if (checkuname((char *)cauth->login) == FALSE)
 	{
-	  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_ERROR, PERR_INVUSER,
+	  pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_ERROR, PERR_INVUSER,
 		  NULL);
 	  continue;
 	}
@@ -114,14 +115,14 @@ int Authenticate(char *username, char *password)
 	{
 	case CPAUTH_CHECKUSER:
 
-	  if (clbGetUserNum( &unum, cauth->login, 0 ) == TRUE)
+	  if (clbGetUserNum( &unum, (char *)cauth->login, 0 ) == TRUE)
 	    {			/* user exits */
-	      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_OK,
+	      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_OK,
 		      NULL);
 	    }
 	  else
 	    {
-	      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_ERROR, PERR_NOUSER,
+	      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_ERROR, PERR_NOUSER,
 		      NULL);
 	    }
 
@@ -131,34 +132,35 @@ int Authenticate(char *username, char *password)
 
 	  if (logcount <= 0)	/* too many tries, fail */
 	    {
-	      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_FATAL, PERR_BADPWD,
+	      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_FATAL, PERR_BADPWD,
                       NULL);
 	      return FALSE;
 	    }
 
-	  if ((rv = doLogin(cauth->login, cauth->pw, epw)) != PERR_OK)
+	  if ((rv = doLogin((char *)cauth->login, (char *)cauth->pw, 
+                            epw)) != PERR_OK)
 	    {			/* somethings wrong, bad/inv pw, etc */
-	      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_ERROR, rv,
+	      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_ERROR, rv,
 		      NULL);
 	      logcount--;
 	    }
 	  else
 	    {			/* login successful */
 	      done = TRUE;
-	      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_OK,
+	      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_OK,
                       NULL);
 	    }
 
 	  break;
 
 	default:
-	  clog("servauth: invalid auth flag %d\n",
+	  utLog("servauth: invalid auth flag %d\n",
 	       cauth->flag);
 	  break;
 	}
     }
 
-  strncpy(username, cauth->login, MAXUSERNAME);
+  strncpy(username, (char *)cauth->login, MAXUSERNAME);
   strncpy(password, epw, MAXUSERNAME);
 
   return(TRUE);
@@ -175,13 +177,13 @@ void expire_users(void)
   unsigned int expire_secs;
 
 #if defined(DEBUG_SERVERAUTH)
-  clog("INFO: expire_users(): Expiring users...");
+  utLog("INFO: expire_users(): Expiring users...");
 #endif
 
   if (SysConf.UserExpiredays == 0)
     {				/* expiration has been disabled */
 #if defined(DEBUG_SERVERAUTH)
-      clog("INFO: expire_users(): SysConf.UserExpiredays == 0, expiration disabled");
+      utLog("INFO: expire_users(): SysConf.UserExpiredays == 0, expiration disabled");
 #endif
 
       return;
@@ -206,13 +208,13 @@ void expire_users(void)
 	{			/* screen out negative expirations -
 				   only happens when system clock goes
 				   way back */
-	  clog("INFO: expire_users(): difftime (%d) is less than 0, skipping user %s\n",
+	  utLog("INFO: expire_users(): difftime (%d) is less than 0, skipping user %s\n",
 	       difftime, Users[i].username);
 	  continue;
 	}
 
 #if defined(DEBUG_SERVERAUTH)
-          clog("expire_users(): getnow(NULL, 0) = %d, Users[%d].lastentry = %d",
+          utLog("expire_users(): getnow(NULL, 0) = %d, Users[%d].lastentry = %d",
 	       getnow(NULL, 0),
 	       i, Users[i].lastentry);
 #endif
@@ -224,7 +226,7 @@ void expire_users(void)
 				   doesn't have one active */
 
 #if defined(DEBUG_SERVERAUTH)
-	  clog("expire_users(): have a candidate: user '%s' (%d), difftime = %d > expire_secs = %d, Users[i].lastentry = %d",
+	  utLog("expire_users(): have a candidate: user '%s' (%d), difftime = %d > expire_secs = %d, Users[i].lastentry = %d",
 	       Users[i].username,
 	       i,
 	       difftime,
@@ -244,7 +246,7 @@ void expire_users(void)
 
 	  if (hasship)
 	    {			/* we can't waste him */
-	      clog("INFO: expire_users(): Couldn't expire remote user '%s' due to active ship(s)",
+	      utLog("INFO: expire_users(): Couldn't expire remote user '%s' due to active ship(s)",
 		   Users[i].username);
 	    }
 	  else
@@ -254,11 +256,11 @@ void expire_users(void)
 	      PVUNLOCK(&ConqInfo->lockword);
 
 #if defined(DEBUG_SERVERAUTH)
-	      clog("expire_users(): calling clbResign(%d, %d)", i, TRUE);
+	      utLog("expire_users(): calling clbResign(%d, %d)", i, TRUE);
 #endif
 
 	      clbResign(i, TRUE);
-	      clog("INFO: expire_users(): Expired remote user '%s' after %d days of inactivity. (limit %d days)",
+	      utLog("INFO: expire_users(): Expired remote user '%s' after %d days of inactivity. (limit %d days)",
 		   Users[i].username,
 		   difftime / SECS_PER_DAY,
                    SysConf.UserExpiredays);
@@ -272,7 +274,7 @@ void expire_users(void)
   PVUNLOCK(&ConqInfo->lockword);
 
 #if defined(DEBUG_SERVERAUTH)
-    clog("expire_users(): ...Done");
+    utLog("expire_users(): ...Done");
 #endif
 
   return;
