@@ -1,7 +1,7 @@
 /* 
  * server auth
  *
- * $Id: servauth.h 552 2006-07-17 04:47:23Z jon $
+ * $Id: servauth.h 762 2008-07-23 02:14:59Z jon13 $
  *
  * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -13,14 +13,6 @@
 #include "datatypes.h"
 #include "protocol.h"
 
-#ifdef SERVAUTH_NOEXTERN
-# define EXTERNAL extern
-#else
-# define EXTERNAL
-#endif
-
-#undef EXTERNAL
-
 int Authenticate(char *name, char *password);
 
 
