@@ -4,7 +4,7 @@
  *
  * server specific stuff
  *
- * $Id: server.c 565 2006-07-24 05:00:20Z jon $
+ * $Id: server.c 762 2008-07-23 02:14:59Z jon13 $
  *
  * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -12,6 +12,7 @@
 #include "conqdef.h"
 #include "conqcom.h"
 #include "conqlb.h"
+#include "conqutil.h"
 #include "conf.h"
 #include "server.h"
 #include "serverpkt.h"
@@ -34,7 +35,7 @@ static void handleUDPErr(void)
       sInfo.doUDP = FALSE;
       close(sInfo.usock);
       sInfo.usock = -1;
-      clog("NET: too many UDP send errors to client, switching to TCP");
+      utLog("NET: too many UDP send errors to client, switching to TCP");
       clbStoreMsg(MSG_COMP, Context.snum, 
               "SERVER: too many UDP send errors. Switching to TCP");
     }
@@ -49,7 +50,7 @@ int sendClientStat(int sock, Unsgn8 flags, Unsgn8 snum, Unsgn8 team,
   memset((void *)&scstat, 0, sizeof(spClientStat_t));
 
 #if defined(DEBUG_SERVERCLNTSTAT)
-  clog("sendClientStat: snum = %d, unum = %d, flags = 0x%x, team = %d",
+  utLog("sendClientStat: snum = %d, unum = %d, flags = 0x%x, team = %d",
        snum, unum, flags, team);
 #endif
 
@@ -60,7 +61,7 @@ int sendClientStat(int sock, Unsgn8 flags, Unsgn8 snum, Unsgn8 team,
   scstat.unum = htons(unum);
   scstat.esystem = esystem;
 
-  if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)&scstat) <= 0)
+  if (pktWrite(PKT_TOCLIENT, sock, &scstat) <= 0)
     return FALSE;
   else
     return TRUE;
@@ -71,18 +72,18 @@ int sendUser(int sock, Unsgn16 unum)
   spUser_t *suser;
 
 #if defined(DEBUG_SERVERSEND)
-  clog("sendUser: unum = %d",
+  utLog("sendUser: unum = %d",
        unum);
 #endif
 
   /* not really any priv bits, but in case we add some later */
   if ((suser = spktUser(unum)))
     {
-      if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)suser) <= 0)
+      if (pktWrite(PKT_TOCLIENT, sock, suser) <= 0)
         return FALSE;
 
       if (Context.recmode == RECMODE_ON)
-        recordWriteEvent((Unsgn8 *)suser);
+        recWriteEvent(suser);
     }
 
   return TRUE;
@@ -96,7 +97,7 @@ int sendShip(int sock, Unsgn8 snum)
   spShipLoc_t *sshiploc;
 
 #if defined(DEBUG_SERVERSEND)
-  clog("sendShip: snum = %d",
+  utLog("sendShip: snum = %d",
        snum);
 #endif
 
@@ -104,22 +105,22 @@ int sendShip(int sock, Unsgn8 snum)
   if (Context.recmode == RECMODE_ON)
     {
       if ((sship = spktShip(snum, TRUE)))
-        recordWriteEvent((Unsgn8 *)sship);
+        recWriteEvent(sship);
     }
 
   if ((sship = spktShip(snum, FALSE)))
-    if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)sship) <= 0)
+    if (pktWrite(PKT_TOCLIENT, sock, sship) <= 0)
       return FALSE;
 
   /* SP_SHIPSML */
   if (Context.recmode == RECMODE_ON)
     {
       if ((sshipsml = spktShipSml(snum, TRUE)))
-        recordWriteEvent((Unsgn8 *)sshipsml);
+        recWriteEvent(sshipsml);
     }
 
   if ((sshipsml = spktShipSml(snum, FALSE)))
-    if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)sshipsml) <= 0)
+    if (pktWrite(PKT_TOCLIENT, sock, sshipsml) <= 0)
       return FALSE;
 
   /* SP_SHIPLOC */
@@ -127,14 +128,14 @@ int sendShip(int sock, Unsgn8 snum)
   if (Context.recmode == RECMODE_ON)
     {
       if ((sshiploc = spktShipLoc(snum, TRUE)))
-        recordWriteEvent((Unsgn8 *)sshiploc);
+        recWriteEvent(sshiploc);
     }
   
   if ((sshiploc = spktShipLoc(snum, FALSE)))
     {
       if (sInfo.doUDP)
         {
-          if (writePacket(PKT_TOCLIENT, sInfo.usock, (Unsgn8 *)sshiploc) <= 0)
+          if (pktWrite(PKT_TOCLIENT, sInfo.usock, sshiploc) <= 0)
             {
               handleUDPErr();
               return FALSE;
@@ -142,7 +143,7 @@ int sendShip(int sock, Unsgn8 snum)
         }
       else
         {
-          if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)sshiploc) <= 0)
+          if (pktWrite(PKT_TOCLIENT, sock, sshiploc) <= 0)
             return FALSE;
         }
     }
@@ -159,7 +160,7 @@ int sendPlanet(int sock, Unsgn8 pnum, int force)
   spPlanetInfo_t *splaninfo;
 
 #if defined(DEBUG_SERVERSEND)
-  clog("sendPlanet: pnum = %d",
+  utLog("sendPlanet: pnum = %d",
        pnum);
 #endif
 
@@ -167,33 +168,33 @@ int sendPlanet(int sock, Unsgn8 pnum, int force)
   if (Context.recmode == RECMODE_ON)
     {
       if ((splan = spktPlanet(pnum, TRUE)))
-        recordWriteEvent((Unsgn8 *)splan);
+        recWriteEvent(splan);
     }
 
   if ((splan = spktPlanet(pnum, FALSE)))
-    if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)splan) <= 0)
+    if (pktWrite(PKT_TOCLIENT, sock, splan) <= 0)
       return FALSE;
 
   /* SP_PLANETSML */
   if (Context.recmode == RECMODE_ON)
     {
       if ((splansml = spktPlanetSml(pnum, TRUE)))
-        recordWriteEvent((Unsgn8 *)splansml);
+        recWriteEvent(splansml);
     }
 
   if ((splansml = spktPlanetSml(pnum, FALSE)))
-    if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)splansml) <= 0)
+    if (pktWrite(PKT_TOCLIENT, sock, splansml) <= 0)
       return FALSE;
 
   /* SP_PLANETINFO */
   if (Context.recmode == RECMODE_ON)
     {
       if ((splaninfo = spktPlanetInfo(pnum, TRUE)))
-        recordWriteEvent((Unsgn8 *)splaninfo);
+        recWriteEvent(splaninfo);
     }
 
   if ((splaninfo = spktPlanetInfo(pnum, FALSE)))
-    if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)splaninfo) <= 0)
+    if (pktWrite(PKT_TOCLIENT, sock, splaninfo) <= 0)
       return FALSE;
 
   /* we will do loc packets for recording purposes only.  loc2 is sent
@@ -204,12 +205,12 @@ int sendPlanet(int sock, Unsgn8 pnum, int force)
   if (Context.recmode == RECMODE_ON)
     {
       if ((splanloc = spktPlanetLoc(pnum, TRUE, force)))
-        recordWriteEvent((Unsgn8 *)splanloc);
+        recWriteEvent(splanloc);
     }
 
   /* SP_PLANETLOC2 */
   if ((splanloc2 = spktPlanetLoc2(pnum, FALSE, force)))
-    if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)splanloc2) <= 0)
+    if (pktWrite(PKT_TOCLIENT, sock, splanloc2) <= 0)
       return FALSE;
 
   return TRUE;
@@ -229,7 +230,7 @@ int sendServerStat(int sock)
   memset((void *)&sStat, 0, sizeof(spServerStat_t));
 
 #if defined(DEBUG_SERVERSEND)
-  clog("sendServerStats: ENTER");
+  utLog("sendServerStats: ENTER");
 #endif
 
   /* get total users */
@@ -271,9 +272,9 @@ int sendServerStat(int sock)
 
   sStat.servertime = (Unsgn32)htonl(getnow(NULL, 0));
   
-  if (!writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)&sStat))
+  if (!pktWrite(PKT_TOCLIENT, sock, &sStat))
     {
-      clog("sendServerStats: writePacket failed\n");
+      utLog("sendServerStats: pktWrite failed\n");
       return FALSE;
     }
 
@@ -297,7 +298,7 @@ int sendTorp(int sock, Unsgn8 tsnum, Unsgn8 tnum)
     return FALSE;
 
 #if defined(DEBUG_SERVERSEND)
-  clog("sendTorp: %d %d", tsnum, tnum);
+  utLog("sendTorp: %d %d", tsnum, tnum);
 #endif
 
 
@@ -306,13 +307,13 @@ int sendTorp(int sock, Unsgn8 tsnum, Unsgn8 tnum)
     {
       if ((storpev = spktTorpEvent(tsnum, tnum, TRUE)))
         {
-          recordWriteEvent((Unsgn8 *)storpev);
+          recWriteEvent(storpev);
         }
     }
 
   if ((storpev = spktTorpEvent(tsnum, tnum, FALSE)))
     {
-      if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)storpev) <= 0)
+      if (pktWrite(PKT_TOCLIENT, sock, storpev) <= 0)
         return FALSE;
     }
 
@@ -321,7 +322,7 @@ int sendTorp(int sock, Unsgn8 tsnum, Unsgn8 tnum)
   if (Context.recmode == RECMODE_ON)
     {
       if ((storp = spktTorp(tsnum, tnum, TRUE)))
-        recordWriteEvent((Unsgn8 *)storp);
+        recWriteEvent(storp);
     }
 
   /* SP_TORPLOC */
@@ -330,7 +331,7 @@ int sendTorp(int sock, Unsgn8 tsnum, Unsgn8 tnum)
   if (Context.recmode == RECMODE_ON)
     {
       if ((storploc = spktTorpLoc(tsnum, tnum, TRUE)))
-        recordWriteEvent((Unsgn8 *)storploc);
+        recWriteEvent(storploc);
     }
 
   return TRUE;
@@ -357,7 +358,7 @@ void sendFeedback(char *msg)
   if (SysConf.LogMessages == TRUE)
     {
       clbFmtMsg(themsg.msgto, themsg.msgfrom, buf);
-      clog("MSG:FEEDBACK: %s: %s",
+      utLog("MSG:FEEDBACK: %s: %s",
            buf, themsg.msgbuf);
     }
 
@@ -378,7 +379,7 @@ int sendMessage(Msg_t *msg)
   memset((void *)&smsg, 0, sizeof(spMessage_t));
 
 #if defined(DEBUG_SERVERSEND) 
-  clog("sendMessage: to = %d, from = %d, flags = 0x%02x, msg = '%s'",
+  utLog("sendMessage: to = %d, from = %d, flags = 0x%02x, msg = '%s'",
        msg->msgto, msg->msgfrom, msg->flags, msg->msgbuf);
 #endif
 
@@ -388,16 +389,16 @@ int sendMessage(Msg_t *msg)
   smsg.to = (Sgn16)htons(msg->msgto);
   smsg.flags = msg->flags;
   
-  strncpy(smsg.msg, msg->msgbuf, MESSAGE_SIZE - 1);
+  strncpy((char *)smsg.msg, msg->msgbuf, MESSAGE_SIZE - 1);
 
   /* don't record feeback or tersable msgs */
   if (Context.recmode == RECMODE_ON)
     if (!(smsg.flags & (MSG_FLAGS_FEEDBACK | MSG_FLAGS_TERSABLE)))
-      recordWriteEvent((Unsgn8 *)&smsg);
+      recWriteEvent(&smsg);
 
-  if (!writePacket(PKT_TOCLIENT, sInfo.sock, (Unsgn8 *)&smsg))
+  if (!pktWrite(PKT_TOCLIENT, sInfo.sock, &smsg))
     {
-      clog("sendMessage: writePacket failed\n");
+      utLog("sendMessage: pktWrite failed\n");
       return FALSE;
     }
 
@@ -409,17 +410,17 @@ int sendTeam(int sock, Unsgn8 team, int force)
   spTeam_t *steam;
 
 #if defined(DEBUG_SERVERSEND)
-  clog("sendTeam: team = %d, f = %d", team, force);
+  utLog("sendTeam: team = %d, f = %d", team, force);
 #endif
 
   if (Context.recmode == RECMODE_ON)
     {
       if ((steam = spktTeam(team, force, TRUE)))
-        recordWriteEvent((Unsgn8 *)steam);
+        recWriteEvent(steam);
     }
 
   if ((steam = spktTeam(team, force, FALSE)))
-    if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)steam) <= 0)
+    if (pktWrite(PKT_TOCLIENT, sock, steam) <= 0)
       return FALSE;
 
   return TRUE;
@@ -430,11 +431,11 @@ int sendConqInfo(int sock, int force)
   spConqInfo_t *spci;
 
 #if defined(DEBUG_SERVERSEND)
-  clog("sendConqInfo: f = %d", force);
+  utLog("sendConqInfo: f = %d", force);
 #endif
 
   if ((spci = spktConqInfo(force)))
-    if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)spci) <= 0)
+    if (pktWrite(PKT_TOCLIENT, sock, spci) <= 0)
       return FALSE;
 
   return TRUE;
@@ -448,11 +449,11 @@ int sendHistory(int sock, int hnum)
     return FALSE;
 
 #if defined(DEBUG_SERVERSEND)
-  clog("sendHistory: hnum = %d", hnum);
+  utLog("sendHistory: hnum = %d", hnum);
 #endif
 
   if ((shist = spktHistory(hnum)))
-    if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)shist) <= 0)
+    if (pktWrite(PKT_TOCLIENT, sock, shist) <= 0)
       return FALSE;
 
   return TRUE;
@@ -463,54 +464,54 @@ int sendDoomsday(int sock)
   spDoomsday_t *dd;
 
 #if defined(DEBUG_SERVERSEND)
-  clog("sendDoomsday");
+  utLog("sendDoomsday");
 #endif
 
   if (Context.recmode == RECMODE_ON)
     {
       if ((dd = spktDoomsday(TRUE)))
-        recordWriteEvent((Unsgn8 *)dd);
+        recWriteEvent(dd);
     }
 
   if ((dd = spktDoomsday(FALSE)))
-    if (writePacket(PKT_TOCLIENT, sock, (Unsgn8 *)dd) <= 0)
+    if (pktWrite(PKT_TOCLIENT, sock, dd) <= 0)
       return FALSE;
 
   return TRUE;
 }
   
 
-void procSetName(Unsgn8 *buf)
+void procSetName(char *buf)
 {
   cpSetName_t *cpsetn = (cpSetName_t *)buf;
 
-  if (!validPkt(CP_SETNAME, cpsetn))
+  if (!pktIsValid(CP_SETNAME, cpsetn))
     return;
 
   cpsetn->alias[MAXUSERPNAME - 1] = 0;
 
-  strncpy(Users[Context.unum].alias, cpsetn->alias, MAXUSERPNAME);
+  strncpy(Users[Context.unum].alias, (char *)cpsetn->alias, MAXUSERPNAME);
 
   if (Context.snum > 0 && Context.snum <= MAXSHIPS)
-    strncpy(Ships[Context.snum].alias, cpsetn->alias, MAXUSERPNAME);
+    strncpy(Ships[Context.snum].alias, (char *)cpsetn->alias, MAXUSERPNAME);
 
   return;
 }
 
-void procSetCourse(Unsgn8 *buf)
+void procSetCourse(char *buf)
 {
   cpSetCourse_t *csc = (cpSetCourse_t *)buf;
   int lock;
   real dir;
 
-  if (!validPkt(CP_SETCOURSE, csc))
+  if (!pktIsValid(CP_SETCOURSE, csc))
     return;
 
   lock = (int)csc->lock;
   dir = (real)((real)ntohs(csc->head) / 100.0);
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC SETCOURSE: lock = %d, head = %f",
+  utLog("PROC SETCOURSE: lock = %d, head = %f",
        lock, dir);
 #endif
 
@@ -544,7 +545,7 @@ void procSetWarp(cpCommand_t *swarp)
   real warp;
   real mw;
 
-  if (!validPkt(CP_COMMAND, swarp))
+  if (!pktIsValid(CP_COMMAND, swarp))
     return;
 
   if (swarp->cmd != CPCMD_SETWARP)
@@ -553,7 +554,7 @@ void procSetWarp(cpCommand_t *swarp)
   warp = (real)ntohs(swarp->detail);
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC SETWARP: warp = %f", warp);
+  utLog("PROC SETWARP: warp = %f", warp);
 #endif
 
   if ( Ships[snum].dwarp == 0.0 && warp != 0.0 )
@@ -603,7 +604,7 @@ void procSetShields(cpCommand_t *cmd)
   int snum = Context.snum;		/* we always use our own ship */
   int shup;
 
-  if (!validPkt(CP_COMMAND, cmd))
+  if (!pktIsValid(CP_COMMAND, cmd))
     return;
 
   if (cmd->cmd != CPCMD_SETSHIELDS)
@@ -612,7 +613,7 @@ void procSetShields(cpCommand_t *cmd)
   shup = (((int)ntohs(cmd->detail)) ? TRUE : FALSE);
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC SETSHIELDS: sh = %d", shup);
+  utLog("PROC SETSHIELDS: sh = %d", shup);
 #endif
 
   if (shup)
@@ -631,7 +632,7 @@ void procAlloc(cpCommand_t *cmd)
   int snum = Context.snum;		/* we always use our own ship */
   int alloc;
 
-  if (!validPkt(CP_COMMAND, cmd))
+  if (!pktIsValid(CP_COMMAND, cmd))
     return;
 
   if (cmd->cmd != CPCMD_ALLOC)
@@ -647,7 +648,7 @@ void procAlloc(cpCommand_t *cmd)
     alloc = 70;
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC ALLOC: (w)alloc = %d", alloc);
+  utLog("PROC ALLOC: (w)alloc = %d", alloc);
 #endif
 
   Ships[snum].weapalloc = alloc;
@@ -662,14 +663,14 @@ void procCloak(cpCommand_t *cmd)
   int snum = Context.snum;		/* we always use our own ship */
   string nofuel="Not enough fuel to engage cloaking device.";
 
-  if (!validPkt(CP_COMMAND, cmd))
+  if (!pktIsValid(CP_COMMAND, cmd))
     return;
 
   if (cmd->cmd != CPCMD_CLOAK)
     return;
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC CLOAK");
+  utLog("PROC CLOAK");
 #endif
 
 
@@ -709,14 +710,14 @@ void procDetSelf(cpCommand_t *cmd)
   int snum = Context.snum;		/* we always use our own ship */
   int j;
 
-  if (!validPkt(CP_COMMAND, cmd))
+  if (!pktIsValid(CP_COMMAND, cmd))
     return;
 
   if (cmd->cmd != CPCMD_DETSELF)
     return;
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC DETSELF");
+  utLog("PROC DETSELF");
 #endif
 
   for ( j = 0; j < MAXTORPS; j++ )
@@ -729,14 +730,14 @@ void procDetEnemy(cpCommand_t *cmd)
 {
   int snum = Context.snum;		/* we always use our own ship */
 
-  if (!validPkt(CP_COMMAND, cmd))
+  if (!pktIsValid(CP_COMMAND, cmd))
     return;
 
   if (cmd->cmd != CPCMD_DETENEMY)
     return;
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC DETENEMY");
+  utLog("PROC DETENEMY");
 #endif
 
   clbEnemyDet( snum );
@@ -752,7 +753,7 @@ void procDistress(cpCommand_t *cmd)
   int i, isorb = FALSE;
   int tofriendly;
 
-  if (!validPkt(CP_COMMAND, cmd))
+  if (!pktIsValid(CP_COMMAND, cmd))
     return;
 
   if (cmd->cmd != CPCMD_DISTRESS)
@@ -761,7 +762,7 @@ void procDistress(cpCommand_t *cmd)
   tofriendly = (int)ntohs(cmd->detail);
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC DISTRESS: tofriendly = %d", tofriendly);
+  utLog("PROC DISTRESS: tofriendly = %d", tofriendly);
 #endif
 
   sprintf( cbuf,
@@ -773,13 +774,13 @@ void procDistress(cpCommand_t *cmd)
 
   i = round(Ships[snum].wtemp);
   if ( i < 100 )
-    appint( i, cbuf );
+    utAppendInt( i, cbuf );
   else
     appstr( "**", cbuf );
   appchr( '/', cbuf );
   i = round(Ships[snum].etemp);
   if ( i < 100 )
-    appint( i, cbuf );
+    utAppendInt( i, cbuf );
   else
     appstr( "**", cbuf );
   i = Ships[snum].armies;
@@ -787,7 +788,7 @@ void procDistress(cpCommand_t *cmd)
   if ( i > 0 )
     {
       appstr( ", arm=", cbuf );
-      appint( i, cbuf );
+      utAppendInt( i, cbuf );
     }
 
   if ( Ships[snum].wfuse > 0 )
@@ -843,7 +844,7 @@ void procFirePhaser(cpCommand_t *cmd)
   int snum = Context.snum;		/* we always use our own ship */
   real dir;
 
-  if (!validPkt(CP_COMMAND, cmd))
+  if (!pktIsValid(CP_COMMAND, cmd))
     return;
 
   if (cmd->cmd != CPCMD_FIREPHASER)
@@ -858,7 +859,7 @@ void procFirePhaser(cpCommand_t *cmd)
     dir = 359.9;
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC FIREPHASER: dir = %f", dir);
+  utLog("PROC FIREPHASER: dir = %f", dir);
 #endif
 
   if ( SCLOAKED(snum) )
@@ -890,14 +891,14 @@ void procOrbit(cpCommand_t *cmd)
   int snum = Context.snum;		/* we always use our own ship */
   int pnum;
 
-  if (!validPkt(CP_COMMAND, cmd))
+  if (!pktIsValid(CP_COMMAND, cmd))
     return;
 
   if (cmd->cmd != CPCMD_ORBIT)
     return;
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC ORBIT");
+  utLog("PROC ORBIT");
 #endif
 
   if ( ( Ships[snum].warp == ORBIT_CW ) || ( Ships[snum].warp == ORBIT_CCW ) )
@@ -918,14 +919,14 @@ void procRepair(cpCommand_t *cmd)
 {
   int snum = Context.snum;		/* we always use our own ship */
 
-  if (!validPkt(CP_COMMAND, cmd))
+  if (!pktIsValid(CP_COMMAND, cmd))
     return;
 
   if (cmd->cmd != CPCMD_REPAIR)
     return;
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC REPAIR");
+  utLog("PROC REPAIR");
 #endif
 
   if ( ! SCLOAKED(snum) )
@@ -948,14 +949,14 @@ void procCoup(cpCommand_t *cmd)
   char cbuf[128];
   int rv = -1;
 
-  if (!validPkt(CP_COMMAND, cmd))
+  if (!pktIsValid(CP_COMMAND, cmd))
     return;
 
   if (cmd->cmd != CPCMD_COUP)
     return;
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC COUP");
+  utLog("PROC COUP");
 #endif
 
   /* Check for allowability. */
@@ -1011,8 +1012,8 @@ void procCoup(cpCommand_t *cmd)
   
   /* Now wait it out... */
   sendFeedback("Attempting coup...");
-  grand( &entertime );
-  while ( dgrand( entertime, &now ) < COUP_GRAND )
+  utGrand( &entertime );
+  while ( utDeltaGrand( entertime, &now ) < COUP_GRAND )
     {
       /* See if we're still alive. */
       if ( ! clbStillAlive( Context.snum ) )
@@ -1063,14 +1064,14 @@ void procCoup(cpCommand_t *cmd)
   return;
 }
   
-void procFireTorps(Unsgn8 *buf)
+void procFireTorps(char *buf)
 {
   int snum = Context.snum;		/* we always use our own ship */
   cpFireTorps_t *cftorp = (cpFireTorps_t *)buf;
   real dir;
   int num;
 
-  if (!validPkt(CP_FIRETORPS, cftorp))
+  if (!pktIsValid(CP_FIRETORPS, cftorp))
     return;
 
   dir = (real)((real)ntohs(cftorp->dir) / 100.0);
@@ -1083,7 +1084,7 @@ void procFireTorps(Unsgn8 *buf)
     dir = 359.9;
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC FIRETORPS: dir = %f, num = %d", dir, num);
+  utLog("PROC FIRETORPS: dir = %f, num = %d", dir, num);
 #endif
 
   if ( SCLOAKED(snum) )
@@ -1113,7 +1114,7 @@ void procFireTorps(Unsgn8 *buf)
   
 }
 
-void procMessage(Unsgn8 *buf)
+void procMessage(char *buf)
 {
   int snum = Context.snum;		/* we always use our own ship */
   cpMessage_t *cmsg = (cpMessage_t *)buf;
@@ -1122,29 +1123,29 @@ void procMessage(Unsgn8 *buf)
   if (sInfo.state != SVR_STATE_PLAY)
     return;
    
-  if (!validPkt(CP_MESSAGE, cmsg))
+  if (!pktIsValid(CP_MESSAGE, cmsg))
     return;
 
   to = (Sgn16)ntohs(cmsg->to);
   cmsg->msg[MESSAGE_SIZE - 1] = 0;
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC MESSAGE: to %d", to);
+  utLog("PROC MESSAGE: to %d", to);
 #endif
 
-  clbStoreMsg(snum, to, cmsg->msg);
-  checkOperExec(snum, to, cmsg->msg);
+  clbStoreMsg(snum, to, (char *)cmsg->msg);
+  checkOperExec(snum, to, (char *)cmsg->msg);
 
   return;
 }
 
-void procChangePassword(Unsgn8 *buf)
+void procChangePassword(char *buf)
 {
   char salt[3];
   int unum = Context.unum;
   cpAuthenticate_t *cauth = (cpAuthenticate_t *)buf;
 
-  if (!validPkt(CP_AUTHENTICATE, buf))
+  if (!pktIsValid(CP_AUTHENTICATE, buf))
     return;
 
   cauth->pw[MAXUSERNAME - 1] = 0;
@@ -1152,7 +1153,7 @@ void procChangePassword(Unsgn8 *buf)
   /* we are just interested in the pw */
  
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC ChangePassword");
+  utLog("PROC ChangePassword");
 #endif
  
   salt[0] = (Users[unum].username[0] != EOS) ? Users[unum].username[0] :
@@ -1161,7 +1162,8 @@ void procChangePassword(Unsgn8 *buf)
     'T';
   salt[2] = EOS;
 
-  strncpy(Users[unum].pw, (char *)crypt(cauth->pw, salt), MAXUSERNAME - 2);
+  strncpy(Users[unum].pw, (char *)crypt((char *)cauth->pw, salt), 
+          MAXUSERNAME - 2);
   Users[unum].pw[MAXUSERNAME - 1] = EOS;
 
   return;
@@ -1175,7 +1177,7 @@ void procSetWar(cpCommand_t *cmd)
   int dowait = FALSE, entertime, now, i;
   Unsgn8 war;
 
-  if (!validPkt(CP_COMMAND, cmd))
+  if (!pktIsValid(CP_COMMAND, cmd))
     return;
 
   if (cmd->cmd != CPCMD_SETWAR)
@@ -1184,7 +1186,7 @@ void procSetWar(cpCommand_t *cmd)
   war = (Unsgn8)ntohs(cmd->detail);
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC SETWAR war = 0x%02x", war);
+  utLog("PROC SETWAR war = 0x%02x", war);
 #endif
 
   for (i=0; i<NUMPLAYERTEAMS; i++)
@@ -1208,8 +1210,8 @@ void procSetWar(cpCommand_t *cmd)
   /* any packets the client tries to send will have to wait ;-) */
   if (dowait && Ships[Context.snum].status != SS_RESERVED)
     {
-      grand( &entertime );
-      while ( dgrand( entertime, &now ) < REARM_GRAND )
+      utGrand( &entertime );
+      while ( utDeltaGrand( entertime, &now ) < REARM_GRAND )
 	{
 	  /* See if we're still alive. */
 	  if ( ! clbStillAlive( Context.snum ) )
@@ -1230,7 +1232,7 @@ void procRefit(cpCommand_t *cmd)
   int stype;
   int pnum;
 
-  if (!validPkt(CP_COMMAND, cmd))
+  if (!pktIsValid(CP_COMMAND, cmd))
     return;
 
   if (cmd->cmd != CPCMD_REFIT)
@@ -1242,7 +1244,7 @@ void procRefit(cpCommand_t *cmd)
     return;
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC REFIT: snum - %d, stype = %d", snum, stype);
+  utLog("PROC REFIT: snum - %d, stype = %d", snum, stype);
 #endif
   
   /* Check for allowability. */
@@ -1267,8 +1269,8 @@ void procRefit(cpCommand_t *cmd)
     }
   
   /* now we wait for a bit. */
-  grand( &entertime );
-  while ( dgrand( entertime, &now ) < REFIT_GRAND )
+  utGrand( &entertime );
+  while ( utDeltaGrand( entertime, &now ) < REFIT_GRAND )
     {
       /* See if we're still alive. */
       if ( ! clbStillAlive( snum ) )
@@ -1291,7 +1293,7 @@ void procSetRate(cpCommand_t *cmd)
 #endif
   int rate;
 
-  if (!validPkt(CP_COMMAND, cmd))
+  if (!pktIsValid(CP_COMMAND, cmd))
     return;
 
   if (cmd->cmd != CPCMD_SETRATE)
@@ -1303,7 +1305,7 @@ void procSetRate(cpCommand_t *cmd)
     return;
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC SETRATE: snum = %d, rate = %d", snum, rate);
+  utLog("PROC SETRATE: snum = %d, rate = %d", snum, rate);
 #endif
 
   Context.updsec = rate;
@@ -1317,14 +1319,14 @@ void procTow(cpCommand_t *cmd)
   int other;
   char cbuf[BUFFER_SIZE];
 
-  if (!validPkt(CP_COMMAND, cmd))
+  if (!pktIsValid(CP_COMMAND, cmd))
     return;
 
   if (cmd->cmd != CPCMD_TOW)
     return;
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC TOW: snum = %d", snum);
+  utLog("PROC TOW: snum = %d", snum);
 #endif
 
   other = (int)ntohs(cmd->detail);
@@ -1332,7 +1334,7 @@ void procTow(cpCommand_t *cmd)
   if ( Ships[snum].towedby != 0 )
     {
       c_strcpy( "But we are being towed by ", cbuf );
-      appship( Ships[snum].towedby, cbuf );
+      utAppendShip( Ships[snum].towedby, cbuf );
       appchr( '!', cbuf );
       sendFeedback(cbuf);
       return;
@@ -1340,7 +1342,7 @@ void procTow(cpCommand_t *cmd)
   if ( Ships[snum].towing != 0 )
     {
       c_strcpy( "But we're already towing ", cbuf );
-      appship( Ships[snum].towing, cbuf );
+      utAppendShip( Ships[snum].towing, cbuf );
       appchr( '.', cbuf );
       sendFeedback(cbuf);
       return;
@@ -1387,14 +1389,14 @@ void procUnTow(cpCommand_t *cmd)
   int entertime, now;
   int warsome; 
 
-  if (!validPkt(CP_COMMAND, cmd))
+  if (!pktIsValid(CP_COMMAND, cmd))
     return;
 
   if (cmd->cmd != CPCMD_UNTOW)
     return;
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC UNTOW: snum = %d", snum);
+  utLog("PROC UNTOW: snum = %d", snum);
 #endif
 
   if ( Ships[snum].towedby != 0 )
@@ -1404,8 +1406,8 @@ void procUnTow(cpCommand_t *cmd)
       warsome = ( satwar( snum, Ships[snum].towedby) );
       if ( warsome )
 	{
-	  grand( &entertime );
-	  while ( dgrand( entertime, &now ) < BREAKAWAY_GRAND )
+	  utGrand( &entertime );
+	  while ( utDeltaGrand( entertime, &now ) < BREAKAWAY_GRAND )
 	    {
 	      if ( ! clbStillAlive( Context.snum ) )
 		return;
@@ -1419,7 +1421,7 @@ void procUnTow(cpCommand_t *cmd)
       else
 	{
 	  c_strcpy( "Breaking free from ship ", cbuf );
-	  appship( Ships[snum].towedby, cbuf );
+	  utAppendShip( Ships[snum].towedby, cbuf );
 	  PVLOCK(&ConqInfo->lockword);
 	  if ( Ships[snum].towedby != 0 )
 	    {
@@ -1449,7 +1451,7 @@ void procUnTow(cpCommand_t *cmd)
   else if ( Ships[snum].towing != 0 )
     {
       c_strcpy( "Tow released from ship ", cbuf );
-      appship( Ships[snum].towing, cbuf );
+      utAppendShip( Ships[snum].towing, cbuf );
       PVLOCK(&ConqInfo->lockword);
       if ( Ships[snum].towing != 0 )
 	{
@@ -1495,7 +1497,7 @@ void procBomb(cpCommand_t *cmd)
   string lastfew="The last few armies are eluding us.";
 
 
-  if (!validPkt(CP_COMMAND, cmd))
+  if (!pktIsValid(CP_COMMAND, cmd))
     return;
 
   if (cmd->cmd != CPCMD_BOMB)
@@ -1504,7 +1506,7 @@ void procBomb(cpCommand_t *cmd)
   bomb = (int)ntohs(cmd->detail);
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC BOMB: snum = %d, start bombing = %d", snum, bomb);
+  utLog("PROC BOMB: snum = %d, start bombing = %d", snum, bomb);
 #endif
 
   if (!bomb)			/* the bombing has stopped. yaay. */
@@ -1515,7 +1517,7 @@ void procBomb(cpCommand_t *cmd)
   /* Check for allowability. */
   if ( Ships[snum].warp >= 0.0 )
     {
-      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
       sendFeedback("We must be orbiting a planet to bombard it.");
       return;
     }
@@ -1523,20 +1525,20 @@ void procBomb(cpCommand_t *cmd)
   if ( Planets[pnum].type == PLANET_SUN || Planets[pnum].type == PLANET_MOON ||
       Planets[pnum].team == TEAM_NOTEAM || Planets[pnum].armies == 0 )
     {
-      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
       sendFeedback("There is no one there to bombard.");
       return;
     }
   if ( Planets[pnum].team == Ships[snum].team )
     {
-      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
       sendFeedback("We can't bomb our own armies!");
       return;
     }
   if ( Planets[pnum].team != TEAM_SELFRULED && Planets[pnum].team != TEAM_GOD )
     if ( ! Ships[snum].war[Planets[pnum].team] )
       {
-	sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+	pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
 	sendFeedback("But we are not at war with this planet!");
 	return;
       }
@@ -1554,7 +1556,7 @@ void procBomb(cpCommand_t *cmd)
     {
       sprintf( cbuf, "That was a bad idea, %s...", Ships[snum].alias );
       clbDamage( snum,  rnduni( 50.0, 100.0 ), KB_LIGHTNING );
-      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
       sendFeedback(cbuf);
       return;
     }
@@ -1567,7 +1569,7 @@ void procBomb(cpCommand_t *cmd)
   total = 0;
   ototal = -1;			/* force an update the first time */
   oparmies = -1;
-  grand( &entertime );		/* get start time */
+  utGrand( &entertime );		/* get start time */
   SFSET(snum, SHIP_F_BOMBING);
   while(TRUE)
     {
@@ -1576,18 +1578,18 @@ void procBomb(cpCommand_t *cmd)
           SFCLR(snum, SHIP_F_BOMBING);
           return;
         }
-      if ( isPacketWaiting(sInfo.sock) )
+      if ( pktIsPacketWaiting(sInfo.sock) )
         {
           SFCLR(snum, SHIP_F_BOMBING);
           break;
         }
       
       /* See if it's time to bomb yet. */
-      while ((int) fabs ((real)dgrand( (int)entertime, (int *)&now )) >= BOMBARD_GRAND )
+      while ((int) fabs ((real)utDeltaGrand( (int)entertime, (int *)&now )) >= BOMBARD_GRAND )
 	{
 	  if ( Ships[snum].wfuse > 0 )
 	    {
-	      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, 
+	      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, 
 		      NULL);
 	      sendFeedback("Weapons are currently overloaded.");
 	      goto cbrk22; /* break 2;*/
@@ -1595,13 +1597,13 @@ void procBomb(cpCommand_t *cmd)
 	  x = BOMBARD_FUEL * (real)(BOMBARD_GRAND / 1000.0);
 	  if ( ! clbUseFuel( snum, x, TRUE, TRUE ) )
 	    {
-	      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, 
+	      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, 
 		      NULL);
 	      sendFeedback("Not enough fuel to bombard.");
 	      goto cbrk22; /* break 2;*/
 	    }
 	  /*  entertime = mod( entertime + BOMBARD_GRAND, 24*60*60*1000 );*/
-	  grand(&entertime);
+	  utGrand(&entertime);
 	  killprob = (real)((BOMBARD_PROB *
 			     ((real) weaeff( snum ) *
 			      (real)((real)Planets[pnum].armies/100.0))) + 0.5);
@@ -1613,7 +1615,7 @@ void procBomb(cpCommand_t *cmd)
 		{
 		  /* No more armies left to bomb. */
 		  PVUNLOCK(&ConqInfo->lockword);
-		  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, 
+		  pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, 
 			  NULL);
 		  sendFeedback(lastfew);
 		  goto cbrk22; /* break 2;*/
@@ -1631,7 +1633,7 @@ void procBomb(cpCommand_t *cmd)
       if ( Planets[pnum].armies <= MIN_BOMB_ARMIES )
 	{
 	  /* No more armies left to bomb. */
-	  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+	  pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
 	  sendFeedback(lastfew);
 	  break;
 	}
@@ -1681,7 +1683,7 @@ void procBeam(cpCommand_t *cmd)
   string lastfew="Fleet orders prohibit removing the last three armies.";
   int rv = -1;
 
-  if (!validPkt(CP_COMMAND, cmd))
+  if (!pktIsValid(CP_COMMAND, cmd))
     return;
 
   if (cmd->cmd != CPCMD_BEAM)
@@ -1700,7 +1702,7 @@ void procBeam(cpCommand_t *cmd)
     beamup = TRUE;		/* beaming up */
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC BEAM: snum = %d, detail = 0x%04x, beamup = %d, beam = %d", 
+  utLog("PROC BEAM: snum = %d, detail = 0x%04x, beamup = %d, beam = %d", 
        snum, cmd->detail, beamup, beam);
 #endif
 
@@ -1709,7 +1711,7 @@ void procBeam(cpCommand_t *cmd)
   /* Check for allowability. */
   if ( Ships[snum].warp >= 0.0 )
     {
-      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
       sendFeedback("We must be orbiting a planet to use the transporter.");
       return;
     }
@@ -1718,19 +1720,19 @@ void procBeam(cpCommand_t *cmd)
     {
       if ( Planets[pnum].type == PLANET_SUN )
 	{
-	  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+	  pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
 	  sendFeedback("Idiot!  Our armies will fry down there!");
 	  return;
 	}
       else if ( Planets[pnum].type == PLANET_MOON )
 	{
-	  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+	  pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
 	  sendFeedback("Fool!  Our armies will suffocate down there!");
 	  return;
 	}
       else if ( Planets[pnum].team == TEAM_GOD )
 	{
-	  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+	  pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
 	  sendFeedback("GOD->you: YOUR ARMIES AREN'T GOOD ENOUGH FOR THIS PLANET.");
 	  return;
 	}
@@ -1744,7 +1746,7 @@ void procBeam(cpCommand_t *cmd)
       if ( i != 1 )
 	appchr( 's', cbuf );
       appchr( '.', cbuf );
-      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
       sendFeedback(cbuf);
       return;
     }
@@ -1754,7 +1756,7 @@ void procBeam(cpCommand_t *cmd)
       Planets[pnum].team != TEAM_NOTEAM )
     if ( ! Ships[snum].war[Planets[pnum].team] && Planets[pnum].armies != 0) /* can take empty planets */
       {
-	sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+	pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
 	sendFeedback("But we are not at war with this planet!");
 	return;
       }
@@ -1762,7 +1764,7 @@ void procBeam(cpCommand_t *cmd)
   if ( Ships[snum].armies == 0 &&
       Planets[pnum].team == Ships[snum].team && Planets[pnum].armies <= MIN_BEAM_ARMIES )
     {
-      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
       sendFeedback(lastfew);
       return;
     }
@@ -1771,7 +1773,7 @@ void procBeam(cpCommand_t *cmd)
 
   if ( rkills < (real)1.0 )
     {
-      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
       sendFeedback("Fleet orders prohibit beaming armies until you have a kill.");
       return;
     }
@@ -1804,7 +1806,7 @@ void procBeam(cpCommand_t *cmd)
 	  else
 	    appstr( "ies are", cbuf );
 	  appstr( " reluctant to beam aboard a pirate vessel.", cbuf );
-	  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+	  pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
 	  sendFeedback(cbuf);
 	  return;
 	}
@@ -1814,7 +1816,7 @@ void procBeam(cpCommand_t *cmd)
   /* Figure out which direction to beam. */
   if ( upmax <= 0 && downmax <= 0 )
     {
-      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
+      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, NULL);
       sendFeedback("There is no one to beam.");
       return;
     }
@@ -1860,18 +1862,18 @@ void procBeam(cpCommand_t *cmd)
   zeroed = FALSE;
   conqed = FALSE;
   
-  grand( &entertime );
+  utGrand( &entertime );
   while(TRUE)
     {
       if ( ! clbStillAlive( Context.snum ) )
 	return;
-      if ( isPacketWaiting(sInfo.sock) )
+      if ( pktIsPacketWaiting(sInfo.sock) )
 	break;
       
       /* See if it's time to beam again. */
-      while ( dgrand( entertime, &now ) >= BEAM_GRAND )
+      while ( utDeltaGrand( entertime, &now ) >= BEAM_GRAND )
 	{
-	  grand(&entertime);
+	  utGrand(&entertime);
 	  PVLOCK(&ConqInfo->lockword);
 	  if ( dirup )
 	    {
@@ -1879,7 +1881,7 @@ void procBeam(cpCommand_t *cmd)
 	      if ( Planets[pnum].armies <= MIN_BEAM_ARMIES )
 		{
 		  PVUNLOCK(&ConqInfo->lockword);
-		  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, 
+		  pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED, 
 			  NULL);
 		  sendFeedback(lastfew);
 		  break;
@@ -1914,7 +1916,7 @@ void procBeam(cpCommand_t *cmd)
 	  if ( total >= num )
 	    {
 	      /* Done. */
-	      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_DONE, 
+	      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_DONE, 
 		      NULL);
               sendFeedback("");
 	      goto cbrk21; 
@@ -1933,7 +1935,7 @@ void procBeam(cpCommand_t *cmd)
 	  if ( total == 0 )
 	    appstr( "no", cbuf );
 	  else
-	    appint( total, cbuf );
+	    utAppendInt( total, cbuf );
 	  appstr( " arm", cbuf );
 	  if ( total == 1 )
 	    {
@@ -1944,7 +1946,7 @@ void procBeam(cpCommand_t *cmd)
 	      appstr( "ies", cbuf );
 	    }
 	  appstr( " transported, ", cbuf );
-	  appint( num - total, cbuf );
+	  utAppendInt( num - total, cbuf );
 	  appstr( " to go.", cbuf );
 	  sendFeedback(cbuf);
 	  ototal = total;
@@ -1982,14 +1984,14 @@ void procDestruct(cpCommand_t *cmd)
   int snum = Context.snum;
   int entertime, now; 
 
-  if (!validPkt(CP_COMMAND, cmd))
+  if (!pktIsValid(CP_COMMAND, cmd))
     return;
   
   if (cmd->cmd != CPCMD_DESTRUCT)
     return;
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC DESTRUCT: snum = %d, detail = 0x%04x", 
+  utLog("PROC DESTRUCT: snum = %d, detail = 0x%04x", 
        snum, cmd->detail);
 #endif
 
@@ -2000,7 +2002,7 @@ void procDestruct(cpCommand_t *cmd)
 
   if ( SCLOAKED(snum) )
     {
-      sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED,
+      pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED,
 	      NULL);
       sendFeedback("The cloaking device is using all available power.");
       return;
@@ -2009,13 +2011,13 @@ void procDestruct(cpCommand_t *cmd)
   /* Set up the destruct fuse. */
   Ships[Context.snum].sdfuse = SELFDESTRUCT_FUSE;
   
-  gsecs( &entertime );
+  utGetSecs( &entertime );
   
 
   Context.msgok = TRUE;			/* messages are ok in the beginning */
   while ( Ships[Context.snum].sdfuse > 0 )
     {
-      Ships[Context.snum].sdfuse = SELFDESTRUCT_FUSE - dsecs ( entertime, &now );
+      Ships[Context.snum].sdfuse = SELFDESTRUCT_FUSE - utDeltaSecs ( entertime, &now );
 
       /* Display new messages until T-minus 3 seconds. */
 
@@ -2029,10 +2031,10 @@ void procDestruct(cpCommand_t *cmd)
 	  return;
 	}
 
-      if ( isPacketWaiting(sInfo.sock) )
+      if ( pktIsPacketWaiting(sInfo.sock) )
 	{
 	  Ships[Context.snum].sdfuse = 0;
-	  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED,
+	  pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED,
 		  NULL);
 	  return;
 	}
@@ -2062,7 +2064,7 @@ void procDestruct(cpCommand_t *cmd)
 	clbKillShip( Context.snum, KB_SELF );
     }
   
-  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_DONE,
+  pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_DONE,
 	  NULL);
   return;
   
@@ -2073,14 +2075,14 @@ void procAutoPilot(cpCommand_t *cmd)
   int snum = Context.snum;
   int laststat, now; 
 
-  if (!validPkt(CP_COMMAND, cmd))
+  if (!pktIsValid(CP_COMMAND, cmd))
     return;
   
   if (cmd->cmd != CPCMD_AUTOPILOT)
     return;
 
 #if defined(DEBUG_SERVERPROC)
-  clog("PROC AUTOPILOT: snum = %d, detail = 0x%04x", 
+  utLog("PROC AUTOPILOT: snum = %d, detail = 0x%04x", 
        snum, ntohs(cmd->detail));
 #endif
 
@@ -2090,7 +2092,7 @@ void procAutoPilot(cpCommand_t *cmd)
   /* allowed? */
   if (!Users[Ships[snum].unum].ooptions[OOPT_AUTOPILOT])
     {
-      clog("PROC AUTOPILOT: unum = %d, snum = %d: NOT ALLOWED", 
+      utLog("PROC AUTOPILOT: unum = %d, snum = %d: NOT ALLOWED", 
            Ships[snum].unum, snum);
       return;
     }
@@ -2098,7 +2100,7 @@ void procAutoPilot(cpCommand_t *cmd)
  sendFeedback("Autopilot activated.");
  SFSET(snum, SHIP_F_ROBOT);
 
-  gsecs( &laststat );			/* initialize stat timer */
+  utGetSecs( &laststat );			/* initialize stat timer */
   while ( clbStillAlive( Context.snum ) )
     {
       /* Make sure we still control our ship. */
@@ -2106,15 +2108,15 @@ void procAutoPilot(cpCommand_t *cmd)
 	break;
       
       /* See if it's time to update the statistics. */
-      if ( dsecs( laststat, &now ) >= 15 )
+      if ( utDeltaSecs( laststat, &now ) >= 15 )
 	{
 	  conqstats( Context.snum );
 	  laststat = now;
 	}
 
-      if ( isPacketWaiting(sInfo.sock) ) 
+      if ( pktIsPacketWaiting(sInfo.sock) ) 
         {
-          sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED,
+          pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_CANCELED,
                   NULL);
           break;
         }
@@ -2125,7 +2127,7 @@ void procAutoPilot(cpCommand_t *cmd)
   SFCLR(snum, SHIP_F_ROBOT);
   Ships[snum].action = 0;
   
-  sendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_DONE,
+  pktSendAck(sInfo.sock, PKT_TOCLIENT, PSEV_INFO, PERR_DONE,
 	  NULL);
   return;
   
@@ -2133,7 +2135,7 @@ void procAutoPilot(cpCommand_t *cmd)
 
 void procReload(cpCommand_t *cmd)
 {
-  if (!validPkt(CP_COMMAND, cmd))
+  if (!pktIsValid(CP_COMMAND, cmd))
     return;
 
   if (cmd->cmd != CPCMD_RELOAD)
