@@ -4,7 +4,7 @@
  *
  * packet recEvent/pkt generation for the server
  *
- * $Id: serverpkt.c 564 2006-07-24 00:52:28Z jon $
+ * $Id: serverpkt.c 762 2008-07-23 02:14:59Z jon13 $
  *
  * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -145,8 +145,8 @@ spUser_t *spktUser(Unsgn16 unum)
   for (i=0; i<USTAT_TOTALSTATS; i++)
     suser.stats[i] = (Sgn32)htonl(Users[unum].stats[i]);
 
-  strncpy(suser.username, Users[unum].username, MAXUSERNAME - 1);
-  strncpy(suser.alias, Users[unum].alias, MAXUSERPNAME - 1);
+  strncpy((char *)suser.username, Users[unum].username, MAXUSERNAME - 1);
+  strncpy((char *)suser.alias, Users[unum].alias, MAXUSERPNAME - 1);
 
   if (memcmp((void *)&suser, (void *)&pktUser[unum], sizeof(spUser_t)))
     {
@@ -217,7 +217,7 @@ spShip_t *spktShip(Unsgn8 snum, int rec)
   for (i=0; i<NUMPLAYERTEAMS; i++)
     sship.scanned[i] = (Unsgn8)Ships[snum].scanned[i];
 
-  strncpy(sship.alias, Ships[snum].alias, MAXUSERPNAME - 1);
+  strncpy((char *)sship.alias, Ships[snum].alias, MAXUSERPNAME - 1);
 
   if (rec)
     {
@@ -452,7 +452,6 @@ spShipLoc_t *spktShipLoc(Unsgn8 snum, int rec)
   return NULL;
 }
 
-/* we have the potential to send 3 packets here. */
 spPlanet_t *spktPlanet(Unsgn8 pnum, int rec)
 {
   int snum = Context.snum;
@@ -462,7 +461,7 @@ spPlanet_t *spktPlanet(Unsgn8 pnum, int rec)
   memset((void *)&splan, 0, sizeof(spPlanet_t));
 
 #if defined(DEBUG_SERVERSEND)
-  clog("sendPlanet: pnum = %d",
+  utLog("sendPlanet: pnum = %d",
        pnum);
 #endif
 
@@ -476,7 +475,7 @@ spPlanet_t *spktPlanet(Unsgn8 pnum, int rec)
   else
     splan.team = TEAM_SELFRULED; /* until we know for sure... */
 
-  strncpy(splan.name, Planets[pnum].name, MAXPLANETNAME);
+  strncpy((char *)splan.name, Planets[pnum].name, MAXPLANETNAME);
 
   if (rec)
     {
@@ -558,8 +557,8 @@ spPlanetLoc_t *spktPlanetLoc(Unsgn8 pnum, int rec, int force)
   int team = Ships[snum].team;
   static spPlanetLoc_t splanloc;
   real dx, dy;
-  static real px[NUMPLANETS] = {}; /* saved x/y */
-  static real py[NUMPLANETS] = {}; 
+  static real px[NUMPLANETS + 1] = {}; /* saved x/y */
+  static real py[NUMPLANETS + 1] = {}; 
   
   memset((void *)&splanloc, 0, sizeof(spPlanetLoc_t));
 
@@ -586,7 +585,7 @@ spPlanetLoc_t *spktPlanetLoc(Unsgn8 pnum, int rec, int force)
       ((dx + dy) / 2.0) < 3.0)
     {
 #if 0
-      clog("REJECT: %s dx = %f dy = %f [%f]", Planets[pnum].name,
+      utLog("REJECT: %s dx = %f dy = %f [%f]", Planets[pnum].name,
            dx, dy,
            ((dx + dy) / 2.0));
 #endif
@@ -602,7 +601,7 @@ spPlanetLoc_t *spktPlanetLoc(Unsgn8 pnum, int rec, int force)
     }
   
 #if 0
-  clog("%s dx = %f dy = %f [%f]", Planets[pnum].name,
+  utLog("%s dx = %f dy = %f [%f]", Planets[pnum].name,
        dx, dy,
        ((dx + dy) / 2.0));
 #endif
@@ -639,7 +638,7 @@ spPlanetLoc2_t *spktPlanetLoc2(Unsgn8 pnum, int rec, int force)
   static spPlanetLoc2_t splanloc2;
   Unsgn32 iternow = clbGetMillis(); /* we send the loc2 packets only every 5 secs */
   const Unsgn32 iterwait = 5000.0; /* ms */
-  static Unsgn32 tstart[NUMPLANETS] = {}; /* saved time deltas */
+  static Unsgn32 tstart[NUMPLANETS + 1] = {}; /* saved time deltas */
   int tooearly = FALSE;
   
   /* 
@@ -898,7 +897,7 @@ spTeam_t *spktTeam(Unsgn8 team, int force, int rec)
   for (i=0; i<MAXTSTATS; i++)
     steam.stats[i] = (Unsgn32)htonl(Teams[team].stats[i]);
 
-  strncpy(steam.name, Teams[team].name, MAXTEAMNAME - 1);
+  strncpy((char *)steam.name, Teams[team].name, MAXTEAMNAME - 1);
   
   if (rec)
     {
@@ -930,10 +929,10 @@ spConqInfo_t *spktConqInfo(int force)
 
   spci.type = SP_CONQINFO;
 
-  strncpy(spci.conqueror, ConqInfo->conqueror, MAXUSERPNAME - 1);
-  strncpy(spci.conqteam, ConqInfo->conqteam, MAXTEAMNAME - 1);
-  strncpy(spci.conqtime, ConqInfo->conqtime, DATESIZE - 1);
-  strncpy(spci.lastwords, ConqInfo->lastwords, MAXLASTWORDS - 1);
+  strncpy((char *)spci.conqueror, ConqInfo->conqueror, MAXUSERPNAME - 1);
+  strncpy((char *)spci.conqteam, ConqInfo->conqteam, MAXTEAMNAME - 1);
+  strncpy((char *)spci.conqtime, ConqInfo->conqtime, DATESIZE - 1);
+  strncpy((char *)spci.lastwords, ConqInfo->lastwords, MAXLASTWORDS - 1);
   
   if (memcmp((void *)&spci, (void *)&pktConqInfo,
              sizeof(spConqInfo_t)) || force)
