@@ -1,7 +1,7 @@
 /* 
  * Ship structure
  *
- * $Id: ship.h 696 2007-04-25 04:47:32Z jon $
+ * $Id: ship.h 762 2008-07-23 02:14:59Z jon13 $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -25,21 +25,21 @@
 #define SHIP_F_BOMBING     0x0100 /* ship is currently bombing */
 
 /* helpers */
-#define SCLOAKED(x)  ( bitIsSet(Ships[(x)].flags, SHIP_F_CLOAKED) )
-#define SVACANT(x)   ( bitIsSet(Ships[(x)].flags, SHIP_F_VACANT) )
-#define SSHUP(x)     ( bitIsSet(Ships[(x)].flags, SHIP_F_SHUP) )
-#define SREPAIR(x)   ( bitIsSet(Ships[(x)].flags, SHIP_F_REPAIR) )
-#define STALERT(x)   ( bitIsSet(Ships[(x)].flags, SHIP_F_TALERT) )
-#define SROBOT(x)    ( bitIsSet(Ships[(x)].flags, SHIP_F_ROBOT) )
-#define SMAP(x)      ( bitIsSet(Ships[(x)].flags, SHIP_F_MAP) )
-#define SSCANDIST(x) ( bitIsSet(Ships[(x)].flags, SHIP_F_SCANDIST) )
-#define SBOMBING(x)  ( bitIsSet(Ships[(x)].flags, SHIP_F_BOMBING) )
+#define SCLOAKED(x)  ( Ships[(x)].flags & SHIP_F_CLOAKED )
+#define SVACANT(x)   ( Ships[(x)].flags & SHIP_F_VACANT )
+#define SSHUP(x)     ( Ships[(x)].flags & SHIP_F_SHUP )
+#define SREPAIR(x)   ( Ships[(x)].flags & SHIP_F_REPAIR )
+#define STALERT(x)   ( Ships[(x)].flags & SHIP_F_TALERT )
+#define SROBOT(x)    ( Ships[(x)].flags & SHIP_F_ROBOT )
+#define SMAP(x)      ( Ships[(x)].flags & SHIP_F_MAP )
+#define SSCANDIST(x) ( Ships[(x)].flags & SHIP_F_SCANDIST )
+#define SBOMBING(x)  ( Ships[(x)].flags & SHIP_F_BOMBING )
 
 /* lookup the proper [SCALE|MAP]_FAC depending on LR/SR status */
 #define SFAC(x)      (SMAP(x) ? MAP_FAC : SCALE_FAC) 
 
-#define SFSET(x, b)  (bitSet(Ships[(x)].flags, b))
-#define SFCLR(x, b)  (bitClear(Ships[(x)].flags, b))
+#define SFSET(x, b)  ( Ships[(x)].flags |=  (b) )
+#define SFCLR(x, b)  ( Ships[(x)].flags &= ~(b) )
 
 typedef struct {
   int status;			/* one of the SS_ values */
