@@ -1,12 +1,13 @@
 /* 
  * TCP Wrappers support
  *
- * $Id: tcpwrap.c 711 2007-07-16 18:37:32Z jon $
+ * $Id: tcpwrap.c 762 2008-07-23 02:14:59Z jon13 $
  *
  * Copyright 2007 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
 
 #include "c_defs.h"
+#include "global.h"
 #include "config.h"
 
 #if defined(HAVE_TCPW) && defined(HAVE_TCPD_H) 
@@ -38,10 +39,10 @@ int tcpwCheckHostAccess(char *daemon, char *remotehost)
     }
   
   if (!allowed)
-    clog("TCPW: %s: %s: ACCESS DENIED",
+    utLog("TCPW: %s: %s: ACCESS DENIED",
          daemon, remotehost);
-  else
-    clog("TCPW: %s: %s: ACCESS GRANTED",
+  else if (cqDebug)
+    utLog("TCPW: %s: %s: ACCESS GRANTED",
          daemon, remotehost);
       
   return((allowed) ? TRUE : FALSE);
