@@ -2,7 +2,7 @@
 /* Copyright (c) Mark J. Kilgard, 1997. */
 
 /* JET - I've modified it a little, but it works nicely. */
-/* $Id: texfont.c 552 2006-07-17 04:47:23Z jon $ */
+/* $Id: texfont.c 762 2008-07-23 02:14:59Z jon13 $ */
 /* This program is freely distributable without licensing fees  and is
    provided without guarantee or warrantee expressed or  implied. This
    program is -not- in the public domain. */
@@ -99,7 +99,7 @@ getTCVI(TexFont * txf, int c)
   }
 
 #ifdef DEBUG_GL
-  clog("texfont: tried to access unavailable font character \"%c\" (%d)\n",
+  utLog("texfont: tried to access unavailable font character \"%c\" (%d)\n",
        isprint(c) ? c : '?', c);
   assert(0); 
 #endif
@@ -384,6 +384,11 @@ txfEstablishTexture(
   }
 #if !defined(USE_DISPLAY_LISTS)
   glBindTexture(GL_TEXTURE_2D, txf->texobj);
+  /* use linear MAG filtering */
+  glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
+  /* this is highest quality.  It should be configurable. */
+  glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, 
+                  GL_LINEAR_MIPMAP_LINEAR);
 #else
   glNewList(txf->texobj, GL_COMPILE);
 #endif
